@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: acccomp.tcl
-#  Last change:  23 May 2004
+#  Last change:  24 October 2008
 #
 
 # Replacement procedures for more accurate and more slow computations of
@@ -52,8 +52,9 @@ proc ComputeDist {p1 p2 datum} {
     if { [expr abs(cos($la1))]<1.e-20 || [expr abs(cos($la2))]<1.e-20 || \
 	 ( $lad1+$lad2 < 1e-4 && abs(abs($lod1-$lod2)-180) < 1e-4 ) } {
 	# use Law of Cosines for Spherical Trigonometry
-	return [expr 1e-3*$a*acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+ \
-		sin($la1)*sin($la2))]
+	set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+	if { $x >= 1 } { return 0 }
+	return [expr 1e-3*$a*acos($x)]
     }
     set eps 5e-12
     set r [expr 1-$f]
@@ -246,8 +247,9 @@ proc ComputeDistFD {p1 p2} {
     set lo2 [expr $lod2*0.01745329251994329576]
     if { [expr abs(cos($la1))]<1.e-20 || [expr abs(cos($la2))]<1.e-20 } {
 	# use Law of Cosines for Spherical Trigonometry
-	return [expr 1e-3*$DatumA*acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+ \
-		sin($la1)*sin($la2))]
+	set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+	if { $x >= 1 } { return 0 }
+	return [expr 1e-3*$DatumA*acos($x)]
     }
     set eps 5e-12
     set r [expr 1-$DatumF]
