@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: cluster.tcl
-#  Last change:  20 October 2004
+#  Last change:  24 July 2009
 #
 
 proc DistCluster {w dtxt dist args} {
@@ -178,12 +178,9 @@ proc MakeClusters {w} {
 	    DISTUNIT DLUNIT
 
     destroy .clstr
-    toplevel .clstr
-    wm protocol .clstr WM_DELETE_WINDOW  { destroy .clstr }
-    wm title .clstr "$TXT(cluster)/GPS Manager"
-    wm transient .clstr
-    wm geometry .clstr +$EPOSX+$EPOSY
-    bind .clstr <Key-Return> "DoMakeClusters $w"
+    GMToplevel .clstr cluster +$EPOSX+$EPOSY {} \
+        {WM_DELETE_WINDOW {destroy .clstr}} \
+        [list <Key-Return> "DoMakeClusters $w"]
     catch { unset Cluster }
     set Cluster(how) inquadr
     set Cluster(min) 0
@@ -287,7 +284,7 @@ proc MakeClusters {w} {
 proc DoMakeClusters {w} {
     # use information in dialog created by proc MakeClusters to call
     #  the procedures that do the actual computation of clusters
-    global Cluster TXT DSCALEFOR DLUNIT
+    global Cluster TXT DSCALEFOR DLUNIT MESS
 
     switch $Cluster(how) {
 	bydist {
