@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command.tcl
-#  Last change:  25 September 2008
+#  Last change:  27 October 2009
 #
 
 # this file is only source-ed in command-line mode (even if the graphical
@@ -62,7 +62,10 @@ proc ExecCommand {} {
 		Img {
 		    if { $NoImgLib } { return 1 }
 		}
-		default { return 1 }
+		default {
+		    if { [lsearch -exact [package names] $COMMAND(what)] \
+			     == -1 } { return 1 }
+		}
 	    }
 	}
 	getwrite {
