@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command_parse.tcl
-#  Last change:  25 September 2008
+#  Last change:  27 October 2009
 #
 
 # this file is only source-ed in command-line mode
@@ -39,7 +39,7 @@ set COMMAND(USAGE) {Usage: gpsman [PREFIXES] COMMAND [ARGS]
     is available | connected
     show help | version | formats | protocols | projections | datums |
                 transfs | symbols
-    haslib gpsmanshp | Img
+    haslib gpsmanshp | Img | TclCurl
     getwrite IN-TYPES FORMAT [OUT-PARAMS] [OUT-TYPES] PATH
     readput FORMAT [IN-PARAMS] [IN-TYPES] PATH [OUT-TYPES]  (-rec not allowed!)
     translate IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH [HOW-PARAMS] \
@@ -205,7 +205,7 @@ proc BadCommandLine {} {
 	}
 	haslib {
 	    set what [lindex $argv 0]
-	    if { [lsearch "gpsmanshp Img" $what] == -1 } {
+	    if { [lsearch "gpsmanshp Img TclCurl" $what] == -1 } {
 		puts stderr "Unknown argument $what; use \"show help\""
 		return 1
 	    }
