@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  24 October 2008
+#  Last change:  16 December 2009
 #
 # Includes contributions by
 #  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
@@ -666,7 +666,7 @@ proc SphericalArea {wpixs} {
 proc ChangeTPsDatum {tps datum1 datum2} {
     # convert position of TR points on list $tps from $datum1 to $datum2
     # change only the first 4 elements (position) of each TP representation
-    # this depends on DataIndex (see main.tcl, Storage), not used here
+    # this depends on DataIndex (see setup.tcl, Storage), not used here
     #  for speed
 
     if { $datum1 == $datum2 } { return $tps }
@@ -682,7 +682,7 @@ proc ChangeTPsDatum {tps datum1 datum2} {
 proc ChangeLPsDatum {lps odatum datum pformt} {
     # change datum of LN list of points
     # change only the first element (position) of each LP representation
-    # this depends on DataIndex (see main.tcl, Storage), not used here
+    # this depends on DataIndex (see setup.tcl, Storage), not used here
     #  for speed
     # return -1 if the current position format requires a fixed datum
     #  different from $datum
@@ -886,14 +886,23 @@ proc ScanDate {date} {
 	set n 1
 	if { [scan $hms %02d:%02d:%0f h mn s] == 3 && \
 		 [scan $ymd %4d-%02d-%02d y m d] == 3 } {
-	    set s [expr round($s)]
+	    if { [set s [expr round($s)]] > 59 } {
+		incr s -60
+		if { [incr mn] > 59 } {
+		    incr mn -60
+		    if { [incr h] > 23 } {
+			incr h -24
+			foreach "y m d" [NextDay $y $m $d] {}
+		    }
+		}
+	    }
 	    if { [scan $tail %03d:%02d hz mz] == 2 } {
 		set goodn 1
 		# compute UTC date
 		if { $hz > 0 } { set mz [expr -$mz] }
 		set hz [expr -$hz]
-		if { [incr mn $mz] > 60 } {
-		    incr h ; set mn [expr $mn-60]
+		if { [incr mn $mz] > 59 } {
+		    incr h ; incr mn -60
 		} elseif { $mn < 0 } {
 		    incr h -1 ; incr mn 60
 		}
