@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: config.tcl
-#  Last change:  7 May 2008
+#  Last change:  27 December 2009
 #
 
 ## the following values can be set from the options dialog of the interface
@@ -154,8 +154,11 @@ set DEFMAPPROJ UTM
 set DEFMAPPFRMT UTM/UPS
 set DEFMAPPFDATUM $Datum
 
-  # formulae: either more accurate or faster
-set ACCFORMULAE 0
+  # formulae: either more accurate (1) or faster (0)
+  #  faster should only be used on very slow computers as these
+  #  formulae can give rise to large errors when computing
+  #  distances
+set ACCFORMULAE 1
 
   # ask for confirmation of projection parameters
 set ASKPROJPARAMS 1
@@ -181,15 +184,17 @@ set MAPSCLENGTH 300
          # actual distance and unit (from the values above) for the scale arrow
 set MAPSCALE "4 km"
 
- # fonts: size in points or "Tcl/Tk" for the default of Tcl/Tk
-  # default font size
-set FONTSIZE Tcl/Tk
-  # fixed font size
-set FIXEDFONTSIZE Tcl/Tk
-  # map font size in points or "Tcl/Tk" for the default of Tcl/Tk
-set MAPFONTSIZE Tcl/Tk
-  # travel/navigation font size in points or "Tcl/Tk" for the default of Tcl/Tk
-set TRAVELFONTSIZE 12
+ # fonts: either "default" or a Tcl/Tk font description
+  # default font
+set DEFAULTFONT default
+  # fixed font
+set FIXEDFONT fixed
+  # map font
+set MAPFONT fixed
+  # travel/navigation font
+set TRAVELFONT {fixed 12}
+  # plot/graph font
+set PLOTFONT {fixed 12}
 
  # size of icons: either 15x15 (pixels) or 30x30
 set ICONSIZE 15x15
@@ -310,6 +315,9 @@ array set COUTFMT {
     GRA    %.5f
 }
 
+  # echo on password fields, either "none" or a single character
+set PASSWDECHO *
+
   # options used when importing Kismet .network files
   #   types: which Kismet network types should be converted to waypoints
   #   esymbols: symbols (icons) to use for each encryption under each type
