@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: elevation.tcl
-#  Last change:  14 August 2008
+#  Last change:  18 December 2009
 #
 # This file contains mostly code contributed by Alessandro Palmas
 #   (alpalmas _AT_ tin.it)
@@ -122,11 +122,12 @@ proc Hgraph {k what args} {
     #   retrieving and displaying this information later on
     #  - button to extend the ticks in the horizontal axis to the top of
     #   the window and restore them
+    #  - changing the text font
     #----
     global MESS TXT BITMAP
     # MF contribution
     global NoImgLib ImgOutFormats DPOSX DPOSY MapWidth MAPH2 PlotWNo \
-	HGinfo
+	HGinfo PlotFont
 
     if { $args == "time" } {
 	set totdist 0
@@ -240,12 +241,9 @@ proc Hgraph {k what args} {
 	# MF change: using proc HgraphClose
 	HgraphClose $w
     }
-    toplevel $w
-    # MF contribution: added usual things in other GPSMan toplevels
-    wm protocol $w WM_DELETE_WINDOW "HgraphClose $w"
-    wm title $w "$TXT($what)/GPS Manager"
-    wm transient $w .
-    wm geometry $w +$DPOSX+$DPOSY
+    # MF change: using general proc as for other GPSMan toplevels
+    GMToplevel $w $what +$DPOSX+$DPOSY . \
+        [list WM_DELETE_WINDOW "HgraphClose $w"] {}
     #----
     # a frame with border to avoid wm corniche to cover inner canvas
     frame $w.gf -borderwidth 3
@@ -266,7 +264,7 @@ proc Hgraph {k what args} {
     pack $bf -side bottom
 
     # MF change: using proc HgraphClose
-    set b [button $w.bf.b -text Ok -command "HgraphClose $w"]
+    set b [button $w.bf.b -text $TXT(ok) -command "HgraphClose $w"]
     # MF change: use of Img lib
     if { $NoImgLib } {
 	set p [button $w.bf.p -text "$TXT(saveto) PS" \
@@ -280,11 +278,16 @@ proc Hgraph {k what args} {
 	    $m add command -label $f -command "SaveCanvas $c {} $f file"
 	}
     }
-    # MF contrib: save canvas and extend/restore ticks in horizontal axis
+    # MF contrib: save canvas, extend/restore ticks in horizontal axis
+    #  and change font
     button $w.bf.pp -text $TXT(print) \
-		-command "SaveCanvas $w.gf.c {} PS printer"
-    button $w.bf.btick -text $TXT(vertgridlines) -command "HgraphVertGrid $w"
-    pack $p $w.bf.pp $w.bf.btick $b -side left
+	-command "SaveCanvas $w.gf.c {} PS printer"
+    button $w.bf.btick -text $TXT(vertgridlines) \
+	-command "HgraphVertGrid $w"
+    button $w.bf.font -text $TXT(optPLOTFONT) \
+	-command "CanvasChangeFont $c PlotFont PlotFont;
+		    $w.bf.font configure -state normal"
+    pack $p $w.bf.pp $w.bf.btick $w.bf.font $b -side left
     #----
 
     # MF contrib
@@ -385,8 +388,9 @@ proc Hgraph {k what args} {
 	    set tmp [Hnormalize $y $ymin $scaly]
 	    set tmp [expr $MY-$tmp]
 	    set tmp [expr int($tmp)]
-	    # MF contribution: lowering these items
-	    set it [$c create text 50 $tmp -fill "red" -text "$y"]
+	    # MF contribution: lowering these items and using $PlotFont
+	    set it [$c create text 50 $tmp -fill "red" -text "$y" \
+			-font $PlotFont -tags txt]
 	    $c lower $it
 	    set it [$c create line 0 $tmp $MX $tmp -fill "tan" -width 2]
 	    $c lower $it
@@ -417,7 +421,8 @@ proc Hgraph {k what args} {
 		$c lower $it
 		# MF contribution: show value
 		set it [$c create text $tmp [expr $MY+5] -anchor n \
-			    -text $x -fill red]
+			    -text $x -fill red -font $PlotFont \
+			    -tags txt]
 		$c lower $it
 		#======
 	    }
@@ -466,8 +471,10 @@ proc Hgraph {k what args} {
 		} else { incr hour0 }
 	    } else { incr min0 $min_d }
 	    set tmp [expr [Hnormalize $x 0 $scalx]]
+	    # MF contrib: using $PlotFont
 	    set it [$c create text $tmp $MY -anchor n \
-			-text [format "%02d:%02d" $hour0 $min0] -fill red]
+			-text [format "%02d:%02d" $hour0 $min0] -fill red \
+		        -font $PlotFont -tags txt]
 	    $c lower $it
 	    set it [$c create line $tmp $MY $tmp [expr $MY-10] \
 			-fill "tan" -tags vgline]
@@ -481,13 +488,14 @@ proc Hgraph {k what args} {
     #---
     # MF change: time values are self-documented, placing extreme values
     #   replaced "h. max"/"h. min" by "max"/"min"; lowering the items
+    #   and using $PlotFont
     set xextrs 50
     if { $totdist } {
 	set it [$c create text [expr $MX - 60] [expr $MY + 15] -fill "black" \
-		    -text "delta $deltax"]
+		    -text "delta $deltax" -font $PlotFont -tags txt]
 	$c lower $it
 	set it [$c create text [expr $MX - 50] [expr $MY + 5] -fill "black" \
-		    -text "tot. $xexcursion"]
+		    -text "tot. $xexcursion" -font $PlotFont -tags txt]
 	$c lower $it
     } else {
 	set xhr0 [Hnormalize $xhr0 0 $scalx]
@@ -497,11 +505,11 @@ proc Hgraph {k what args} {
 	    set xextrs [expr $xhr0+$deltax/2]
 	}
     }
-    #----
     $c create text $xextrs [expr $MY + 5] -fill "black" -justify "left" \
-	-text "max: $trueymax"
+	-text "max: $trueymax" -font $PlotFont -tags txt
     $c create text $xextrs [expr $MY + 15] -fill "black" -justify "left" \
-	-text "min: $ymin"
+	-text "min: $ymin" -font $PlotFont -tags txt
+    #----
 
     #to be polite, let's return explicitly
     return
@@ -519,6 +527,8 @@ proc HGtest1 {c x y} {
     #  - avoid problems if window was resized by replacing use of
     #   HGpxwp array by tags in graph lines
     #  - maximum x and y must depend on current window size
+    #  - using $PlotFont
+    global PlotFont
 
     foreach "mx my" [$c coords currentsize] { break }
     set my [expr $my*0.85]
@@ -592,14 +602,14 @@ proc HGtest1 {c x y} {
     $c create oval  [expr $x-1] [expr $y-1] [expr $x+1] [expr $y+1] \
 	-outline tan -fill tan -tags oldlt
     $c create text  $x $y -text $pts -anchor $an -justify $ju -fill tan \
-	-tag oldlt
+	-tags {oldlt txt} -font $PlotFont
     return
 }
 
 # BS contribution: based on proc HGtest1, display info on plot points
 proc HGtest3 {c x y dist_or_time secs0} {
     # MF change
-    global HGinfo DTUNIT SUBDTUNIT
+    global HGinfo DTUNIT SUBDTUNIT PlotFont
     #======
 
     foreach "mx my" [$c coords currentsize] { break }
@@ -713,8 +723,9 @@ proc HGtest3 {c x y dist_or_time secs0} {
 	# Display the selected point
 	$c create oval  [expr $x-3] [expr $y-3] [expr $x+3] [expr $y+3] \
 	    -outline tan -fill tan -tags oldlt
+	# MF contrib: using $PlotFont
 	$c create text  $x_text $y_text -text $comment -anchor "w" \
-	    -justify "left" -fill "red" -tag oldlt
+	    -justify "left" -fill "red" -tags {oldlt txt} -font $PlotFont
 
 	# BS: end
 	# MF ccontrib: clear old information near the legend
@@ -1392,12 +1403,9 @@ proc HG3D_canvas {alt} {
 	set anim_stop $HG3Dglob(anim_stop)
 	#
 	destroy .elev3D
-	set w [toplevel .elev3D]
-    wm protocol .elev3D WM_DELETE_WINDOW { destroy .elev3D }
-    wm title .elev3D "$TXT(elevation)/GPS Manager"
-    wm transient .elev3D .
-	# MF contribution
-	wm geometry .elev3D +$DPOSX+$DPOSY
+	# MF change: using general proc as for other GPSMan toplevels
+        set w [GMToplevel .elev3D elevation +$DPOSX+$DPOSY . \
+	       {WM_DELETE_WINDOW {destroy .elev3D}} {}]
 	#-----
 	set f0 [frame $w.f0]
 	set c1 [canvas $f0.c1 -width $WIDTH_  -height $HEIGHT_]
@@ -1489,7 +1497,7 @@ proc HG3D_canvas {alt} {
 	$mn add checkbutton -label $TXT(notext) -variable HG3Dglob(text_on) \
 		-command HG3D_text -selectcolor $COLOUR(check)
 
-	button $w.f6.ok -text Ok -command "destroy $w; "
+	button $w.f6.ok -text $TXT(ok) -command "destroy $w; "
 
 	pack $w.f6  $w.f6.view -side left -fill x
 
