@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  30 August 2008
+#  Last change:  23 August 2009
 #
 # See also files_foreign.tcl
 #  and metadata.tcl for properties of known file formats
@@ -643,7 +643,7 @@ proc SaveGREls {how args} {
     }
     set f [GMOpenFile $TXT(saveto) GR w]
     if { $f != ".." } {
-	SlowOpWindow $TXT(save)
+	set sid [SlowOpWindow $TXT(save)]
 	set SFileHeader($f) 0
 	if { [set i [lsearch -exact $whs GR]] != -1 } {
 	    set whs [lreplace $whs $i $i]
@@ -659,7 +659,7 @@ proc SaveGREls {how args} {
 	    unset SFileHeader($f)
 	}
 	if { $f != "stdout" } { close $f }
-	SlowOpFinish ""
+	SlowOpFinish $sid ""
     }
     return
 }
@@ -714,7 +714,7 @@ proc SaveFileTo {f how what args} {
     set oldf $f
     if { $f != "" || [set f [GMOpenFile $TXT(saveto) $what w]] != ".." } {
 	if { $slow } {
-	    SlowOpWindow $TXT(save)
+	    set sid [SlowOpWindow $TXT(save)]
 	} else { SetCursor . watch }
 	set SFileHeader($f) 0
 	switch $how {
@@ -739,7 +739,7 @@ proc SaveFileTo {f how what args} {
 	}
 	if { $f != "stdout" } { close $f }
 	if { $slow } {
-	    SlowOpFinish ""
+	    SlowOpFinish $sid ""
 	} else { ResetCursor . }
     }
     return
@@ -1156,7 +1156,10 @@ proc OpenInputFileFails {what fmt} {
     lappend parwidgts "@$TXT(mapitems)"
     while 1 {
 	set f [GMOpenFileParms $TXT($for) $what r $params $parwidgts]
-	if { $f == ".." } { return 1 }
+	if { $f == ".." } {
+	    EndWPRenaming
+	    return 1
+	}
 	set ok 1
 	if { $pars != "" } {
 	    set vrctvl ""
@@ -1194,10 +1197,10 @@ proc InitInputFileVars {f what cr vis} {
     #  $cr set if creation date is in use
     #  $vis set if must display items read in
     global LFileLNo LFileCreat LFileBuffFull LFileEOF LFileDefs LFileVisible \
-	    LFileTimeOff LChannel TXT
+	    LFileTimeOff LFileSlowId LChannel TXT
 
-    SlowOpWindow $TXT(fread)
-    set LChannel($what) $f
+    set sid [SlowOpWindow $TXT(fread)]
+    set LChannel($what) $f ; set LFileSlowId($f) $sid
     set LFileLNo($f) 0 ; set LFileCreat($f) $cr ; set LFileTimeOff($f) ""
     set LFileBuffFull($f) 0 ; set LFileEOF($f) 0
     set LFileDefs($f) 0 ; set LFileVisible($f) $vis
@@ -1210,17 +1213,19 @@ proc CloseInputFile {what} {
     #  $what in $TYPES or $what=="LAP"
     global LFilePFrmt LFileDatum LFileLNo LFileCreat \
 	    LFileId LFileOther LFileBuff LFileBuffFull LFileEOF LFileDefs \
-	    LFileVisible LFileTimeOff LChannel
+	    LFileVisible LFileTimeOff LFileSlowId LChannel
 
     set f $LChannel($what)
     if { $f != "stdin" } { close $f }
+    set sid $LFileSlowId($f)
     foreach v "LFilePFrmt($f) LFileDatum($f) LFileTimeOff($f) \
 	    LFileLNo($f) LFileCreat($f) LFileDefs($f) LFileId($f) \
 	    LFileOther($f) LFileBuff($f) LFileBuffFull($f) \
-	    LFileEOF($f) LFileVisible($f) LChannel($what)" {
+	    LFileEOF($f) LFileVisible($f) LFileSlowId($f) \
+            LChannel($what)" {
 	catch { unset $v }
     }
-    SlowOpFinish ""
+    SlowOpFinish $sid ""
     return
 }
 
@@ -2326,8 +2331,8 @@ proc LoadGRElements {file id} {
 	set line [ReadFile $file]
 	if { $LFileEOF($file) } { break }
 	set line [CleanLine $line 0]
-	if { [string length $line] > 0 } {
-	    if { [string first ! $line]==0 } {
+	if { $line != "" } {
+	    if { [string first ! $line] == 0 } {
 		switch -glob [set c [ProcCommand $line $file]] {
 		    format -  datum -  pformat -  dates - 
 		    WP -  RT -  TR -  LN -  LAP -
@@ -2337,7 +2342,7 @@ proc LoadGRElements {file id} {
 		    }
 		    GRWP {
 			set wh WP
-			set n [GetReplacedName $LFileId($file) GR $id]
+			set n [GetReplNameInGR $LFileId($file) $id]
 			if { ! [CheckName Ignore $n] } {
 			    GMMessage "$MESS(badGRel) $LFileLNo($file)"
 			    return ""
@@ -2367,7 +2372,7 @@ proc LoadGRElements {file id} {
 		}
 		set n [lindex $fs 1]
 		if { $wh == "WP" } {
-		    set n [GetReplacedName $n GR $id]
+		    set n [GetReplNameInGR $n $id]
 		    if { ! [CheckName Ignore $n] } {
 			GMMessage "$MESS(badGRel) $LFileLNo($file)"
 			return ""
@@ -2465,8 +2470,9 @@ proc LoadFile {what} {
     # return 0 on error
     global LChannel
 
-    InitWPRenaming
-    if { [OpenInputFileFails $what GPSMan] } { return }
+    if { [InitWPRenaming] == 0 || [OpenInputFileFails $what GPSMan] } {
+	return 0
+    }
     set r [LoadAll $LChannel($what)]
     CloseInputFile $what
     EndWPRenaming
@@ -2480,7 +2486,7 @@ proc LoadFileFrom {f what} {
     # return 0 on error
     global LChannel CREATIONDATE SHOWFILEITEMS
 
-    InitWPRenaming
+    if { [InitWPRenaming] == 0 } { return 0 }
     InitInputFileVars $f $what $CREATIONDATE $SHOWFILEITEMS
     set r [LoadAll $f]
     CloseInputFile $what
@@ -2517,7 +2523,7 @@ proc LoadGRElsIn {types lixs fmt} {
 		    GMMessage $MESS(noheader)
 		    break
 		}
-		if { [Bad${wh}Read $file 0 $howRT] } { break }
+		if { [Bad${wh}Read $file 0 [set how$wh]] } { break }
 	    }
 	    GR {
 		if { [BadGRRead $file 0] } { break }
@@ -2666,7 +2672,7 @@ proc LoadMapInfo {path} {
 	set f [GMOpenFile $TXT(loadfrm) MapInfo r]
     } else {
 	if { [catch {set f [open $path r]}] } {
-	    GMMessage "MESS(cantread) $path"
+	    GMMessage "$MESS(cantread) $path"
 	    return -1
 	}
     }
