@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,12 @@
 #      along with this program.
 #
 #  File: garmin_nmea.tcl
-#  Last change:  22 November 2005
+#  Last change:  13 October 2008
 #
 
+# Includes contributions by
+#  - Valere Robin (valere.robin _AT_ wanadoo.fr) marked "VR contribution"
+
 ## procedures used to interpret NMEA-0183 sentences from a receiver or
 ##  a file (see files_foreign.tcl)
 
@@ -360,13 +363,18 @@ proc CollectNMEAData {sent time data} {
 	    set from "0 1 3" ; set to "0 1 2"
 	}
 	GPRMC {
-	    set sp [expr [lindex $data 4]/539.9568e-3]
-	    set data [lreplace $data 4 4 $sp]
-	    set date [lindex $data 6]
-	    if { $date != "_" } {
-		set NMEACurrentDate $date
-	    }
-	    set from "1 2 3 4 5" ; set to "2 0 1 7 8"
+	    # VR contribution: test for validity of data
+	    if { [lindex $data 4] != "_" } {
+		set sp [expr [lindex $data 4]/539.9568e-3]
+	    	set data [lreplace $data 4 4 $sp]
+	    	set date [lindex $data 6]
+	    	if { $date != "_" } {
+			set NMEACurrentDate $date
+	    	}
+	    	set from "1 2 3 4 5" ; set to "2 0 1 7 8"
+	    } else {
+		set from ""
+            }
 	}
 	GPVTG {
 	    set from "0 3" ; set to "8 7"
