@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  27 September 2008
+#  Last change:  30 July 2009
 #
 
 # description of Garmin protocols based on
@@ -527,11 +527,15 @@ array set PRODID {
     "Forerunner 305" 484
     "StreetPilot c330" 497
     "StreetPilot i2" 532
+    "GPSmap 378 SYS" 557
+    "Rino 530HCx" 577
     "eTrex Legend HCx" 694
     "eTrex Vista HCx" 694
     "eTrex Venture HC" {695 786}
-    "eTrex H" 696
-    "eTrex Summit HC" 786
+    "eTrex H" {696 696+}
+    "eTrex Summit HC" {695 786}
+    "GPS 20x USB" 811
+    "eTrex Legend H" 957
 }
 
     # product names and how to obain its product specific protocols
@@ -647,11 +651,16 @@ array set PNAME {
     484  "Forerunner 205/305"
     497  "StreetPilot c320/c330"
     532  "StreetPilot i2"
+    557  "GPSmap 378 SYS"
     574  "Geko 201"
+    577  "Rino 530HCx"
     694  "eTrex Legend/Vista HCx"
-    695  "eTrex Venture HC"
+    695  "eTrex Summit/Venture HC"
     696  "eTrex H"
+    696+ "eTrex H"
     786  "eTrex Summit/Venture HC"
+    811  "GPS 20x USB"
+    957  "eTrex Legend H"
 }
 
 # the descriptions below are valid for all versions except:
@@ -682,6 +691,7 @@ array set PRTCLVERSION {
     289 {{{>= 240} 289+}}
     484 {{{>= 260} 484+}}
     694 {{{>= 240} 694+}}
+    696 {{{>= 300} 696+}}
 }
 
 array set PRTCLDEF {
@@ -792,11 +802,15 @@ array set PRTCLDEF {
     497  array
     532  array
     574  see=248
+    577  see=292
     694  diff
     694+ diff
     695  see=694+
     696  see=248
+    696+ diff
     786  see=694+
+    811  diff
+    957  diff
 }
 
 ### there is no information on which receivers use the PVT protocol
@@ -1237,9 +1251,9 @@ array set PSPID {
     404,ALData D501
     404,DtTm A600
     404,DtTmData D600
-    404,Posn A700
     404,FleetManagement A602
     404,FMData D602
+    404,Posn A700
     404,PosnData D700
     404,PVT A800
     404,PVTData D800
@@ -1369,6 +1383,32 @@ array set PSPID {
     532,PVT A800
     532,PVTData D800
     532,nospec A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A913+A916+A917+D917+A918+D918
+
+    557,Link L001
+    557,Baud T001
+    557,DevCmd A010
+    557,WP A100
+    557,WPData D110
+    557,WPCat A101
+    557,WPCatData D120
+    557,RT A201
+    557,RTHeader D202
+    557,RTWPData D110
+    557,RTLinkData D210
+    557,TR A301
+    557,TRHeader D312
+    557,TRData D302
+    557,Prx A400
+    557,PrxWPData D110
+    557,AL A500
+    557,ALData D501
+    557,DtTm A600
+    557,DtTmData D600
+    557,Posn A700
+    557,PosnData D700
+    557,PVT A800
+    557,PVTData D800
+    557,nospec A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A913+D913+A916+A918+D918
 }
 
           # must not differ on the Link and DevCmd protocols
@@ -1407,8 +1447,11 @@ array set PSDIFF {
    439  {177 {nospec A800+D801+A802+D802+A900+A902+A903}}
    484  {450 {AL N/A} {nospec A601+D601+A902+A903+A907+D907+D908+D909+D910+A1000+D1009+A906+D1011+A1000+D1009+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013}}
    484+ {450 {nospec A601+D601+A801+D801+A902+A903+A907+D907+D908+D909+D910+A918+D918+A1000+D1009+A906+D1015+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013+A1013+D1014}}
-   694  {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918}}
+   694  {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918}}  
    694+ {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918}}
+   696+ {696 {nospec A902+A903}}
+   811  {273 {Baud N/A} {nospec A902+A903+A1010}}
+   957  {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A914+A916+A918+D918}}
 }
 
 ## descriptions, positions in Garmin structures of GPSMan data
