@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,13 +17,39 @@
 #      along with this program.
 #
 #  File: gendials.tcl
-#  Last change:  27 September 2008
+#  Last change:  27 December 2009
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb_AT_onthenet.com.au) marked "BSB contribution"
 #  - Stefan Heinen (stefan.heinen_AT_djh-freeweb.de) marked "SH contribution"
 #
 
+  # creating toplevels
+
+proc GMToplevel {w title geom trans prots binds} {
+    # create a toplevel with given geometry
+    #   $w      window path
+    #   $title  if not empty title given as either "==TITLE" for TITLE,
+    #            or as an index in TXT array
+    #   $trans  if not void is path of window of which $w is a transient
+    #   $prots  list with in sequence a wm protocol and a command
+    #   $binds  list with in sequence an event and a command
+    # return $w
+    global TXT
+
+    if { $title != "" && ! [regsub {^==} $title "" title] } {
+	set title $TXT($title)
+    }
+    toplevel $w
+    if { $title != "" } { wm title $w "$title/GPSMan" }
+    wm geometry $w $geom
+    if { $trans != {} } { wm transient $w $trans }
+    wm group $w .
+    foreach {p c} $prots { wm protocol $w $p $c }
+    foreach {e c} $binds { bind $w $e $c }
+    return $w
+}
+
   # modal dialogs
 
 proc GMMessage {mess args} {
@@ -69,22 +95,18 @@ proc GMMessage {mess args} {
     }
     # this avoids bugs but may create havoc with grabs
     set gs [grab current]
-    toplevel .mess
+    GMToplevel .mess message +$EPOSX+$EPOSY . \
+        [list WM_DELETE_WINDOW  [list DestroyRGrabs .mess $gs]] \
+        [list <Key-Return> [list DestroyRGrabs .mess $gs]]
     if { ! $UNIX } {
 	# SH contribution
 	focus .mess
     }
 
-    wm protocol .mess WM_DELETE_WINDOW [list DestroyRGrabs .mess $gs]
-    wm title .mess "$TXT(message)/GPS Manager"
-    wm transient .mess .
-    wm geometry .mess +$EPOSX+$EPOSY
-    bind .mess <Key-Return> [list DestroyRGrabs .mess $gs]
-
     frame .mess.fr -borderwidth 5 -bg $COLOUR(messbg)
     label .mess.fr.title -text "!!!" -relief sunken
     label .mess.fr.text -text $mess
-    button .mess.fr.ok -text Ok -command [list DestroyRGrabs .mess $gs]
+    button .mess.fr.ok -text $TXT(ok) -command [list DestroyRGrabs .mess $gs]
     pack .mess.fr -side top
     # changes in packing order must be reflected above when adding
     #  new messages to existing window
@@ -109,19 +131,16 @@ proc GMConfirm {mess} {
 
     if { $CMDLINE } { return 1 }
     destroy .messres
-    toplevel .messres
-    wm protocol .messres WM_DELETE_WINDOW { set GMResConf 0 }
-    wm title .messres "$TXT(message)/GPS Manager"
-    wm transient .messres .
-    wm geometry .messres +$EPOSX+$EPOSY
-    bind .messres <Key-Return> { set GMResConf 1 }
-    bind .messres <Key-Delete> { set GMResConf 0 }
+    GMToplevel .messres message +$EPOSX+$EPOSY . \
+        {WM_DELETE_WINDOW {set GMResConf 0}} \
+        [list <Key-Return> {set GMResConf 1} \
+	     <Key-Delete> {set GMResConf 0}]
 
     frame .messres.fr -borderwidth 5 -bg $COLOUR(confbg)
     label .messres.fr.title -text "???" -relief sunken
     label .messres.fr.text -text $mess
     frame .messres.fr.bs
-    button .messres.fr.bs.ok -text Ok -command { set GMResConf 1 }
+    button .messres.fr.bs.ok -text $TXT(ok) -command { set GMResConf 1 }
     button .messres.fr.bs.cancel -text $TXT(no) -command { set GMResConf 0 }
     pack .messres.fr.bs.ok .messres.fr.bs.cancel -side left -pady 5
     pack .messres.fr.title .messres.fr.text .messres.fr.bs -side top -pady 5
@@ -151,16 +170,13 @@ proc GMSelect {mess blist vlist} {
     #  Return and Delete keys, respectively
 
     destroy .messres
-    toplevel .messres
-    wm protocol .messres WM_DELETE_WINDOW "set GMResSel [lindex $vlist 0]"
-    wm title .messres "$TXT(selection)/GPS Manager"
-    wm transient .messres .
-    wm geometry .messres +$EPOSX+$EPOSY
     set e [lindex $blist 0]
     if { [string first "@" $e] == 0 } {
 	set e [lindex [lindex $vlist 0] 0]
     } else { set e [lindex $vlist 0] }
-    bind .messres <Key-Return> "set GMResSel $e"
+    GMToplevel .messres selection +$EPOSX+$EPOSY . \
+        [list WM_DELETE_WINDOW  "set GMResSel [lindex $vlist 0]"] \
+        [list <Key-Return> "set GMResSel $e"]
 
     frame .messres.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .messres.fr.title -text "???" -relief sunken
@@ -224,12 +240,9 @@ proc GMChooseFrom {how mess wd blist vlist args} {
     set w .gmchoosefr
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set GMResult cnc }
-    wm title $w "$mess/GPS Manager"
-    wm transient $w .
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set GMResult ok }
+    GMToplevel $w "==$mess" +$DPOSX+$DPOSY . \
+        {WM_DELETE_WINDOW {set GMResult cnc}} \
+        [list <Key-Return> {set GMResult ok}]
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.text -text $mess
@@ -264,7 +277,7 @@ proc GMChooseFrom {how mess wd blist vlist args} {
     } else { set opts 0 ; set menus 0 }
 
     frame $w.fr.frbt
-    button $w.fr.frbt.ok -text Ok -command { set GMResult ok }
+    button $w.fr.frbt.ok -text $TXT(ok) -command { set GMResult ok }
     button $w.fr.frbt.cnc -text $TXT(cancel) -command { set GMResult cnc }
 
     pack $w.fr.frbt.ok $w.fr.frbt.cnc -side left -pady 5
@@ -324,12 +337,9 @@ proc GMChooseParams {mess vars descs} {
     set w .gmchooseprsr
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set GMResult cnc }
-    wm title $w "$mess/GPS Manager"
-    wm transient $w .
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set GMResult ok }
+    GMToplevel $w "==$mess" +$DPOSX+$DPOSY . \
+        {WM_DELETE_WINDOW {set GMResult cnc}} \
+        [list <Key-Return> {set GMResult ok}]
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.text -text $mess
@@ -338,7 +348,7 @@ proc GMChooseParams {mess vars descs} {
     foreach "menus es" [GMSetupParams $w.fr.fopt $vars $descs] {}
 
     frame $w.fr.frbt
-    button $w.fr.frbt.ok -text Ok -command { set GMResult ok }
+    button $w.fr.frbt.ok -text $TXT(ok) -command { set GMResult ok }
     button $w.fr.frbt.cnc -text $TXT(cancel) -command { set GMResult cnc }
 
     pack $w.fr.frbt.ok $w.fr.frbt.cnc -side left -pady 5
@@ -370,6 +380,26 @@ proc GMChooseParams {mess vars descs} {
     return $res
 }
 
+proc GMLogin {service} {
+    # get or retrieve login information for accessing a given service
+    #  $service is a unique name for the service, needed for displaying
+    #    a message and indexing saved login information
+    # save the login information for use in the current session if the user
+    #  asks for it
+    # return list with user name and password or an empty list if cancelled
+    global MESS TXT GMPInfo
+
+    if { ! [catch {set up $GMPInfo($service)}] } { return $up }
+    if { [GMChooseParams [format $MESS(loginto) $service] \
+	      {GMPInfo(__tmp,u) GMPInfo(__tmp,p) GMPInfo(__tmp,s)} \
+	      [list =$TXT(uname) =@$TXT(pword) @$TXT(remember)]] \
+	     == 0 } { return {} }
+    set up [list $GMPInfo(__tmp,u) $GMPInfo(__tmp,p)]
+    unset GMPInfo(__tmp,p)
+    if { $GMPInfo(__tmp,s) } { set GMPInfo($service) $up }
+    return $up
+}
+
 ##### information window
 
 proc DisplayInfo {mess args} {
@@ -385,11 +415,8 @@ proc DisplayInfo {mess args} {
 
     set frt .gminfo.fr.frt
     if { ! [winfo exists .gminfo] } {
-	toplevel .gminfo
-	wm protocol .gminfo WM_DELETE_WINDOW { destroy .gminfo }
-	wm title .gminfo "$TXT(info)/GPS Manager"
-	wm transient .gminfo
-	wm geometry .gminfo +$EPOSX+$EPOSY
+	GMToplevel .gminfo info +$EPOSX+$EPOSY {} \
+	    {WM_DELETE_WINDOW {destroy .gminfo}} {}
 
 	frame .gminfo.fr -borderwidth 5 -bg $COLOUR(messbg)
 	label .gminfo.fr.title -text $TXT(info) -relief sunken
@@ -477,24 +504,27 @@ proc SlowOpWindow {mess} {
     #  returns 1 if the operation is to be aborted, or updates the interface
     #  and returns 0  otherwise
     # any call within the loop to GMMessage will be diverted to this dialog
-    # after the main loop there should be a call to proc SlowOpFinish
+    # after the main loop there should be a call to proc SlowOpFinish with
+    #  the unique identifier that is returned by proc SlowOpWindow
+    # returns a unique identifier to be used when calling proc SlowOpWindow
     global SlowOp COLOUR MAPCOLOUR EPOSX EPOSY TXT CMDLINE USESLOWOPWINDOW \
 	FixedFont
 
     if { $CMDLINE || ! $USESLOWOPWINDOW } { return }
-
     if { [winfo exists .slowop] } {
+	set SlowOp(id) [clock seconds]
+	set SlowOp(ids) [linsert $SlowOp(ids) 0 $SlowOp(id)]
 	.slowop.fr.title configure -text $mess
-	return
+	return $SlowOp(id)
     }
 
-    array set SlowOp [list \
-	    aborting 0  status "$TXT(working)..."  grabs [grab current]]
-    toplevel .slowop
-    wm protocol .slowop WM_DELETE_WINDOW { set SlowOp(aborting) 1 }
-    wm title .slowop "$TXT(opinprogr)/GPS Manager"
-    wm transient .slowop
-    wm geometry .slowop +$EPOSX+$EPOSY
+    set id [clock seconds]
+    array set SlowOp [list aborting 0  id $id  ids $id \
+			  status "$TXT(working)..." grabs [grab current]]
+    # avoid completely covering other dialogs
+    set pos [expr $EPOSX+150]
+    GMToplevel .slowop opinprogr +$pos+$EPOSY {} \
+        {WM_DELETE_WINDOW {set SlowOp(aborting) 1}} {}
 
     frame .slowop.fr -borderwidth 5 -bg $COLOUR(messbg)
     label .slowop.fr.title -text $mess -relief sunken
@@ -529,6 +559,42 @@ proc SlowOpWindow {mess} {
     update idletasks
     grab .slowop
     RaiseWindow .slowop
+    return $id
+}
+
+proc SlowOpFinish {id mess} {
+    # to be called by application when the operation ends (either normally
+    #  or not)
+    #  $id is unique identifier that was returned by proc SlowOpWindow
+    #    if $id is not in the $SlowOp(ids) stack the message is displayed
+    #    and nothing else happens
+    #  $mess will be displayed if not empty
+    # the dialog window will be closed only when the stack of calls to
+    #  proc SlowOpWindow is empty
+    # the dialog window is closed silently if there were no messages,
+    #  otherwise the Ok button is activated and the user must acknowledge it
+    global SlowOp TXT
+
+    if { ! [winfo exists .slowop] } {
+	if { $mess != "" } { GMMessage $mess }
+	return
+    }
+    if { $mess != "" } { SlowOpMessage $mess }
+    if { [set ix [lsearch -exact $SlowOp(ids) $id]] == -1 || \
+	     [set SlowOp(ids) [lreplace $SlowOp(ids) 0 $ix]] != {} } {
+	return
+    }
+    if { ! $SlowOp(aborting) } { set SlowOp(status) $TXT(errwarn) }
+    set SlowOp(aborting) 0
+    set txt .slowop.fr.frt.txt
+    if { [$txt index end] == 2.0 } {
+	DestroyRGrabs .slowop $SlowOp(grabs)
+	return
+    }
+    set frb .slowop.fr.frb
+    foreach b "abort ok" st "disabled normal" {
+	$frb.$b configure -state $st
+    }
     return
 }
 
@@ -553,33 +619,6 @@ proc SlowOpMessage {mess} {
     return
 }    
 
-proc SlowOpFinish {mess} {
-    # to be called by application when the operation ends (either normally
-    #  or not)
-    #  $mess will be displayed if not empty
-    # the dialog window will be closed silently if there were no messages,
-    #  otherwise the Ok button is activated and the user must acknowledge it
-    global SlowOp TXT
-
-    if { ! [winfo exists .slowop] } {
-	if { $mess != "" } { GMMessage $mess }
-	return
-    }
-    if { ! $SlowOp(aborting) } { set SlowOp(status) $TXT(errwarn) }
-    set SlowOp(aborting) 0
-    if { $mess != "" } { SlowOpMessage $mess }
-    set txt .slowop.fr.frt.txt
-    if { [$txt index end] == 2.0 } {
-	DestroyRGrabs .slowop $SlowOp(grabs)
-	return
-    }
-    set frb .slowop.fr.frb
-    foreach b "abort ok" st "disabled normal" {
-	$frb.$b configure -state $st
-    }
-    return
-}
-
 proc SlowOpAborted {} {
     # to be called by the application to test if the operation was aborted
     # if not a call to update is made to ensure that the window is usable
@@ -602,7 +641,7 @@ proc SlowOpAborted {} {
 proc GMOpenFile {act wh mode} {
     # create modal dialog for selecting and opening a file
     #  $act is string describing the action to do on the file
-    #  $wh in $filetypes (see proc GMStart, main.tcl)
+    #  $wh in $filetypes (see proc GMStart, setup.tcl)
     #  $mode in {r, w}
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
@@ -612,12 +651,9 @@ proc GMOpenFile {act wh mode} {
 	set currfile ""
     } else { set currfile [file tail $f] }
 
-    toplevel .fdlg
-    wm protocol .fdlg WM_DELETE_WINDOW { set GMResult cnc }
-    wm title .fdlg "$TXT(file)/GPS Manager"
-    wm transient .fdlg .
-    wm geometry .fdlg +$DPOSX+$DPOSY
-    bind .fdlg <Key-Return> { set GMResult ok }
+    GMToplevel .fdlg file +$DPOSX+$DPOSY . \
+        {WM_DELETE_WINDOW {set GMResult cnc}} \
+        [list <Key-Return> {set GMResult ok}]
 
     frame .fdlg.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .fdlg.fr.title -text [format $MESS(fileact) $act $TXT(name$wh)] \
@@ -652,7 +688,7 @@ proc GMOpenFile {act wh mode} {
     TextBindings .fdlg.fr.fn
     
     frame .fdlg.fr.bs
-    button .fdlg.fr.bs.ok -text Ok -command { set GMResult ok }
+    button .fdlg.fr.bs.ok -text $TXT(ok) -command { set GMResult ok }
     button .fdlg.fr.bs.cnc -text $TXT(cancel) \
 	    -command { set GMResult cnc }
 
@@ -723,7 +759,7 @@ proc GMOpenFileParms {act wh mode vars vals} {
 proc GMGetFileName {act wh mode vars vals} {
     # create modal dialog for selecting a file name and parameters
     #  $act is string describing the action to do on the file
-    #  $wh in $filetypes (see proc GMStart, main.tcl)
+    #  $wh in $filetypes (see proc GMStart, setup.tcl)
     #  $mode in {r, w}
     #  $vars is list of (global) vars to set
     #  $vals is associated list of value descriptions (see proc GMSetupParams)
@@ -735,12 +771,9 @@ proc GMGetFileName {act wh mode vars vals} {
 	set currfile ""
     } else { set currfile [file tail $f] }
 
-    toplevel .fdlg
-    wm protocol .fdlg WM_DELETE_WINDOW { set GMResult cnc }
-    wm title .fdlg "$TXT(file)/GPS Manager"
-    wm transient .fdlg .
-    wm geometry .fdlg +$DPOSX+$DPOSY
-    bind .fdlg <Key-Return> { set GMResult ok }
+    GMToplevel .fdlg file +$DPOSX+$DPOSY . \
+        {WM_DELETE_WINDOW {set GMResult cnc}} \
+        [list <Key-Return> {set GMResult ok}]
 
     frame .fdlg.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .fdlg.fr.title -text [format $MESS(fileact) $act $TXT(name$wh)] \
@@ -782,7 +815,7 @@ proc GMGetFileName {act wh mode vars vals} {
     foreach "menus es" [GMSetupParams .fdlg.fr.fopt $vars $vals] {}
 
     frame .fdlg.fr.bs
-    button .fdlg.fr.bs.ok -text Ok -command { set GMResult ok }
+    button .fdlg.fr.bs.ok -text $TXT(ok) -command { set GMResult ok }
     button .fdlg.fr.bs.cnc -text $TXT(cancel) \
 	-command { set GMResult cnc }
 
@@ -905,57 +938,212 @@ proc ChangeVolume {w vol} {
     return
 }
 
+### font selection
+
+proc GMSelectFont {args} {
+    # dialog for selecting a font
+    #  $args may contain the font description to return if the
+    #        default is selected; if empty "default" is returned
+    # a font is defined by giving
+    #   one of [font families] and
+    #   the size in points or pixels, an integer > 0
+    #   the weight, one of {normal bold}
+    #   the slant, one of {roman italic}
+    #   whether to use underline
+    #   whether to use overstrike
+    # return empty list if cancelled, "default" or the description
+    #   in $args, or list with family, size, and other style
+    #   indicators in {normal bold roman italic underline overstrike}
+    #   where size follows the Tk convention (negative if in pixels)
+    global GMFtDial TXT MESS LISTHEIGHT EPOSX EPOSY COLOUR
+
+    array set GMFtDial {
+	size 12
+	units points
+	weight normal
+	slant roman
+	underline 0
+	overstrike 0
+    }
+
+    if { [winfo exists .gmselfont] } { destroy .gmselfont }
+    set w [GMToplevel .gmselfont selfont +$EPOSX+$EPOSY . \
+	       {WM_DELETE_WINDOW {set GMFtDial(act) cancel}} \
+	       [list <Key-Return> {set GMFtDial(act) ok}]]
+
+    frame $w.fr -borderwidth 5 -bg $COLOUR(selbg)
+    label $w.fr.tit -text $TXT(selfont)
+    set frbx $w.fr.frbx
+    frame $frbx
+    listbox $frbx.box -height $LISTHEIGHT -width 40 -selectmode single \
+	-yscrollcommand "$frbx.bscr set" -exportselection 1
+    scrollbar $frbx.bscr -command "$frbx.box yview"
+    grid $frbx.box -row 0 -column 0
+    grid $frbx.bscr -row 0 -column 1 -sticky ns
+    grid rowconfigure $frbx 0 -weight 1
+    grid columnconfigure $frbx 0 -weight 1
+    foreach fam [lsort -dictionary [font families]] {
+	$frbx.box insert end $fam
+    }
+
+    frame $w.fr.frp
+    set vars {} ; set descs {}
+    foreach v {size units weight slant underline overstrike} {
+	lappend vars GMFtDial($v)
+    }
+    set descs [list "=$TXT(size)" \
+		   "~$TXT(units)/[list points pixels]" \
+		   "~$TXT(weight)/[list normal bold]" \
+		   "~$TXT(slant)/[list roman italic]" \
+		   "@$TXT(underline)" "@$TXT(overstrike)"]
+    set pes [lindex [GMSetupParams $w.fr.frp $vars $descs] 1]
+
+    set frbs $w.fr.frbs
+    frame $frbs
+    foreach x {ok default cancel} {
+	button $frbs.$x -text $TXT($x) -command "set GMFtDial(act) $x"
+	pack $frbs.$x -side left
+    }
+
+    pack $w.fr.tit
+    pack $frbs -side bottom -pady 5
+    pack $w.fr.frp -side bottom -pady 5
+    # must be the last one
+    pack $w.fr.frbx -fill both -expand 1 -pady 5
+
+    grid $w.fr
+    grid rowconfigure $w.fr 0 -weight 1
+    grid columnconfigure $w.fr 0 -weight 1
+    grid rowconfigure $w 0 -weight 1
+    grid columnconfigure $w 0 -weight 1
+
+    update idletasks
+    # cannot use RaiseWindow because of menus
+    set grabs [grab current]
+    grab $w
+    while 1 {
+	tkwait variable GMFtDial(act)
+	switch $GMFtDial(act) {
+	    cancel {
+		set res {} ; break
+	    }
+	    default {
+		if { [set res [lindex $args 0]] == {} } {
+		    set res default
+		}
+		break
+	    }
+	    ok {
+		if { [set ix [$frbx.box curselection]] == {} } {
+		    GMMessage $MESS(mustselftfam)
+		    continue
+		}
+		GMUseEntries $w.fr.frp $pes
+		set n [string trim $GMFtDial(size)]
+		if { ! [CheckNumber GMMessage $n] } { continue }
+		if { $n < 1 } {
+		    GMMessage [format $MESS(xcantbey) $TXT(size) 0]
+		    continue
+		}
+		if { $GMFtDial(units) == "pixels" } {
+		    set n [expr -$n]
+		}
+		set res [list [$frbx.box get $ix]]
+		lappend res $n
+		foreach x {weight slant} { lappend res $GMFtDial($x) }
+		foreach x {underline overstrike} {
+		    if { $GMFtDial($x) } { lappend res $x }
+		}
+		break
+	    }
+	}
+    }
+    DestroyRGrabs $w $grabs
+    destroy $w
+    return $res
+}
+
 ### utilities for dealing with parameters in a dialog
 
 proc GMSetupParams {w vars descs} {
     # set-up widgets for setting parameters in a dialog
     #  $w is window parent
     #  $vars is list of (global) vars to set; they must have a value
-    #    except those associated to entries which will be initialized to ""
+    #    except those associated to entries which will be initialised to ""
+    #    and to menubuttons that if undefined will be initialised to "";
+    #    array elements may also be given instead of normal variables but
+    #    the indices must be alphanumeric
     #  $descs is associated list of value descriptions as:
     #      @TEXT   checkbutton with label TEXT, values 0 1
+    #      =@TEXT  non-echo entry with label TEXT
     #      =TEXT   entry with label TEXT
     #      !TEXT=MENUPROC/ARGS menubutton with label TEXT and menu filled by
-    #         proc MENUPROC; the arguments to the call are:
+    #         proc MENUPROC; the arguments to the MENUPROC call are:
     #                - the menu window
     #                - the command to be associated with final entries, whose
     #                arguments are the selected value and the menu window
     #                - the elements of the list ARGS
-    #      +TEXT/LIST radiobutton with possible values in LIST and label TEXT
-    #      /TEXT|LIST radiobutton with possible values in LIST and label TEXT
+    #      |TEXT/LIST label TEXT and menubutton with text-variable for values
+    #         in LIST
+    #      +TEXT/LIST radiobuttons with possible values in LIST, label TEXT
+    #      /TEXT|LIST radiobuttons with possible values in LIST, label TEXT
+    #      ~TEXT/LIST radiobuttons with possible values in LIST but their
+    #         names are in the array TXT, label TEXT
     #      LIST    radiobutton with possible values in LIST
     # LISTs above cannot have repeated elements
     # return pair with flag set if there are menubuttons, and list of entries,
-    #  each as a pair: path from $w to entry and name of global variable to
-    #  set; the list can be processed by proc GMUseEntries
-    global COLOUR
+    #  each as a triple, usually with path from $w to entry, the name of
+    #  global (array or normal) variable to be used in "global" and complete
+    #  name of variable to be used in "set"; for non-echo entries the
+    #  path is prefixed by a "@"; the list can be processed by proc GMUseEntries
+    global COLOUR TXT NEEntry
 
     set i 0 ; set es "" ; set menus 0
     foreach v $vars os $descs {
-	global $v
+	if { [regexp {^([^(]+)[(]([^)]+)[)]$} $v x vname el] } {
+	    set vid "${vname}___ARR_$el"
+	} else { set vid $v ; set vname $v }
+	global $vname
 	frame $w.f$i
 	switch -glob -- $os {
 	    @* {
-		set os [string range $os 1 end]
-		checkbutton $w.f$i.c$v -text $os -variable $v \
-		   -anchor w -onvalue 1 -offvalue 0 -selectcolor $COLOUR(check)
-		pack $w.f$i.c$v
+		set os [string replace $os 0 0]
+		set cb $w.f$i.c$vid
+		checkbutton $cb -text $os -variable $v -anchor w \
+		    -onvalue 1 -offvalue 0 -selectcolor $COLOUR(check)
+		if { [set $v] } {
+		    $cb select
+		} else { $cb deselect }
+		pack $cb
 	    }
 	    =* {
-		set os [string range $os 1 end]
-		label $w.f$i.l$v -text $os
-		entry $w.f$i.e$v -width 30
+		if { [string index $os 1] == "@" } {
+		    set z 1
+		} else { set z 0 }
+		set os [string replace $os 0 $z]
+		set wl [label $w.f$i.l$vid -text $os]
+		set ppath f$i.e$vid
+		set we [entry $w.f$i.e$vid -width 30]
+		TextBindings $we
+		if { $z } {
+		    set NEEntry($we) ""
+		    bind $we <Delete> "GMNEEntry $we _ BackSpace ; break"
+		    bind $we <Any-Key> "GMNEEntry $we %A %K ; break"
+		    set ppath "@$ppath"
+		}
 		if { [catch {set $v}] } {
 		    set $v ""
-		} else { $w.f$i.e$v insert 0 [set $v] }
-		TextBindings $w.f$i.e$v
-		pack $w.f$i.l$v $w.f$i.e$v -side left
-		lappend es "f$i.e$v $v"
+		} elseif { $z == 0 } { $we insert 0 [set $v] }
+		pack $wl $we -side left
+		lappend es [list $ppath $vname $v]
 	    }
 	    !* {
 		set menus 1
-		regexp {^!(.+)=(.+)/(.*)$} $os m lab menuproc mpargs
-		set mb $w.f$i.mb$v
+		if { ! [regexp {^!([^=]+)=([^/]+)/(.*)$} $os \
+			    m lab menuproc mpargs] } {
+		    BUG Bad argument to GMSetupParams !
+		}
+		set mb $w.f$i.mb$vid
 		menubutton $mb -text $lab -relief raised \
 		    -direction below -menu $mb.m
 		menu $mb.m
@@ -963,35 +1151,60 @@ proc GMSetupParams {w vars descs} {
 		if { [catch {set $v}] } {
 		    set $v ""
 		}
-		label $w.f$i.l$v -textvariable $v
-		pack $mb $w.f$i.l$v -side left
+		set wl [label $w.f$i.l$vid -textvariable $v]
+		pack $mb $wl -side left
 	    }
-	    +* -  /* {
-		if { ! [regexp {^\+(.+)/(.+)$} $os m lab lst] && \
-			 ! [regexp {^/(.+)\|(.+)$} $os m lab lst] } {
-		    BUG Bad argument to GMSetuParams
+	    |* {
+		set menus 1
+		if { ! [regexp {^[|]([^/]+)/(.*)$} $os \
+			    m lab lst] } {
+		    BUG Bad argument to GMSetupParams |
+		}
+		set wl [label $w.f$i.t$vid -text $lab -width 16]
+		set mb $w.f$i.mb$vid
+		menubutton $mb -textvariable $v -relief raised \
+		    -direction below -menu $mb.m
+		menu $mb.m
+		foreach x $lst {
+		    $mb.m add command -label $x -command "set $v $x"
+		}
+		pack $wl $mb -side left
+	    }
+	    +* -  /* -  ~* {
+		set labval [string first "~" $os]
+		if { ! [regexp {^.([^/]+)/(.+)$} $os m lab lst] } {
+		    BUG Bad argument to GMSetupParams +/~
 		    continue
 		}
-		label $w.f$i.l$v -text $lab
-		pack $w.f$i.l$v -side left
+		
+		pack [label $w.f$i.l$vid -text $lab] -side left
 		set k 0
+		set wrb $w.f$i.r_${vid}_0
 		foreach o $lst {
-		    radiobutton $w.f$i.r$k -text $o -variable $v \
-			    -value $o -anchor w -selectcolor $COLOUR(check)
-		    pack $w.f$i.r$k -side left -padx 2
+		    if { $labval } {
+			set lv $o
+		    } else { set lv $TXT($o) }
+		    set rb $w.f$i.r_${vid}_$k
+		    radiobutton $rb -text $lv -variable $v \
+			-value $o -anchor w -selectcolor $COLOUR(check)
+		    pack $rb -side left -padx 2
+		    if { [set $v] == $o } { set wrb $rb }
 		    incr k
 		}
-		$w.f$i.r0 invoke
+		$wrb invoke
 	    }
 	    default {
 		set k 0
+		set wrb $w.f$i.rd_${vid}_0
 		foreach o $os {
-		    radiobutton $w.f$i.rdef$k -text $o -variable $v \
-			    -value $o -anchor w -selectcolor $COLOUR(check)
-		    pack $w.f$i.rdef$k -side left -padx 2
+		    set rb $w.f$i.rd_${vid}_$k
+		    radiobutton $rb -text $o -variable $v \
+			-value $o -anchor w -selectcolor $COLOUR(check)
+		    pack $rb -side left -padx 2
+		    if { [set $v] == $o } { set wrb $rb }
 		    incr k
 		}
-		$w.f$i.rdef0 invoke
+		$wrb invoke
 	    }
 	}
 	pack $w.f$i -side top -fill x -expand 1
@@ -1000,21 +1213,48 @@ proc GMSetupParams {w vars descs} {
     return [list $menus $es]
 }
 
+proc GMNEEntry {e char ksym} {
+    # keep track of characters typed in a non-echo entry $e
+    # current contents are kept on global NEEntry($e) that should be unset
+    #  after use
+    global NEEntry PASSWDECHO
+
+    if { $PASSWDECHO == "none" } {
+	echo 0
+	$e delete 0 end
+    } else { set echo 1 }
+    if { $ksym == "BackSpace" } {
+	set NEEntry($e) [string replace $NEEntry($e) end end]
+	if { $echo } { $e delete 0 }
+	return
+    }
+    if { $ksym == $char || $ksym == "??" || [regexp {^[a-z]} $ksym] } {
+	append NEEntry($e) $char
+	if { $echo } { $e insert end $PASSWDECHO }
+    }
+    return
+}
+
 proc GMChangeParam {val varmenu args} {
     # parameter value changed by a selection in a menu
-    #  $varmenu is either the menu path assumed to have a single occurrence of
-    #   .mbVARNAME. where VARNAME is the name of the global variable to set,
-    #   or of the form =VARNAME
+    #  $varmenu is either the menu path assumed to have a single occurrence
+    #   of .mbVARID. or has the form =VARID where VARID either is the name
+    #   of the global simple variable to set, or has is the string
+    #   concatenation of a global array identifier, "___ARR_" and
+    #   an array index
     #  $args may be TXT to force value to be $TXT($val)
     global TXT
 
     if { ! [regexp {^=(.+)$} $varmenu x v] } {
-	regexp {\.mb(.+)\.} $varmenu m v
+	regexp {\.mb([^.]+)\.} $varmenu x v
     }
+    if { [regexp {^(.+)___ARR_(.+)$} $v x v ix] } {
+	global $v
+	append v "(" $ix ")"
+    } else { global $v }
     if { $args == "TXT" } {
 	set val $TXT($val)
     }
-    global $v
     set $v $val
     return
 }
@@ -1022,13 +1262,22 @@ proc GMChangeParam {val varmenu args} {
 proc GMUseEntries {w es} {
     # set global variables according to entries set-up by proc GMSetupParams
     #  $w is window parent
-    #  $es is list of pairs with path from $w to entry and
-    #   name of global variable to set
+    #  $es is list of triples usually with path from $w to entry,
+    #   name of global (array or normal) variable to be used in "global" and
+    #   complete name of variable to be used in "set"; for non-echo entries
+    #   the path is prefixed with a "@"
+    # current contents of non-echo entries are kept on global array NEEntry
+    #  (see proc GMNEEntry) and corresponding elements are unset here
+    global NEEntry
 
     foreach e $es {
-	set v [lindex $e 1]
-	global $v
-	set $v [$w.[lindex $e 0] get]
+	global [lindex $e 1]
+	if { [string index [set ppath [lindex $e 0]] 0] == "@" } {
+	    set ppath $w.[string replace $ppath 0 0]
+	    set v $NEEntry($ppath)
+	    unset NEEntry($ppath)
+	} else { set v [$w.$ppath get] }
+	set [lindex $e 2] $v
     }
     return
 }
