@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: geod.tcl
-#  Last change:  15 September 2008
+#  Last change:  5 October 2009
 #
 
 ## Most of the geodetic information herein taken or adopted from
@@ -101,16 +101,12 @@ proc DatumWithRefId {n} {
 ###### known datums
      # when changing this list make sure you update the definitions below
 
-proc FillDatumMenu {menu commdargs args} {
-    # fill menu with known datum names
-    # see proc FillMenu (utils.tcl) for the details on the arguments
-    #  $args not used
-    global TXT UDatums
+## description of predefined datum menu
 
-    set descr \
-      [list "WGS 84" "WGS 72" \
-	--- \
-	@ [list Europe \
+set PREDEFDATUMDESCR \
+    [list "WGS 84" "WGS 72" \
+	 --- \
+	 @ [list Europe \
                 Austrian "Austrian (MGI)" "CH-1903" "Datum 73" \
 	        "Deutsches Hauptdreiecksnetz" \
 		"Estonia Coord System 1937" "ED73" \
@@ -259,9 +255,20 @@ proc FillDatumMenu {menu commdargs args} {
 		"Montserrat Island Astro 1958" \
 		"Pitcairn Astro 1967" "Qatar National" "Santo (DOS)" \
 		"Selvagem Grande 1938" "Timbalai 1948" "Viti Levu 1916" \
-		"Wake Island Astro 1952" "Wake-Eniwetok `60"]]
-    if { "$UDatums" != "" } {
-	set ud [linsert $UDatums 0 "$TXT(userdefs)..."]
+		"Wake Island Astro 1952" "Wake-Eniwetok `60"]
+     ]
+
+proc FillDatumMenu {menu commdargs args} {
+    # fill menu with known datum names
+    # see proc FillMenu (utils.tcl) for the details on the arguments
+    #  $args not used
+    global TXT DefSpecs PREDEFDATUMDESCR
+    global $DefSpecs(datum,ulist)
+
+    set descr $PREDEFDATUMDESCR
+    set ulist [set $DefSpecs(datum,ulist)]
+    if { $ulist != "" } {
+	set ud [linsert $ulist 0 "$TXT(userdefs)..."]
 	set descr [linsert $descr 0 @ $ud ---]
     }
     FillMenu $menu $commdargs $descr
@@ -1347,12 +1354,9 @@ array set GDATUM {
 ###### known ellipsoids
      # when changing this list make sure you update the definitions below
 
-proc FillEllipsoidMenu {menu commdargs} {
-    # fill menu with known ellipsoid names
-    # see proc FillMenu (utils.tcl) for the details on the arguments
-    global TXT UEllipsoids
+## description of predefined ellipsoid menu
 
-    set descr \
+set PREDEFELLIPSOIDDESCR \
       [list \
          @ [list Airy \
               {Airy 1830} {Modified Airy}] \
@@ -1382,13 +1386,6 @@ proc FillEllipsoidMenu {menu commdargs} {
          @ [list WGS \
               {WGS 60} {WGS 66} {WGS 72} {WGS 84}] \
          Walbeck]
-    if { "$UEllipsoids" != "" } {
-	set ud [linsert $UEllipsoids 0 "$TXT(userdefs)..."]
-	set descr [linsert $descr 0 @ $ud ---]
-    }
-    FillMenu $menu $commdargs $descr
-    return
-}
 
 ## ellipsoid definitions
 # indexed by name
