@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: know.tcl
-#  Last change:  3 September 2008
+#  Last change:  27 December 2009
 #
 # Includes contributions by Brian Baulch (baulchb_AT_onthenet.com.au)
 #  marked "BSB contribution"
@@ -96,7 +96,7 @@ proc ItemData {wh index} {
     # find data for item with given index
     #  $wh in $TYPES or LAP
     # return list of values in the order given by $Storage($wh)
-    # see GMStart (main.tcl) for the description of data arrays
+    # see GMStart (setup.tcl) for the description of data arrays
     global Storage
 
     set l ""
@@ -115,7 +115,7 @@ proc FormData {wh names vals} {
     # return list of values in the order given by $DataIndex($wh)
     #  (if $wh in $TYPES or LAP that is the order of $Storage($wh)) using
     #  default values for those not given in $vals
-    # see GMStart (main.tcl) for the description of data arrays
+    # see GMStart (setup.tcl) for the description of data arrays
     global DataDefault DataIndex
 
     set l $DataDefault($wh)
@@ -129,7 +129,7 @@ proc FormData {wh names vals} {
 proc SetItem {wh index data} {
     # set data for item with given index
     #  $wh in $TYPES or LAP
-    # see GMStart (main.tcl) for description of data arrays
+    # see GMStart (setup.tcl) for description of data arrays
     global Storage IndexOf
 
     set ids [lindex $Storage($wh) 0]
@@ -152,7 +152,7 @@ proc SetItem {wh index data} {
 proc UnsetItem {wh index} {
     # destroy data for item with given index
     #  $wh in $TYPES or LAP
-    # see GMStart (main.tcl) for description of data arrays
+    # see GMStart (setup.tcl) for description of data arrays
     global Storage IndexOf
 
     set ids [lindex $Storage($wh) 0]
@@ -170,7 +170,7 @@ proc UnsetItem {wh index} {
 proc UnsetSeveral {wh ixs} {
     # destroy data for items with given indices
     #  $wh in $TYPES or LAP
-    # see GMStart (main.tcl) for description of data arrays
+    # see GMStart (setup.tcl) for description of data arrays
     global Storage IndexOf
 
     set ids [lindex $Storage($wh) 0]
@@ -192,7 +192,7 @@ proc UnsetSeveral {wh ixs} {
 proc UnsetAll {wh} {
     # destroy data for all items with given type
     #  $wh in $TYPES or LAP
-    # see GMStart (main.tcl) for description of data arrays
+    # see GMStart (setup.tcl) for description of data arrays
     global Storage IndexOf
 
     foreach n [array names IndexOf $wh,*] {
@@ -385,7 +385,7 @@ proc SetWPRoute {rt wps} {
     foreach wp $wps {
 	if { [set ix [IndexNamed WP $wp]] != -1 } {
 	    if { [lsearch -exact $WPRoute($ix) $rt] == -1 } {
-		set WPRoute($ix) [linsert $WPRoute($ix) 0 $rt]
+		lappend WPRoute($ix) $rt
 		set WPRoute($ix) [lsort $WPRoute($ix)]
 	    }
 	}
@@ -394,8 +394,8 @@ proc SetWPRoute {rt wps} {
 }
 
 proc UnsetWPRoute {rt wps} {
-    # delete RT name $rt in list of RTs of each known WP
-    #  whose name belongs to $wps
+    # delete RT name $rt in list of RTs of each given WP
+    #  that is defined
     global WPRoute
 
     foreach wp $wps {
@@ -410,6 +410,25 @@ proc UnsetWPRoute {rt wps} {
     return
 }
 
+proc RenameWPRoute {oldname newname wps} {
+    # change RT name in list of RTs of each given WP
+    #  that is defined or add new name if old not found
+    global WPRoute
+
+    foreach wp $wps {
+	set ix [IndexNamed WP $wp]
+	if { $ix != -1 } {
+	    set wi [lsearch -exact $WPRoute($ix) $oldname]
+	    if { $wi != -1 } {
+		set WPRoute($ix) [lreplace $WPRoute($ix) $wi $wi \
+				      $newname]
+	    } else { lappend $WPRoute($ix) $newname }
+	    set WPRoute($ix) [lsort $WPRoute($ix)]
+	}
+    }
+    return
+}
+
 proc DateCommt {date} {
     # create comment from date
     global COMMENTLENGTH NOLOWERCASE
@@ -473,101 +492,122 @@ proc GRsElsCollect {ixs rec wh} {
     return
 }
 
+proc GRWPNames {conts} {
+    # find names of WPs in given GR contents
+    # return pair with index of WP-pair entry in $conts, followed by list
+    #  of names, on failure the index is meaningless and the list is empty
+
+    set names {} ; set ics 0
+    foreach p $conts {
+	if { [lindex $p 0] == "WP" } {
+	    set names [lindex $p 1]
+	    break
+	}
+	incr ics
+    }
+    return [list $ics $names]    
+}
+
 ## renaming items
 
 proc InitWPRenaming {} {
     # this proc must be called before any input operation!
     # initialize variables before an input operation (get, load, import)
     #  for use with procs AskForName and ReplaceWPName
-    global ReplacedNames ReplacedWPs GenerateAll ReplRTs ReplGRs
+    # returns 0 if another renaming operation is under way
+    global ReplNames MESS
 
-    set ReplacedNames "" ; set ReplacedWPs ""
-    set GenerateAll 0
-    set ReplRTs "" ; set ReplGRs ""
-    return
+    if { $ReplNames(busy) } {
+	GMMessage $MESS(busytrylater)
+	return 0
+    }
+    array set ReplNames {busy 1 old {} new {} wps {} grs {} how ask}
+    return 1
 }
 
 proc EndWPRenaming {} {
     # this proc must be called after any input operation that stored data!
-    # build a group with renamed WPs and RTs or GRs that have ambiguous
-    #  WPs, after an input operation (get, load, import)
-    global ReplacedNames ReplacedWPs ReplRTs ReplGRs
+    # build a group with renamed WPs as well as GRs in which they occur
+    #  after an input operation (get, load, import)
+    global ReplNames
 
-    if { $ReplacedNames == "" && $ReplacedWPs == "" } { return }
-    set nwps ""
-    foreach m [concat $ReplacedNames $ReplacedWPs] {
-	lappend nwps [lindex $m 1]
-    }
-    set lp [list [list WP [lsort -dictionary $nwps]]]
-    foreach wh "RT GR" {
-	if { [set lns [set Repl${wh}s]] != "" } {
-	    set ns ""
-	    foreach n $lns {
+    if { $ReplNames(old) != {} || $ReplNames(wps) != {} } {
+	set nwps $ReplNames(new)
+	foreach m $ReplNames(wps) { lappend nwps [lindex $m 1] }
+	set lp [list [list WP [lsort -dictionary $nwps]]]
+	if { $ReplNames(grs) != {} } {
+	    set ns {}
+	    foreach n $ReplNames(grs) {
 		if { [lsearch -exact $ns $n] == -1 && \
-			[IndexNamed $wh $n] != -1 } {
+			 [IndexNamed GR $n] != -1 } {
 		    lappend ns $n
 		}
 	    }
-	    lappend lp [list $wh [lsort -dictionary $ns]]
+	    lappend lp [list GR [lsort -dictionary $ns]]
 	}
+	CreateGRFor renres "" $lp
     }
-    CreateGRFor renres "" $lp
+    set ReplNames(busy) 0
     return
 }
 
-proc GetReplacedName {name wh id} {
-    # get replacement for an isolated WP name belonging to item $id
-    #  of type $wh (in {RT, GR})
+proc GetReplNameInGR {name id} {
+    # get replacement for a WP name appearing in a GR
+    #  $id is the GR name
     # return $name if there is no replacement, otherwise the one that
     #  was done last
-    global ReplacedNames ReplacedWPs ReplRTs ReplGRs
+    global ReplNames
 
     set chg 0
-    foreach p $ReplacedNames {
-	if { [lindex $p 0] == $name } {
-	    set name [lindex $p 1] ; incr chg
-	    break
-	}
+    if { [set ix [lsearch -exact $ReplNames(old) $name]] != -1 } {
+	set name [lindex $ReplNames(new) $ix] ; incr chg
     }
-    foreach t $ReplacedWPs {
+    foreach t $ReplNames(wps) {
 	if { [lindex $t 0] == $name } {
 	    set name [lindex $t 1] ; incr chg
 	    break
 	}
     }
-    if { $chg && [lindex [set Repl${wh}s] 0] != $id } {
-	set Repl${wh}s [linsert [set Repl${wh}s] 0 $id]
+    if { $chg && [lindex $ReplNames(grs) 0] != $id } {
+	set ReplNames(grs) [linsert $ReplNames(grs) 0 $id]
     }
     return $name
-}    
+}
 
 proc AskForName {name} {
-    # ask for replacement of WP $name which is not valid
-    #  but check first that there is not a replacement in list $ReplacedNames
-    # on success add pair $name and new name to ReplacedNames
-    # callers of this proc should initialize ReplacedNames to empty and
-    #  GenerateAll to 0 before first call (see proc InitWPRenaming)
-    # names already in use are not accepted!
+    # obtain a replacement for a WP $name which is not valid by one of
+    #  - checking if it was already replaced
+    #  - letting the user write the new name
+    #  - applying a renaming method selected by the user
+    #  - generating an automatic replacement
+    # proc InitWPRenaming must be called before the first call to this proc
+    #  and proc EndWPRenaming must be called after the renaming operation
+    #  is finished
     # create modal dialog for displaying message
     #  buttons: OK, Cancel
     #  binding: return to accept
+    # return empty string on cancel
     global MYGPS RECNAMECHARS NAMELENGTH GMResAsk COLOUR EPOSX EPOSY MESS TXT \
-	    ReplacedNames GenerateAll CMDLINE
+	    ReplNames CMDLINE
 
-    foreach p $ReplacedNames {
-	if { $name == [lindex $p 0] } { return [lindex $p 1] }
+    if { [set ix [lsearch -exact $ReplNames(old) $name]] != -1 } {
+	return [lindex $ReplNames(new) $ix]
     }
-    if { $GenerateAll || $CMDLINE } {
-	set nn [NewName WP $name]
-	lappend ReplacedNames [list $name $nn]
+    if { $ReplNames(how) == "methall" } {
+	set nn [RenameMethApplyTo $name $ReplNames(method) Ignore]
+	lappend ReplNames(old) $name
+	lappend ReplNames(new) $nn
 	return $nn
     }
-    toplevel .askname
-    wm protocol .askname WM_DELETE_WINDOW { set GMResAsk cnc }
-    wm title .askname "$TXT(change)/GPS Manager"
-    wm transient .askname .
-    wm geometry .askname +$EPOSX+$EPOSY
-    bind .askname <Key-Return> { set GMResAsk ok }
+    if { $ReplNames(how) == "genall" || $CMDLINE } {
+	set nn [NewName WP $name]
+	lappend ReplNames(old) $name
+	lappend ReplNames(new) $nn
+	return $nn
+    }
+    GMToplevel .askname change +$EPOSX+$EPOSY . \
+        {WM_DELETE_WINDOW {set GMResAsk cnc}} \
+        [list <Key-Return> {set GMResAsk ok}]
 
     frame .askname.fr -relief flat -borderwidth 5 -bg $COLOUR(confbg)
     label .askname.fr.title -text "!!!" -relief sunken
@@ -576,17 +616,33 @@ proc AskForName {name} {
 	             $RECNAMECHARS($MYGPS,mess)]
     entry .askname.fr.name -width $NAMELENGTH
     TextBindings .askname.fr.name
-    frame .askname.fr.bs -relief flat -borderwidth 0
-    button .askname.fr.bs.ok -text Ok -command { set GMResAsk ok }
-    button .askname.fr.bs.gen -text $TXT(generate) \
-	    -command { set GMResAsk gen }
-    button .askname.fr.bs.genall -text $TXT(generateall) \
-	    -command { set GenerateAll 1 ; set GMResAsk gen }
-    button .askname.fr.bs.cancel -text $TXT(cancel) \
+
+    set fbs .askname.fr.bs
+    frame $fbs -relief flat -borderwidth 0
+    button $fbs.ok -text $TXT(ok) -command { set GMResAsk ok }
+    foreach x {gen meth} t {generate renamethod} { 
+	menubutton $fbs.$x -text $TXT($t) -relief raised -menu $fbs.$x.m
+	menu $fbs.$x.m
+    }
+    $fbs.gen.m add command -label $TXT(forthisWP) \
+	-command { set ReplNames(how) ask ; set GMResAsk gen }
+    $fbs.gen.m add command -label $TXT(forall) \
+	-command { set ReplNames(how) genall ; set GMResAsk gen }
+    # 2 menus are needed as not all platforms support cascade commands
+    foreach x {ask methall} t {forthisWP forall} {
+	set mx $fbs.meth.m.$x
+	$fbs.meth.m add cascade -label $TXT($t) -menu $mx
+	menu $mx
+	menu $mx.m -postcommand \
+	    [list FillDefsMenu renamethod $mx.m [list AskForNameMethod $x]]
+	$mx add cascade -label $TXT(use) -menu $mx.m
+	$mx add command -label $TXT(define) \
+	    -command [list AskForNameMethod define-$x {}]
+    }
+    button $fbs.cancel -text $TXT(cancel) \
 	    -command { set GMResAsk cnc }
-    pack .askname.fr.bs.ok .askname.fr.bs.gen .askname.fr.bs.genall \
-	    .askname.fr.bs.cancel -side left -pady 5
-    pack .askname.fr.title .askname.fr.text .askname.fr.name .askname.fr.bs \
+    pack $fbs.ok $fbs.gen $fbs.meth $fbs.cancel -side left -pady 5
+    pack .askname.fr.title .askname.fr.text .askname.fr.name $fbs \
 	    -side top -pady 5
     pack .askname.fr -side top
     update idletasks
@@ -598,32 +654,61 @@ proc AskForName {name} {
 	switch $GMResAsk {
 	    ""  { }
 	    ok {
-		set nn [string trim [.askname.fr.name get]]
-		if { [CheckName Ignore $nn] } {
-		    if { [IndexNamed WP $nn] != -1 } {
+		set res [string trim [.askname.fr.name get]]
+		if { [CheckName Ignore $res] } {
+		    if { [lsearch -exact $ReplNames(new) $res] != -1 || \
+			     [IndexNamed WP $res] != -1 } {
 			GMMessage $MESS(idinuse) ; continue
 		    }
-		    lappend ReplacedNames [list $name $nn]
-		    set res $nn
 		    break
 		}
 		bell
 	    }
 	    gen {
-		set nn [NewName WP $name]
-		lappend ReplacedNames [list $name $nn]
-		set res $nn
+		set res [NewName WP $name]
 		break
 	    }
+	    meth {
+		if { $ReplNames(method) == "" } {
+		    set ReplNames(how) ask
+		    continue
+		}
+		set res [RenameMethApplyTo $name $ReplNames(method) Ignore]
+		break		    
+	    }
 	    cnc {
 		set res "" ; break
 	    }
 	}
     }
+    if { $res != "" } {
+	lappend ReplNames(old) $name
+	lappend ReplNames(new) $res
+    }
     DestroyRGrabs .askname $gs
     update idletasks
     return $res
+}
 
+proc AskForNameMethod {how method args} {
+    # a WP renaming method is to be applied
+    #  $how in {ask, methall, define-ask, define-methall} indicates
+    #   whether the choice is for this or all WPs and if the method is to
+    #   be defined
+    #  $method is the name of renaming method to use or empty meaning,
+    #   unless the method is to be defined, that operation is to be cancelled
+    #  $args not in use but is needed because of proc FillMenu
+    # this proc only changes the global variables that force
+    #  proc AskForName to do the intended actions
+    global ReplNames GMResAsk
+
+    if { [regsub {^define-} $how "" how] } {
+	set method [Define renamethod]
+    }
+    set ReplNames(how) $how ; set ReplNames(method) $method
+    # must be the last one
+    set GMResAsk meth
+    return
 }
 
 proc SamePosnDat {posndat1 posndat2} {
@@ -644,20 +729,20 @@ proc ReplaceWPName {name posndat} {
     #  $posndat is list with lat, long and datum defining the WP
     #    position (possibly not in the WP datum)
     # use record of previous replacements
-    #  $ReplacedWPs, a list of triples with old name, new name and
+    #  $ReplNames(wps), a list of triples with old name, new name and
     #    position+datum (as $posndat)
     # this list must be initialized when starting a reading operation (get,
     #  load, import) (see proc InitWPRenaming), and is kept as a stack
     #  with the last replacement done as its head
-    global ReplacedWPs
+    global ReplNames
 
-    foreach t $ReplacedWPs {
+    foreach t $ReplNames(wps) {
 	if { [lindex $t 0] == $name && [SamePosnDat $posndat [lindex $t 2]] } {
 	    return [lindex $t 1]
 	}
     }
     set n [NewName WP $name]
-    set ReplacedWPs [linsert $ReplacedWPs 0 [list $name $n $posndat]]
+    set ReplNames(wps) [linsert $ReplNames(wps) 0 [list $name $n $posndat]]
     return $n
 }
 
@@ -696,6 +781,133 @@ proc AddOldNameToObs {wh data name} {
     return [lreplace $data $in $in [AddToNB $nb "$TXT(oname): $name"]]
 }
 
+proc WPChangeNames {methname args} {
+    # change names of items of type $wh (not LAP)
+    #   $methname is the name of renaming method to use or empty for cancel
+    #   $args not in use but is needed because of proc FillMenu
+    # select the items then rename them
+    global MESS TXT NAMELENGTH RENMETHS
+
+    if { $methname == "" || \
+	     [set ixs [ChooseItems WP many]] == "" } { return }
+    RenameInternalWPs $methname [Apply $ixs NameOf WP]
+    return
+}
+
+proc GMGRRenameWPs {w methname args} {
+    # change names of selected WPs in group window $w
+    #   $methname is the name of renaming method to use or empty for cancel
+    #   $args not in use but is needed because of proc FillMenu
+    # by construction WP names in a GR are all different
+    global TXT NAMELENGTH
+
+    if { $methname == "" } { return }
+    if { [set names [GMGRCollectWPNames $w]] != {} && \
+	     [set names [GMChooseFrom many "$TXT(select) $TXT(nameWP)" \
+			     $NAMELENGTH $names $names]] != {} } {
+	RenameInternalWPs $methname $names
+    }
+    return
+}
+
+proc RenameInternalWPs {methname names} {
+    # apply a renaming method to WPs in the data-base or referred to
+    #  in a GR
+    #  $names is a list of the WP names
+    #  $methname is method name
+    # start/end a renaming operation by calling procs InitWPRenaming
+    #  and EndWPRenaming, ensuring no other renaming takes place
+    # use proc CheckName to verify the result of the method and
+    #  if the result is not acceptable use proc NewName to get a
+    #  suitable one
+    # update data-base, map, and edit/show windows
+    global WPName WPRoute WPObs WPDispl RTWPoints GRConts IndexOf \
+	ReplNames TXT
+
+    set descmethod [lindex [GetDefFields renamethod $methname method] 0]
+    if { $names == {} || \
+	     [set method [lindex $descmethod 1]]  == {} || \
+	     [InitWPRenaming] == 0 } {
+	return
+    }
+    set replold {} ; set replnew {}
+    foreach name $names {
+	if { [set nname [RenameMethApply $method $name \
+			     $replnew Ignore]]  == "" || \
+		 ! [CheckName Ignore $nname] } {
+	    set nname [NewName WP $name]
+	}
+	lappend replold $name
+	lappend replnew $nname
+	if { [set ix [IndexNamed WP $name]] != -1 } {
+	    # update the data-base
+	    unset IndexOf(WP,$name)
+	    set IndexOf(WP,$nname) $ix
+	    set WPName($ix) $nname
+	    set WPObs($ix) [AddToNB $WPObs($ix) "$TXT(oname): $name"]
+
+	    # update the items list and edit/show window
+	    ListDelete WP $ix ; ListAdd WP $ix
+	    UpdateItemWindows WP $ix
+
+	    # update map
+	    if { $WPDispl($ix) } {
+		MoveOnMap WP $ix $name 1 $nname
+	    }
+ 	}
+    }
+    # update RTs containing renamed WPs
+    set rtixs {}
+    foreach ixrt [array names RTWPoints] {
+	foreach "chg RTWPoints($ixrt)" \
+		    [ListReplace $RTWPoints($ixrt) $replold $replnew] {}
+	if { $chg } { lappend rtixs $ixrt }
+    }	
+    UpdateWPsInWindows RT $rtixs $replold $replnew
+
+    # update GRs containing renamed WPs
+    set grixs {}
+    foreach grix [array names GRConts] {
+	foreach {ics gwps} [GRWPNames $GRConts($grix)] {}
+	if { $gwps != {} } {
+	    foreach {chg gwps} [ListReplace $gwps $replold $replnew] {}
+	    if { $chg } {
+		set gwps [lsort -dictionary $gwps]
+		set GRConts($grix) [lreplace $GRConts($grix) $ics $ics \
+					[list WP $gwps]]
+		lappend grixs $grix
+	    }
+	}
+    }
+    UpdateWPsInWindows GR $grixs $replold $replnew
+
+    set ReplNames(old) $replold
+    set ReplNames(new) $replnew
+    EndWPRenaming
+    return
+}
+
+proc RenameMethApplyTo {name methname errproc} {
+    # apply a renaming method to WP with given $name
+    #  $methname is method name
+    # to be used in the context of a renaming operation started by
+    #  calling proc InitWPRenaming and ended by calling proc EndWPRenaming
+    # use proc CheckName to verify the result of the method and
+    #  if the result is not acceptable use proc NewName to get a
+    #  suitable one
+    # return the new name
+    global ReplNames
+
+    set descmethod [lindex [GetDefFields renamethod $methname method] 0]
+    if { [set method [lindex $descmethod 1]]  == {} || \
+	     [set nname [RenameMethApply $method $name \
+			     $ReplNames(new) $errproc]] == "" || \
+	     ! [CheckName $errproc $nname] } {
+	return [NewName WP $name]
+    }
+    return $nname
+}
+
 ## storing data items just read in
 
 proc StoreWP {ix name data todispl} {
