@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  30 September 2008
+#  Last change:  22 December 2009
 # German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
 #  last input from him inserted: 31 January 2002
 #
 # Support by Sabine Broda (sbb@ncc.up.pt) since 2002
-#  last input from her inserted:  30 September 2008
+#  last input from her inserted:  22 December 2009
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
@@ -290,7 +290,6 @@ array set MESS {
     undefinedTR   "Unbekannter TR"
     emptymenu "Men hat keine Eintragung; fortsetzen?"
     cantwrtsymenu "Kann die nutzerdefinierte Symbolmen Datei nicht schreiben"
-    cantwrtmbaks "Kann die nutzerdefinierte Hintergrund-Datei nicht schreiben"
     abbrevhasspaces "Abkrzungen drfen keine Leerzeichen haben"
     getAL "Empfangen des Almanachs"
     needNpoints "Mindestens %s Punkten mu ausgewhlt werden!"
@@ -302,6 +301,18 @@ array set MESS {
     baudchgfailed "Baudratennderung ohne Erfolg"
     busytrylater "Andere Vorgnge in Bearbeitung; bitte spter versuchen!"
     obssplit "Teilungsergebnis von %s in der Gruppe mit Name \"%s\""
+    loginto "Login %s"
+    samelgth "Beide Zeichenketten mssen gleich lang sein"
+    rschkargs "Abrufen von regsub gibt Fehler; Argumente berprfen"
+    emptyrmeth "Umbenennungsmethode darf nicht leer sein"
+    cantwrtdefs "Kann Datei mit Benutzerdefinitionen nicht schreiben"
+    xcantbey "%s darf nicht %s sein"
+    mustselftfam "Eine Schriftart muss ausgewhlt sein"
+    badpluginwhere "Falsches plug-in \"wo\"-Argument; muss Liste von Tripeln sein"
+    badpluginparam "Falsche plug-in Parameter: Liste von NAME EXPR, NAME beginnt mit _"
+    badpluginparamexec "Wenn plug-in %s luft, falscher Parameter: %s"
+    pluginfailed "Plug-in %s missglckt mit Nachright: %s"
+    canwrtaux "Kann Hilfsdatei nicht schreiben"
 }
 
 
@@ -935,7 +946,6 @@ array set TXT {
     cwpsdef "Wieviele Kontroll WPe definieren"
     nextTP "Nchster TP"
     generate Erzeugen
-    generateall "Alle erzeugen"
     optSERIALBAUD "Baud Rate"
     optDEFTRTWIDTH "RT Liniendicke"
     optDEFTTRWIDTH "TR Liniendicke"
@@ -965,7 +975,6 @@ array set TXT {
     optMAPCOLOUR,trvwrninfo "Information (nav)"
     travel Reise
     notravel "Reise unterbrechen"
-    optTRAVELFONTSIZE "Schriftgre der Reisenanzeige"
     travdisplay "Anzeige konfigurieren"
     travchgdisplay "Zu Anzeige %s wechseln"
     travdsetup "Reisenanzeige konfigurieren"
@@ -1021,7 +1030,6 @@ array set TXT {
     warntrn "TRN (abs)>"
     warnvspeed "Vertikale Geschwindigkeit"
     warnxtk "XTK (abs)>"
-    fntsize "Schriftgre"
     trvhlpbox "Rechte Taste zur Wiederordnung von\nfolgenden Elementen benutzen"
     trvhlpbxs "Rechte Taste zur Wiederordnung von\nElementen der Liste benutzen"
     trvwarrv "Ankunft in %s!"
@@ -1044,14 +1052,12 @@ array set TXT {
     rthlpdsim "Zeigertasten: steuern, Geschwindigkeit ndern\nLeertaste: geradeaus"
     printopt "Druckoptionen"
     optPRINTCMD "Druckkommandos"
-    optMAPFONTSIZE "Kartenschriftgre"
     print Drucken
     prevctr "Vorheriger Mittelpunkt"
     PRJSOM "Swiss Oblique Mercator"
     PRJLV03 "Swiss LV03 Grid"
     PRJIcG "Iceland Grid"
     PRJRDG "The Netherlands Grid"
-    chgmfsize "Kartenschriftgre ndern"
     PRJBMN "sterreichischer Bundesmeldenetz"
     PRJCTR "Ital. techn. Regionalskarte"
     optDEFMAPPROJ "Kartenprojektion"
@@ -1197,9 +1203,7 @@ array set TXT {
     fromdef "von einer Definition"
     mbaktoload "Zugehriger Hintergrund"
     none "nichts"
-    opt_Fonts "Schriftgren"
-    optFONTSIZE "Standardschriftgre"
-    optFIXEDFONTSIZE "Monoschriftgre"
+    opt_Fonts "Schrift"
     optICONSIZE "Symbolgre"
     optTRNUMBERINTVL "Zeige TP Info auf der Karte alle"
     optTRINFO "zu zeigende TP Info"
@@ -1243,6 +1247,73 @@ array set TXT {
     bysel  "an ausgewhlten Punkten"
     byseg  "an Segmenten"
     openits "%s ffnen"
+    uname "Benutzername"
+    pword "Passwort"
+    remember "Merken"
+    wptotwitter "WP zu Twitter"
+    wptotwitternb "Position, Datum, Hhe, Name und Kommentar von WP zu Twitter mit Etikett #GPSMan #waypoint senden"
+    exportTFW "TFW-Datei exportieren"
+    nametfwfile "TFW-Datei"
+    PRJEOV  EOV
+    chgname "Name ndern"
+    clicktoedit "Zum Bearbeiten hier klicken"
+    renamethod "Umbenennungsmethode"
+    operators "Operatoren"
+    keep1st "Erstes Zeichen fixieren"
+    keep1st_hlp "Erstes Zeichen fixieren\nweitere Operatoren arbeiten mit den
+verbleibenden Zeichen"
+    reset "Reset"
+    reset_hlp "Mit Anfangsnamen neustarten, nderungen werden rckgngig gemacht"
+    case "Gro/Kleinschreibung"
+    case_hlp "Alle Buchstaben in Gro/Kleinschreibung"
+    maxlgth "Max Lnge"
+    maxlgth_hlp "Aktuelle Zeichen werden bis zur angegebenen Lnge gekrzt"
+    inslt "Links einfgen"
+    inslt_hlp "String wird vor dem aktuellen, linken Zeichen eingefgt"
+    insrt "Rechts einfgen"
+    insrt_hlp "String wird am Ende eingefgt"
+    replc "Austausch"
+    replc_hlp "Die Zeichen der ersten String werden durch die\njeweiligen Zeichen der zweiten ausgetauscht" 
+    delany "Alle lschen"
+    delany_hlp "Alle Zeichen in der String werden im Namen gelscht"
+    rsub "RegExp Substitution"
+    rsub_hlp "Regulren Ausdruck und Substitutionsspezifikation angeben\nweitere
+Hinweise in der Anweisungsanleitung"
+    accifnew "Annehmen falls neu"
+    accifnew_hlp "Ergebnis wird angenommen, falls es ein neuer Name ist"
+    guntilnew "Zahl anhngen bis neu"
+    guntilnew_hlp "Alle mglichen Zahlen ausprobieren, bis ein neuer Name gefunden ist"
+    ndigits "Anzahl von Stellen"
+    gennames "Namenerstellung..."
+    rentest_hlp "Aktuelle Methode an gegebenem Namen testen"
+    renmove_hlp "Rechten Knopf zum Zeilenordnung benutzen"
+    tolower "Kleinschreibung"
+    toupper "Groschreibung"
+    applyto "Anwenden auf"
+    forall "alle folgenden"
+    failed "missglckt"
+    selfont "Schrift whlen"
+    default "Vorgegeben"
+    size "Gre"
+    units "Einheiten"
+    points "Punkte"
+    pixels "Pixel"
+    weight "Strke"
+    normal "normal"
+    bold "bold"
+    slant "Neigung"
+    roman "roman"
+    italic "italic"
+    underline "Unterstrichen"	
+    overstrike "Durchgestrichen"
+    optDEFAULTFONT "Vorgegebene Schrift"
+    optFIXEDFONT "Monoschrift"
+    optMAPFONT "Kartenschrift"
+    optTRAVELFONT "Schrift der Reisenanzeige"
+    optPLOTFONT "Zeichnungsschrift"
+    plugin  "Plug-in"
+    unavailif  "Nicht verfgbar, falls"
+    tclcode "Tcl Code"
 }
 
     # the following definitions must be coherent with $TXT
