@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  15 September 2008
+#  Last change:  18 December 2009
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb _AT_ onthenet.com.au)
@@ -290,7 +290,6 @@ array set MESS {
     lapncnsdrd "LAP not considered"
     emptymenu "Empty menu; continue?"
     cantwrtsymenu "Cannot write symbol menu file"
-    cantwrtmbaks "Cannot write user map backgrounds file"
     abbrevhasspaces "Short name cannot have blanks"
     needNpoints "You must give at least %s points!"
     twotimeoffsets "Different time offsets in file"
@@ -301,6 +300,18 @@ array set MESS {
     busytrylater "Other operations under way; please try later"
     baudchgfailed "Could not change baud rate"
     obssplit "Results of splitting %s named \"%s\""
+    samelgth "The two strings must have the same number of characters"
+    rschkargs "Calling regsub gives an error; check the arguments"
+    emptyrmeth "Renaming method cannot be void"
+    cantwrtdefs "Cannot write file with user definitions"
+    xcantbey "%s cannot be %s"
+    mustselftfam "A font family must be selected"
+    badpluginwhere "Bad plug-in \"where\" argument; must be list of triples"
+    badpluginparam "Bad plug-in parameters: list of NAME EXPR, NAME starts with _"
+    badpluginparamexec "When running plug-in %s, bad parameter: %s"
+    pluginfailed "Plug-in %s failed with message: %s"
+    canwrtaux "Cannot write auxiliary file"
+    loginto "Login %s"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -512,10 +523,7 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation on map"
     optMAPCOLOUR,emptygrid  "Empty image"
     optMAPCOLOUR,fullgrid   "Existing image"
-    opt_Fonts "Font sizes"
-    optFONTSIZE "Default font size"
-    optFIXEDFONTSIZE "Fixed font size"
-    optMAPFONTSIZE "Map font size"
+    opt_Fonts "Fonts"
     optDEFTRTWIDTH "RT line width"
     optDEFTTRWIDTH "TR line width"
     optDEFTLNWIDTH "LN width"
@@ -556,7 +564,7 @@ array set TXT {
     group   Group
     element   Element
     insert   Insert
-    joinGR   "Join Group"
+    joinGR   "Add GR Els"
     TRtoRT   "Conversion from TR to RT"
     TRtoLN   "Conversion from TR to LN"
     TRtoTR   "TR simplification"
@@ -1060,7 +1068,6 @@ array set TXT {
     print Print
     prevctr "Previous centre"
     printopt "Print options"
-    chgmfsize "Change map font size"
     cwpsdef "Control WPs to define now"
     nextTP "Next TP"
     generate Generate
@@ -1086,7 +1093,6 @@ array set TXT {
     optMAPCOLOUR,trvwrnimportant "Important warning (nav)"
     optMAPCOLOUR,trvwrnnormal "Warning (nav)"
     optMAPCOLOUR,trvwrninfo "Information (nav)"
-    optTRAVELFONTSIZE "Travel display font size"
     travel Travel
     notravel "Stop travelling"
     travdisplay "Configure display"
@@ -1145,7 +1151,6 @@ array set TXT {
     warntrn "TRN (abs)>"
     warnvspeed "Vertical speed"
     warnxtk "XTK (abs)>"
-    fntsize "Font size"
     trvhlpbox "Use right-button to reorder elements below"
     trvhlpbxs "Use right-button to reorder list elements"
     trvwarrv "Arriving at %s!"
@@ -1322,6 +1327,70 @@ array set TXT {
     byseg  "by segments"
     openits "Open %s"
     PRJEOV  EOV
+    chgname "Change name"
+    clicktoedit "Click to edit"
+    renamethod "Renaming method"
+    operators "Operators"
+    keep1st "keep first char"
+    keep1st_hlp "Keep first char\nfurther operations act on remaining chars"
+    reset "reset"
+    reset_hlp "Restart with initial name undoing any previous changes"
+    case "change case"
+    case_hlp "All letters to upper/lower case"
+    maxlgth "max length"
+    maxlgth_hlp "Current chars trimmed to given number"
+    inslt "insert at left"
+    inslt_hlp "Given string to be inserted before current left char"
+    insrt "insert at right"
+    insrt_hlp "Given string to be inserted at the end"
+    replc "replace"
+    replc_hlp "Any char in the first string will be replaced by\nthe corresponding one in the second"
+    delany "delete any"
+    delany_hlp "All chars in the given string will be deleted from name"
+    rsub "re. substitution"
+    rsub_hlp "Give regular expression and substitution specification\nsee the manual for details"
+    accifnew "accept if new"
+    accifnew_hlp "Accept result if it is a new name"
+    guntilnew "append number until new"
+    guntilnew_hlp "Try all possible values of the number until a new name is found"
+    ndigits "Number of digits"
+    gennames "Generating names..."
+    rentest_hlp "Test present method on given name"
+    renmove_hlp "Use right-button to reorder lines"
+    tolower "to lower"
+    toupper "to upper"
+    applyto "Apply to"
+    forall "for all"
+    selfont "Selecting font"
+    default "Default"
+    size "Size"
+    units "Units"
+    points "points"
+    pixels "pixels"
+    weight "Weight"
+    normal "normal"
+    bold "bold"
+    slant   "Slant"
+    roman "roman"
+    italic "italic"
+    underline "Underline"
+    overstrike "Overstrike"
+    optDEFAULTFONT "Default font"
+    optFIXEDFONT "Fixed font"
+    optMAPFONT "Map font"
+    optTRAVELFONT "Travel display font"
+    optPLOTFONT "Plot/graph font"
+    failed "failed"
+    plugin  "Plug-in"
+    unavailif  "Unavailable if"
+    tclcode  "Tcl code"
+    uname "User name"
+    pword "Password"
+    remember "Remember"
+    wptotwitter "WP to Twitter"
+    wptotwitternb "Send WP position, datum, altitude, name and comment to Twitter with tags #GPSMan #waypoint"
+    exportTFW "Export TFW file"
+    nametfwfile "TFW file"
 }
 
     # the following definitions must be coherent with $TXT
