@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langes.tcl
-#  Last change:  21 April 2007
+#  Last change:  16 March 2009
 #
 # Spanish language file by Alberto Morales (amd77@gulic.org)
 #  last input from him: 21 April 2007
@@ -280,7 +280,6 @@ array set MESS {
     undefinedTR   "Trayecto desconocido"
     emptymenu "Men vacio; continuar?"
     cantwrtsymenu "No puedo escribir en fichero de men de smbolos"
-    cantwrtmbaks "No puedo escribir fichero de mapas de fondo de usuario"
     abbrevhasspaces "El nombre corto no puede tener espacios"
     getAL   "Obteniendo almanaque"
     needNpoints "Debes dar al menos %s puntos!"
@@ -913,7 +912,6 @@ array set TXT {
     cwpsdef "PTs de control para definir ahora"
     nextTP "Prximo punto trayecto"
     generate Generar
-    generateall "Generar todos"
     width Grosor
     simplTRto "Simplificar a"
     exstglog "Registro existente"
