@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  18 September 2008
+#  Last change:  27 December 2009
 #
 # French language file by Valre Robin (valere.robin _AT_ wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  18 September 2008
+#  last input from him inserted:  27 December 2009
 #
 # Includes contributions by Jean H Theoret (ve2za _AT_ rac.ca)
 # Includes contributions by Benoit Steiner (benetsteph _AT_ free.fr)
@@ -280,7 +280,6 @@ array set MESS {
     undefinedTR   "TR inconnu"
     emptymenu "Menu vide; continuer?"
     cantwrtsymenu "Impossible d'criture le fichier des menus de symboles"
-    cantwrtmbaks "Impossible d'criture le fichier de fond de carte"
     abbrevhasspaces "Nom court ne peut pas avoir des blancs"
     getAL  "Acquisition de l'almanach"
     needNpoints "Merci de fournir au moins %s points!"
@@ -292,6 +291,18 @@ array set MESS {
     baudchgfailed "Changement de la vitesse de transfert impossible"
     busytrylater "Opration en cours; merci d'essayer plus tard"
     obssplit "Resultat de la fragmentation de la %s nomme \"%s\""
+    loginto "Connexion  %s"
+    samelgth "Les 2 chaines doivent avoir le mme nombre de caractres"
+    rschkargs "L'appel de la fonction TCL regsub lve une erreur; vrifier les arguments"
+    emptyrmeth "La fonction de renommage ne peut tre vide"
+    cantwrtdefs "Impossibilit d'crire le fichier de dfinitions de l'utilisateur"
+    xcantbey "%s ne peut tre %s"
+    mustselftfam "Une police de caractre doit tre slectionne"
+    badpluginwhere "Mauvais argument \"where\" (localisation) pour le greffon; doit tre une liste de tripls"
+    badpluginparam "Mauvais paramtre du greffon : liste d'expressions de NAME EXPR, NAME commence par _"
+    badpluginparamexec "Lors de l'excution du greffon %s, mauvais paramtre: %s"
+    pluginfailed "Echec du greffon %s avec le message: %s"
+    canwrtaux "Impossibilit d'crire le fichier auxiliaire"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -893,7 +904,6 @@ array set TXT {
     PRJTWG "Grille tawanaise"
     chgdatum "Remplacer datum..."
     optPRINTCMD "Commande d'impression"
-    optMAPFONTSIZE "Taille de police pour la carte"
     print Impression
     prevctr "Centre prcdent"
     PRJSOM "Mercator Oblique Suisse"
@@ -908,7 +918,6 @@ array set TXT {
     cwpsdef "Dfinir les point de contrle"
     nextTP "Prochain point de trace"
     generate "Gnrer"
-    generateall "Gnrer tout"
     optSERIALBAUD "Vitesse de transfert"
     optDEFTRTWIDTH "Largeur des routes"
     optDEFTTRWIDTH "Largeur des traces"
@@ -940,7 +949,6 @@ array set TXT {
     optMAPCOLOUR,trvwrninfo "Information (nav)"
     travel "Voyage"
     notravel "Arrt du voyage"
-    optTRAVELFONTSIZE "Taille de la police d'affichage des voyages"
     travdisplay "Configuration de l'affichage"
     travchgdisplay "Changement pour l'affichage %s"
     travdsetup "Configuration de l'affichage du voyage"
@@ -1231,9 +1239,7 @@ array set TXT {
     fromdef "depuis une dfinition"
     mbaktoload "Fond de map  charger"
     none "aucun"
-    opt_Fonts "Tailles des polices"
-    optFONTSIZE "Taille de police dfaut"
-    optFIXEDFONTSIZE "Taille de police fixe"
+    opt_Fonts "Polices de caractre"
     optICONSIZE "Taille des symboles"
     optTRNUMBERINTVL "Intervalle pour information des points sur les traces"
     optTRINFO "Information sur point de trace"
@@ -1279,6 +1285,71 @@ array set TXT {
     bysel  "par points choisis"
     byseg  "par segments"
     openits "Ouvrir %s"
+    uname "Nom d'utilisateur"
+    pword "Mot de passe"
+    remember "Sauvegarder"
+    wptotwitter "Point d'itinraire (WP) vers Twitter"
+    wptotwitternb "Envoi des informations du point WP  Twitter (position, datum, altitude, nom, commentaire) avec les tags #GPSMan #waypoint"
+    exportTFW "Exportation du fichier TFW"
+    nametfwfile "Fichier TFW"
+    PRJEOV  EOV
+    chgname "Modification du nom"
+    clicktoedit "Cliquer pour modifier"
+    renamethod "Mthode de renommage"
+    operators "Operateurs"
+    keep1st "garder le premier caractre"
+    keep1st_hlp "Garder le premier caractre\nles oprations suivantes portent sur les caractres restants"
+    reset "reset"
+    reset_hlp "Retour au nom initial et effacement des oprations prcdentes"
+    case "changement de casse"
+    case_hlp "Toutes les lettres en minuscule/majuscule"
+    maxlgth "longueur max"
+    maxlgth_hlp "Caractres tronqus  la longueur donne"
+    inslt "insertion  gauche"
+    inslt_hlp "Chane de insre avant le caractre de gauche"
+    insrt "insertion  droite"
+    insrt_hlp "Chane insre  la fin"
+    replc "remplacement"
+    replc_hlp "Chaque caractre de la 1re chane sera remplace par\nle caractre correspondant dans la 2nde"
+    delany "effacement"
+    delany_hlp "Tous les caractres de la chane seront effacs du nom"
+    rsub "Substitution par regexp"
+    rsub_hlp "Substitution par expression rgulire\nConsulter le manuel"
+    accifnew "accept comme nouveau"
+    accifnew_hlp "Accepter le rsultation comme tant un nouveau nom"
+    guntilnew "nouveau nom par nombre"
+    guntilnew_hlp "Essaie des valeurs du nombre pour gnrer un nouveau nom"
+    ndigits "Nombre de chiffres"
+    gennames "Gnratrion du nom..."
+    rentest_hlp "Test de la mthode sur le nom"
+    renmove_hlp "Utiliser le bouton Droit pour trier les lignes"
+    tolower "vers minuscules"
+    toupper "vers majuscules"
+    applyto "Appliquer "
+    forall "pour tous"
+    failed "chec"
+    selfont "Slection de la police"
+    default "Dfaut"
+    size "Taille"
+    units "Units"
+    points "points"
+    pixels "pixels"
+    weight "forme"
+    normal "normale"
+    bold "gras"
+    slant   "italique"
+    roman "roman"
+    italic "italic"
+    underline "soulign"
+    overstrike "barr"
+    optDEFAULTFONT "Police par dfaut"
+    optFIXEDFONT "Largeur fixe"
+    optMAPFONT "Police pour la carte"
+    optTRAVELFONT "Police pour la navigation"
+    optPLOTFONT "Police pour le dessin"
+    plugin  "Greffon"
+    unavailif  "Indisponible si"
+    tclcode  "Code TCL"
 }
 
     # the following definitions must be coherent with $TXT
