@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File		: langid.tcl
-#  Last change	:  14 September 2008
+#  Last change	:  16 March 2009
 #
 # Indonesian language file by Tri Agus Prayitno (acuss@bk.or.id)
 #  last input from him inserted:  14 September 2008
@@ -913,7 +913,6 @@ array set TXT {
     cwpsdef "WP kontrol yang akan diisi"
     nextTP "TP selanjutnya"
     generate Buat
-    generateall "Buat semua"
     optSERIALBAUD "Baud Rate"
     optDEFTRTWIDTH "Lebar garis RT"
     optDEFTTRWIDTH "Lebar garis TR"
