@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  24 September 2008
+#  Last change:  22 December 2009
 #  Italian language file by Alessandro Palmas (alpalmas@tin.it)
-#  last input from him inserted:  24 September 2008
+#  last input from him inserted:  22 December 2009
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -278,7 +278,6 @@ array set MESS {
     undefinedTR   "TR sconosciuta"
     emptymenu "Men vuoto; continuo?"
     cantwrtsymenu "Non posso scrivere il file del men dei simboli"
-    cantwrtmbaks "Impossibile scrivere file mappe background"
     abbrevhasspaces "I nomi corti non debbono contenere spazi"
     needNpoints "Fornire almeno %s punti"
     twotimeoffsets "Differenti offset tempo nel file"
@@ -289,6 +288,18 @@ array set MESS {
     baudchgfailed "Non riesco a cambiare baud rate"
     busytrylater "Altra operazione in corso; prego riprovare pi tardi"
     obssplit "Risultato della suddivisione: %s chiamato \"%s\""
+    loginto "Login %s"
+    samelgth "Le due stringhe debbono avere lo stesso numero di caratteri"
+    rschkargs "La regsub chiamante ritorna errore; controllare i parametri"
+    emptyrmeth "Il metodo di rinomina non pu esser nullo"
+    cantwrtdefs "Impossibile scrivere il file di definizioni dell'utente"
+    xcantbey "%s non pu essere %s"
+    mustselftfam "Una famiglia di caratteri (font) deve essere scelta"
+    badpluginwhere "Parametro  plug-in \"where\" errato; deve essere una lista di triple"
+    badpluginparam  "Parametri plug-in errati: lista di NAME EXPR, NAME inizia con _"
+    badpluginparamexec "Durante l'esecuzione del plug-in %s, incontrato parametro errato: %s"
+    pluginfailed "Plug-in %s fallisce con messaggio: %s"
+    canwrtaux "Impossibile scrivere file ausiliario"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -836,14 +847,12 @@ array set TXT {
     PRJTWG "Griglia di Taiwan"
     chgdatum "Cambia datum"
     optPRINTCMD "Comando di stampa"
-    optMAPFONTSIZE "Dimensioni font mappa"
     print Stampa
     prevctr "Centro precedente"
     PRJSOM "Obliqua di Mercatore - Svizzera"
     PRJLV03 "Griglia svizzera LV03"
     PRJIcG "Griglia islandese"
     PRJRDG "Griglia Olandese"
-    chgmfsize "Cambia dimensione font mappa"
     printopt "Opzioni di stampa"
     numberid "Num/Id"
     hiddendata "Dati protetti"
@@ -851,7 +860,6 @@ array set TXT {
     cwpsdef "Punti di taratura da definire ora:"
     nextTP "Prossimo TP"
     generate Generare
-    generateall "Genera tutti"
     optSERIALBAUD "Baud Rate"
     optDEFTRTWIDTH "Larghezza linee RT"
     optDEFTTRWIDTH "Larghezza linee TR"
@@ -883,7 +891,6 @@ array set TXT {
     optMAPCOLOUR,trvwrninfo "Informazione (nav)"
     travel Viaggio
     notravel "Stop navigazione"
-    optTRAVELFONTSIZE "Dimensione caratteri schermata viaggio"
     travdisplay "Configura schermata"
     travchgdisplay "Vai alla schermata %s"
     travdsetup "Configurare schermata viaggio"
@@ -1174,9 +1181,7 @@ array set TXT {
     fromdef "da definizione"
     mbaktoload "Sfondo da caricare"
     none "nessuno"
-    opt_Fonts "Dimensioni font"
-    optFONTSIZE "Dimensioni default font"
-    optFIXEDFONTSIZE "Dimensione font fissata" 
+    opt_Fonts "Font"
     optICONSIZE "Dimensioni icone"
     optTRNUMBERINTVL "Mostra info TP su mappa ad ogni"
     optTRINFO "Info TP da mostrare" 
@@ -1220,6 +1225,72 @@ array set TXT {
     bysel  "per punti selezionati"
     byseg  "per segmenti"
     openits "Apri %s"
+    uname "Nome utente"
+    pword "Password"
+    remember "Ricordare"
+    wptotwitter "Inviare WP a Twitter"
+    wptotwitternb "Inviare posizione WP, datum, altitudine, nome e commento a 
+Twitter con etichetta #GPSMan #waypoint"
+    exportTFW "Esportare file TWF"
+    nametfwfile "File TFW"
+    PRJEOV  EOV
+    chgname "Cambiare nome"
+    clicktoedit "Click per editare"
+    renamethod "Metodo per rinomina"
+    operators "Operatori"
+    keep1st "tenere il primo carattere"
+    keep1st_hlp "Tenere il primo carattere\nulteriori operazioni sui rimanenti"
+    reset "reset"
+    reset_hlp "Ripartenza con il nome iniziale ignorando i cambiamenti effettuati"
+    case "cambiare maiuscolo/minuscolo"
+    case_hlp "Tutte le lettere in maiuscolo/minuscolo"
+    maxlgth "lungh max"
+    maxlgth_hlp "Caratteri correnti tagliati al numero dato"
+    inslt "inserire a sinistra"
+    inslt_hlp "Inserire la stringa a sinistra prima del carattere corrente"
+    insrt "inserire a destra" 
+    insrt_hlp "Inserire la stringa a sinistra alla fine"
+    replc "sostituire"
+    replc_hlp " i caratteri della prima stringa verranno sostituiti\ndai corrispondenti nella seconda"
+    delany "cancellare"
+    delany_hlp "Tutti i caratteri nella stringa data verranno cancellati dal nome"
+    rsub "re. sostituzione"
+    rsub_hlp "Fornire espressione regolare e specifiche di sostituzione\nsi veda il manuale per dettagli"
+    accifnew "accettare se nuovo"
+    accifnew_hlp "Accettare il risultato se il nome non  in uso"
+    guntilnew "aggiungere in coda numero sino a trovare nuovo"
+    guntilnew_hlp "Tentare con tutti i valori possibili del numero sino a che si trovi un nome non in uso" 
+    ndigits "Numero di cifre"
+    gennames "Generazione nomi in corso..."
+    rentest_hlp "Testare il metodo corrente su un nome dato"
+    renmove_hlp "Usare il bottone destro per riordinare le linee"
+    tolower "a minuscolo" 
+    toupper "a maiuscolo"
+    applyto "Applicare a"
+    forall "per tutti"
+    failed "fallito"
+    selfont "Selezione font"
+    default  "Default"
+    size "Dimensione"
+    units "Unit"
+    points "punti"
+    pixels "pixel"
+    weight "peso"
+    normal "normale"
+    bold "grassetto"
+    slant   "inclinazione"
+    roman "romano"
+    italic "italico"
+    underline "Sottolineato"
+    overstrike "Cancellato"
+    optDEFAULTFONT "Default font"
+    optFIXEDFONT "Font fixed"
+    optMAPFONT "Font mappa"
+    optTRAVELFONT "Font viaggio"
+    optPLOTFONT "Font plot/graph"
+    plugin  "Plug-in"
+    unavailif  "Non disponibile se"
+    tclcode  "Codice Tcl"
 }
 
     # the following definitions must be coherent with $TXT
