@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  22 September 2008
+#  Last change:  27 December 2009
 #  Dutch language file by Rob Buitenhuis (rob@buitenhs.demon.nl)
-#  last input from him inserted: 22 September 2008
+#  last input from him inserted: 27 December 2009
 #
 # 
 #  file langengl.tcl is consulted first; no need for duplicating entries here
@@ -299,6 +299,18 @@ array set MESS {
     baudchgfailed "Kon baud rate niet veranderen"
     busytrylater "Bezig met andere bewerkingen; aub later herhalen"
     obssplit "Resultaat opsplitsen van %s met naam \"%s\""
+    loginto "Login %s"
+    samelgth "De twee strings moeten hetzelfde aantal lettertekens bevatten"
+    rschkargs "Oproepen van regsub foutief; check de argumenten"
+    emptyrmeth "Methode van hernoemen mag niet leeg zijn"
+    cantwrtdefs "Kan het bestand met gebruikersdefinities niet schrijven"
+    xcantbey "%s mag niet %s zijn"
+    mustselftfam "Er moet een font family worden geselecteerd"
+    badpluginwhere "Fout plug-in \"waar\" argument; moet eel lijst tripletten zijn"
+    badpluginparam "Foute plug-in parameters: lijst NAME EXPR, NAME begint met _"
+    badpluginparamexec "Tijdens draaien plug-in %s, foutieve parameter: %s"
+    pluginfailed "Plug-in %s faalde met boodschap: %s"
+    canwrtaux "Kan hulpbestand niet schrijven"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} graad {$ALUNIT} et. beschr."
@@ -873,21 +885,18 @@ array set TXT {
     chgdatum "Wijzig datum ..."
     opt_Interf  "Gebruikers-interface"
     optPRINTCMD "Afdruk commando"
-    optMAPFONTSIZE "Kaart-font grootte"
     print "Druk af"
     prevctr "Vorig centrum"
     PRJSOM "Zwitsers Oblique Mercator"
     PRJLV03 "Zwitsers LV03 Grid"
     PRJIcG "IJslands Grid"
     PRJRDG "Nederlands (RD) Grid"
-    chgmfsize "Verander kaart-font grootte"
     printopt "Afdruk opties"
     numberid "Getal/Aanduiding"
     hiddendata "Afgeschermde gegevens"
     YYYY/MM/DD  JJJJ/MM/DD
     nextTP "Volgend TP"
     generate Maak
-    generateall "Maak alles"
     optSERIALBAUD "Baud Rate"
     optDEFTRTWIDTH "RT lijn-dikte"
     optDEFTTRWIDTH "TR lijn-dikte"
@@ -919,7 +928,6 @@ array set TXT {
     optMAPCOLOUR,trvwrninfo "Informatie (nav)"
     travel Verplaats
     notravel "Stop verplaatsen"
-    optTRAVELFONTSIZE "Font-grootte verplaats-display"
     travdisplay "Configureer display"
     travchgdisplay "Ga naar display %s"
     travdsetup "Configureer verplaatsings-display"
@@ -975,7 +983,6 @@ array set TXT {
     warntrn "TRN (abs)>"
     warnvspeed "Verticale snelheid"
     warnxtk "XTK (abs)>"
-    fntsize "Font-grootte"
     trvhlpbox "Gebruik rechter-button om onderstaande elementen te herschikken"
     trvhlpbxs "Gebuik rechter-button om lijst-elementen te herschikken"
     trvwarrv "Aankomst bij %s!"
@@ -1207,9 +1214,7 @@ array set TXT {
     fromdef "van definitie"
     mbaktoload "Te laden achtergrond"
     none "geen"
-    opt_Fonts "Font-groottes"
-    optFONTSIZE "Default font-grootte"
-    optFIXEDFONTSIZE "Vaste font-grootte"
+    opt_Fonts "Fonts"
     optICONSIZE "Icon-grootte"
     optTRNUMBERINTVL "Toon TP-info op kaart bij elk"
     optTRINFO "Te tonen TP-info"
@@ -1254,6 +1259,71 @@ array set TXT {
     bysel  "via geselecteerde punten"
     byseg  "via segmenten"
     openits "Open %s"
+    uname "Naam gebruiker"
+    pword "Wachtwoord"
+    remember "Vasthouden"
+    wptotwitter "WP naar Twitter"
+    wptotwitternb "Stuur WP positie, datum, hoogte, naam and commentaar naar Twitter met tags #GPSMan #waypoint"
+    exportTFW "Exporteer TFW-bestand"
+    nametfwfile "TFW-bestand"
+    PRJEOV  EOV
+    chgname "Wijzig naam"
+    clicktoedit "Klik om te wijzigen"
+    renamethod "Methode van hernoemen"
+    operators "Operatoren"
+    keep1st "behoud eerste char"
+    keep1st_hlp "Behoud eerste char\noverige operatoren betreffen de resterende chars"
+    reset "reset"
+    reset_hlp "Herstart met oorspronkelijke naam, vorige wijzigingen worden teruggezet"
+    case "wijzig letterkastchange case"
+    case_hlp "Alle letters naar boven/onder-kast"
+    maxlgth "max lengte"
+    maxlgth_hlp "Huidige chars afgekapt naar opgegeven aantal"
+    inslt "links-invoegen"
+    inslt_hlp "Opgegeven string wordt ingevoegd voor huidig links-char"
+    insrt "rechts-invoegen"
+    insrt_hlp "Opgegeven string wordt aan het eind ingevoegd"
+    replc "vervang"
+    replc_hlp "Elk char in de eerste string wordt vervangen\ndoor de corresponderende in de tweede"
+    delany "wis elk"
+    delany_hlp "Alle chars in de opgegeven string worden uit de naam gewist"
+    rsub "re. substitutie"
+    rsub_hlp "Geef de regular expression and substitution specificatie\nzie het manual voor details"
+    accifnew "accepteer als nieuw"
+    accifnew_hlp "Accepteer resultaat als het een nieuwe naam is"
+    guntilnew "voeg getal toe tot nieuw"
+    guntilnew_hlp "Probeer alle mogelijke waarden van het getal tot een nieuwe naam is gevonden"
+    ndigits "Aantal cijfers"
+    gennames "Genereren van namen..."
+    rentest_hlp "Test huidige methode op opgegeven naam"
+    renmove_hlp "Gebruik rechter muisknop om regels te herschikken"
+    tolower "naar onderkast"
+    toupper "naar bovenkast"
+    applyto "Toepassen op"
+    forall "voor alle"
+    failed "gefaald"
+    selfont "Selecteren font"
+    default "Verstek"
+    size "Grootte"
+    units "Eenheden"
+    points "punts"
+    pixels "pixels"
+    weight "Gewicht"
+    normal "normaal"
+    bold "vet"
+    slant   "Schuin"
+    roman "roman"
+    italic "cursief"
+    underline "Onderstreept"
+    overstrike "Overelkaar"
+    optDEFAULTFONT "Verstek-font"
+    optFIXEDFONT "Vast-font"
+    optMAPFONT "Kaart-font"
+    optTRAVELFONT "Reis-display-font"
+    optPLOTFONT "Plot/grafisch-font"
+    plugin  "Plug-in"
+    unavailif  "Niet beschikbaar als"
+    tclcode  "Tcl code"
 }
 
     # the following definitions must be coherent with $TXT
