@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  30 September 2008
+#  Last change:  18 December 2009
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -286,7 +286,6 @@ array set MESS {
     undefinedTR "TR no existente"
     emptymenu "Menu vazio; continuar?"
     cantwrtsymenu "No posso escrever no ficheiro do menu de smbolos"
-    cantwrtmbaks "No posso escrever no ficheiro de mapas"
     abbrevhasspaces "Abreviatura no pode ter espaos"
     needNpoints "Precisa de pelo menos %s pontos!"
     twotimeoffsets "Mais que uma diferena horria no ficheiro"
@@ -297,6 +296,18 @@ array set MESS {
     busytrylater "Outras operaes em curso; tente mais tarde"
     baudchgfailed "Mudana de baud rate falhou"
     obssplit "Resultados de cortar %s com nome \"%s\""
+    samelgth "As duas sequncias tm de ser do mesmo tamanho"
+    rschkargs "Chamada a regsub deu erro; verifique os argumentos"
+    emptyrmeth "Mtodo de substituio no pode ser vazio"
+    cantwrtdefs "No posso escrever no ficheiro de definies do utilizador"
+    xcantbey "%s no pode ser %s"
+    mustselftfam "Tem de seleccionar uma famlia de tipos"
+    badpluginwhere "Erro em argumento \"onde\" de extenso; deve ser lista de ternos"
+    badpluginparam "Erro nos parmetros de extenso: lista de NOME EXPR, NOME iniciado por _"
+    badpluginparamexec "Ao correr extenso %s, parmetro errado: %s"
+    pluginfailed "Extenso %s falhou com mensagem: %s"
+    canwrtaux "No posso escrever um ficheiro auxiliary"
+    loginto "Acesso a %s"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau {$ALUNIT} etapa etiq"
@@ -503,10 +514,7 @@ array set TXT {
     optMAPCOLOUR,anim "Animao no mapa"
     optMAPCOLOUR,emptygrid  "Sem imagem"
     optMAPCOLOUR,fullgrid   "Com imagem"
-    opt_Fonts "Tamanhos de letra"
-    optFONTSIZE "Tamanho de letra, habitual"
-    optFIXEDFONTSIZE "Tamanho de letra, fixa"
-    optMAPFONTSIZE "Tamanho de letra, mapa"
+    opt_Fonts "Tipos de letra"
     optDEFTRTWIDTH "Espessura RT"
     optDEFTTRWIDTH "Espessura TR"
     optDEFTLNWIDTH "Espessura LN"
@@ -1009,7 +1017,6 @@ array set TXT {
     cwpsdef "PTs de controle a definir agora"
     nextTP "Prximo PTR"
     generate Gerar
-    generateall "Gerar todos"
     width Espessura
     simplTRto "Simplificar p/"
     exstlgog "Registo existente"
@@ -1146,7 +1153,7 @@ array set TXT {
     Ghidden_map_addr "Endereo (mapa)"
     Ghidden_map_line "Linha (mapa)"
     Ghidden_locked Bloqueado
-    Ghidden_default "Normal"
+    Ghidden_default "Habitual"
     Ghidden_red Vermelho
     Ghidden_green Verde
     Ghidden_blue Azul
@@ -1266,6 +1273,70 @@ array set TXT {
     bysel  "por pontos seleccionados"
     byseg  "em segmentos"
     openits "Abrir %s"
+    chgname "Substituir nomes"
+    clicktoedit "Tocar para editar"
+    renamethod "Mtodo de substituio"
+    operators "Operadores"
+    keep1st "manter 1.o caracter"
+    keep1st_hlp "Manter o 1.o caracter\noperaes seguintes actuam nos restantes"
+    reset "recomear"
+    reset_hlp "Recomear com o nome inicial esquecendo alteraes j feitas"
+    case "mai/minsculas"
+    case_hlp "Todas as letras em maisculas/minsculas"
+    maxlgth "comprimento mx"
+    maxlgth_hlp "Limitar nmero de caracteres correntes"
+    inslt "inserir  esquerda"
+    inslt_hlp "A sequncia dada ser inserida antes do 1.o caracter corrente"
+    insrt "inserir  direita"
+    insrt_hlp "A sequncia dada ser inserida no fim"
+    replc "substituir"
+    replc_hlp "Cada caracter na 1.a sequncia ser substitudo pelo\ncorrespondente na segunda"
+    delany "apagar todos"
+    delany_hlp "Todos os caracteres na sequncia sero apagados no nome"
+    rsub "substituio com re."
+    rsub_hlp "D a expresso regular e especificao de substituio\npara detalhes ver o manual"
+    accifnew "aceitar se novo"
+    accifnew_hlp "Aceitar o resultado se  um nome novo"
+    guntilnew "juntar nmero at novo"
+    guntilnew_hlp "Tentar todos os nmeros at que o nome seja novo"
+    ndigits "N.o de algarismos"
+    gennames "A gerar nomes..."
+    rentest_hlp "Testar este mtodo com o nome dado"
+    renmove_hlp "Usar boto direito para reordenar linhas"
+    tolower "minsculas"
+    toupper "maisculas"
+    applyto "Aplicar a"
+    forall "para todos"
+    selfont "Seleco de tipo"
+    default "Habitual"
+    size "Tamanho"
+    units "Unidades"
+    points "pontos"
+    pixels "pixels"
+    weight "Peso"
+    normal "normal"
+    bold  "negrito"
+    slant "Inclinao"
+    roman "romano"
+    italic "itlico"
+    underline "Sublinhado"
+    overstrike "Cortado"
+    optDEFAULTFONT "Tipo de letra, habitual"
+    optFIXEDFONT "Tipo de letra mono-espaado"
+    optMAPFONT "Tipo de letra, mapa"
+    optTRAVELFONT "Tipo de letra, viagem"
+    optPLOTFONT "Tipo de letra, grficos"
+    failed "falhou"
+    plugin  "Extenso"
+    unavailif  "Indisponvel se"
+    tclcode  "Cdigo Tcl"
+    uname "Nome de Utilizador"
+    pword "Cdigo de Acesso"
+    remember "Recordar"
+    wptotwitter "PT para Twitter"
+    wptotwitternb "Enviar a posio, datum, altitude, nome e comentrio de PT para Twitter com marcas #GPSMan #waypoint"
+    exportTFW "Exportar ficheiro TFW"
+    nametfwfile "Ficheiro TFW"
 }
 
     # the following definitions must be coherent with $TXT
