@@ -5,7 +5,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c)1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c)1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -21,8 +21,11 @@
 #      along with this program.
 #
 #  File: langru.tcl
-#  Last change:  21 October 2007
+#  Last change:  27 December 2009
+# Russian language file by Nikolai Kosyakov, 21 October 2007
 #
+# Support by Alexander B. Preobrazhenskiy, (modul@ihome.ru) since October 2009
+#  last input from him inserted:  27 December 2009
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -141,7 +144,7 @@ array set MESS {
     fillbuffRT  "Загрузка буфера МТ"
     noACKNAK  "При ожидании ACK/NAK получен пакет данных; проверьте соединение с GPS-приёмником"
     badplatform   "На данной платформе невозможен ввод/вывод через последовательный порт"
-    badserial "Не могу открыть последовательный порт %s"
+    badserial "Не могу соединиться с %s"
     nodata    "Нет %s в приёмнике"
     badimage "Не корректный графический файл"
     mapadjust "Пожалуйста разместите на карте ПТ; щёлкните на Ok, когда закончите"
@@ -167,7 +170,7 @@ array set MESS {
     serial2 "Возвращена некорректная Команда"
     checksum1 "Некорректная Контрольная сумма Заголовка"
     checksum2 "Ошибка Контрольной суммы данных"
-    receiver "Нет соединения по последовательному порту!"
+    receiver "Не соединен с прибором!"
     importonly1 "Могу проимпортировать только 1 вид данных"
     exportonly1 "Могу проэкспортировать только 1 вид данных"
     outdatedprefs "Файл предварительных настроек устарел; пожалуйста проверьте его сейчас"
@@ -207,7 +210,7 @@ array set MESS {
     baddistunit "Недопустимая единица длины в файле настроек для масштаба карты"
     badgridzone "Недопустимая зона для системы координат"
     outofgrid "Положение вне допустимых значений для системы координат"
-    timeoffnotint "Временное смещение должно быть целым значением"
+    timeoffnotint "Временное смещение должен быть целочисленным значением, либо оканчиваться на .5"
     cantchkprot "Невозможно проверить при текущем протоколе"
     mustconn1st "Проверьте сначала соединение с проёмником"
     rltmnotsupp "Этот приёмник не поддерживает запись журнала в реальном времени"
@@ -292,6 +295,25 @@ array set MESS {
     cantwrtmbaks "Не могу записать фоновый файл для карты пользователя"
     abbrevhasspaces "Короткое имя не может быть пустым"
     needNpoints "Вы должны указать не менее %s точек!"
+    samelgth "Обе строки должны иметь одинаковое кол-во символов"
+    rschkargs "Функция regsub завершилась с ошибкой, проверьте аргументы"
+    emptyrmeth "Метод переименования не может быть пустым"
+    cantwrtdefs "Невозможно записать файл пользовательских настроек"
+    xcantbey "%s не может быть %s"
+    mustselftfam "Выберите группу шрифтов"
+    badpluginwhere "Неверный агрумент плугина \"where\"; должен быть списком"
+    badpluginparam "Неверные параметры плугина: список NAME EXPR, где NAME должно начинаться с _"
+    badpluginparamexec "При запуске плугина %s: неверный параметр %s"
+    pluginfailed "Плугин %s завершился ошибкой: %s"
+    canwrtaux "Невозможно записать вспомогательный файл"
+    twotimeoffsets "Различные временные зоны в файле"
+    notimeoffset "Не указана часовой пояс, принимается 0"
+    baddateas "Плохая дата: %s"
+    unknownenc "Неизвестная кодировка символа %s"
+    chgbaudto "Смена скорости обмена с прибором на %s; подождите..."
+    baudchgfailed "Невозможно сменить скорость порта"
+    busytrylater "Выполняются другие операции, попробуйте позже"
+    obssplit "Результат разбиения %s, названного \"%s\""
 }
 
 set TXT(RTcompflds) "# ПТ {$DTUNIT} гр {$ALUNIT} метка этапа"
@@ -501,15 +523,12 @@ array set TXT {
     optMAPCOLOUR,anim  "Анимация на карте"
     optMAPCOLOUR,emptygrid  "Пустое изображение"
     optMAPCOLOUR,fullgrid   "Существующее изображение"
-    opt_Fonts          "Размеры шрифтов"
-    optFONTSIZE        "Размер шрифта поумолчанию"
-    optFIXEDFONTSIZE   "Размер шрифта fixed"
-    optMAPFONTSIZE     "Размер шрифта на карте"
+    opt_Fonts "Шрифты"
     optDEFTRTWIDTH     "Ширина линии для МР"
     optDEFTTRWIDTH     "Ширина линии для ТР"
     optDEFTLNWIDTH     "Щирина линии ЛН"
-    opt_Files          "Последовательный порт и файлы"
-    optDEFSPORT        "Последовательный порт"
+    opt_Files "Прибор и файлы"
+    optDEFSPORT "Прибор"
     optSAVESTATE       "Сохранить при выходе состояние"
     optDELSTATE        "Удалить файлы после восстановления состояния"
     optPERMS           "Права на файл"
@@ -1040,7 +1059,6 @@ array set TXT {
     print      Печать
     prevctr   "Предыдущий центр"
     printopt  "Печать настроек"
-    chgmfsize "Изменить размер шрифта на карте"
     cwpsdef   "Непосредственное определение ПТк"
     nextTP    "Следующая ТТ"
     generate   Сгенерировать
@@ -1066,7 +1084,6 @@ array set TXT {
     optMAPCOLOUR,trvwrnimportant "Важное предупреждение (нав)"
     optMAPCOLOUR,trvwrnnormal "Предупреждение (нав)"
     optMAPCOLOUR,trvwrninfo "Информация (нав)"
-    optTRAVELFONTSIZE "Размер фонта для экрана путешествия"
     travel Путешествие
     notravel "Остановить путешествие"
     travdisplay "Настроить экран"
@@ -1125,7 +1142,6 @@ array set TXT {
     warntrn "TRN (abs)>"
     warnvspeed "Вертикальная скорость"
     warnxtk "XTK (abs)>"
-    fntsize "Размер фонта"
     trvhlpbox "Используйте прав.кнопку для переупорядочивания элементов снизу"
     trvhlpbxs "Используйте прав.кнопку для переупорядочивания элементов списка"
     trvwarrv "Прибытие в %s!"
@@ -1281,6 +1297,95 @@ array set TXT {
     alm_health "здоровье"
     lstsqs  "Наименьшие Квадраты"
     lstsqsfile "Файл Наименьших Квадратов"
+    PRJEOV  "Аварийная машина (EOV)"
+    chgname "Изменить имя"
+    clicktoedit "Нажмите для редактирования"
+    renamethod "Метод переименования"
+    operators "Операторы"
+    keep1st "сохранить 1й символ"
+    keep1st_hlp "Сохранить первый символ\nдальнейшие операции производятся над оставшимися символами"
+    reset "сброс"
+    reset_hlp "Перезапустить с начальным именем, отменить все преддущие изменения"
+    case "сменить регистр"
+    case_hlp "Все буквы в верхний/нижний регистр"
+    maxlgth "макс. длина"
+    maxlgth_hlp "Текущая строка обрезаются до указанной длины"
+    inslt "вставить слева"
+    inslt_hlp "Строка вставляется перед текущим левым символом"
+    insrt "вставить справа"
+    insrt_hlp "Строкаа вставляется в конец"
+    replc "заменить"
+    replc_hlp "Любой символ в 1п строке будет заменен соответствующим символом из 2й"
+    delany "удалить любой"
+    delany_hlp "Все символы в данной строке будут удалены из имени"
+    rsub "подстановка"
+    rsub_hlp "Указать регулярное выражение и спецификацию подстановки\nподробнее - см. руководство"
+    accifnew "применить, если новое"
+    accifnew_hlp "Применить результат, если имя не используется"
+    guntilnew "добавлять, пока новое"
+    guntilnew_hlp "Перебирать все возможные значения числа, пока новое имя не будет найдено"
+    ndigits "Количество цифр"
+    gennames "Генерация имен..."
+    rentest_hlp "Проверить метод на указанном имени"
+    renmove_hlp "Используйте правую кнопку для перераспределения строк"
+    tolower "нижн.регистр"
+    toupper "верх.регистр"
+    applyto "Применить к"
+    forall "для всех"
+    failed "неудача"
+    selfont "Выбранный шрифт"
+    default "По умолчанию"
+    size "Размер"
+    units "Единицы"
+    points "точки"
+    pixels "пиксели"
+    weight "Вес"
+    normal "нормальный"
+    bold "полужирный"
+    slant   "наклонный"
+    roman "римский"
+    italic "курсив"
+    underline "Подчеркнутый"
+    overstrike "Перечеркнутый"
+    optDEFAULTFONT "Шрифт по умолчанию"
+    optFIXEDFONT "Фиксированный шрифт"
+    optMAPFONT "Шрифт карты"
+    optTRAVELFONT "Шрифт экрана путешествия"
+    optPLOTFONT "Шрифт графика"
+    plugin  "Плугин"
+    unavailif  "Недоступно, если"
+    tclcode  "Tcl код"
+    totdstng   "Общая дистанция, без разрывов"
+    tottimeng  "Общее время, без разрывов"
+    SYcross "Курсор"
+    SYcross_3p "Курсор 3 пикс"
+    mapfitWPs "Отобразить ближайшие ПТ на карте"
+    showfitinfo "Показать адаптированные данные"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "rms(x,y-отклонения)"
+    resstderr "остатоная ошибка"
+    chgdev "Сменить прибор"
+    maxalt "Максимальная высота"
+    minalt "Минимальная высота"
+    alt_cumul "Нарастающая высота восхождения"
+    alt_cumuld "Нарастающая величина спуска"
+    optSHOWFILEITEMS "По умолчанию отображать на карте читаемые элементы"
+    vertgridlines "Вертикальные линии сетки"
+    convert  "Конвертировать"
+    split    "Разделить"
+    bysel  "по выделенным точкам"
+    byseg  "по сегментам"
+    openits "Открыть %s"
+    uname "Имя пользователя"
+    pword "Пароль"
+    remember "Запомнить"
+    wptotwitter "ПТ в Twitter"
+    wptotwitternb "Послать позицию, дату, высоту, имя и комментарий путевой точки в Twitter с тегами #GPSMan #waypoint"
+    exportTFW "Экспортировать в TFW файл"
+    nametfwfile "TFW файл"
 }
 
     # the following definitions must be coherent with $TXT
