@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: lists.tcl
-#  Last change:  23 October 2008
+#  Last change:  16 March 2009
 #
 
 proc ChangeOnStateList {wh st} {
@@ -28,8 +28,11 @@ proc ChangeOnStateList {wh st} {
 
     # entries in the type list menu and in the type sub-menu of Data menu
     switch $wh {
+	WP {
+	    set es "1 2 5 6 7" ; set aes "1 2 4 5 6"
+	}
 	GR {
-	    set es "1 2 4 5 6 7 8" ; set aes "1 2 3 4 5 6 7"
+	    set es "1 2 4 5 6 7 8 9" ; set aes "1 2 3 4 5 6 7 8"
 	}
 	LAP {
 	    set es "0 2" ; set aes "0 2"
