@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@
 # Includes changes/contributions by Miguel Filgueiras marked
 #   "MF change" or "MF contribution"
 
+# Date last modified: 19 June 2007
+
 set SERIALLOG ~/.gpsman-log
 set NotLogging 1
 set LogMutex 0
@@ -401,8 +403,11 @@ global PDTYPE PRODID PROTV MAX Prod Protv
     set Protv [lindex $PROTV $vn]
 #    set MAX(WP) [lindex $data 6]
 #    set MAX(RT) [lindex $data 8]
-    set MAX(WP) 50
-    set MAX(RT) 4
+    # MF change: using the user defaults
+    global MAXWPOINTS MAXROUTES
+    set MAX(WP) $MAXWPOINTS
+    set MAX(RT) $MAXROUTES
+    #--
     set MAX(IC) [lindex $data 7]
     set MAXWPINROUTE) [lindex $data 9]
     set MAX(TR) [lindex $data 10]
