@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: magellan.tcl
-#  Last change:  22 November 2004
+#  Last change:  25 March 2008
 #
 # This file contributed by Matt Martin (matt.martin@ieee.org)
 #  Copyright (c) 2003 Matt Martin (matt.martin@ieee.org)
@@ -1240,7 +1240,7 @@ proc AddMagWPT {d} {
     if { ! [CheckName Ignore $name] } {
 	if { [set name [AskForName $name]] == "" } { return "" }
 	# MF change: add remark with old name
-	set d [AddOldNameToObs $d $name]
+	set d [AddOldNameToObs WP $d $name]
 
 	set d [lreplace $d 0 0 $name]
     }
