@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1008-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: mapanim.tcl
-#  Last change:  23 August 2008
+#  Last change:  22 February 2009
 #
 
 proc InitAnimation {type title args} {
@@ -67,12 +67,9 @@ proc InitAnimation {type title args} {
 
     # this name is used explicitly elsewhere
     set w .anim$no
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW \
-	"set Anim(state,$no) abort ; destroy $w ; AnimAbort $no"
-    wm title $w "$TXT(animation)/GPS Manager"
-    wm transient $w
-    wm geometry $w +$EPOSX+$EPOSY
+    GMToplevel $w animation +$EPOSX+$EPOSY {} \
+        [list WM_DELETE_WINDOW \
+	     "set Anim(state,$no) abort ; destroy $w ; AnimAbort $no"] {}
 
     trace variable Anim(state,$no) w AnimStateChange
     trace variable Anim(speed,$no) w AnimSpeedChange
@@ -293,13 +290,13 @@ proc AnimNextTR {no} {
     if { [set tp1 [lindex $tps 1]] != "" } {
 	set Anim(dist,$no) \
 	    [expr $Anim(dist,$no)+[ComputeDist $tp0 $tp1 $datum]*$DSCALE]
-	if { [set tm0 [lindex $tp0 5]] != $UNDEFDATESECS } {
+	if { abs([set tm0 [lindex $tp0 5]] - $UNDEFDATESECS) > 1 } {
 	    set Anim(time,$no) [lindex [DateFromSecsFmt $tm0 YYYYMMDD] 1]
 	} else { set Anim(time,$no) "" }
-	if { $tm0 == $UNDEFDATESECS || \
-		 [set tm1 [lindex $tp1 5]] == $UNDEFDATESECS || \
+	if { $Anim(time,$no) == "" || \
+		 abs([set tm1 [lindex $tp1 5]] - $UNDEFDATESECS) < 2 || \
 		 $tm1 < $tm0 } {
-	    set tint 30 ; set Anim(elapsed,$no) -1
+	    set tint 2 ; set Anim(elapsed,$no) -1
 	} else {
 	    set tint [expr $tm1-$tm0]
 	    if { $Anim(elapsed,$no) != -1 } {
