@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: maptransf.tcl
-#  Last change:  12 February 2008
+#  Last change:  16 December 2009
 #
 
 ## Uses information kindly supplied by
@@ -32,6 +32,7 @@
 #
 # affine transformation, 6 parameters
 #  (xt,yt) = [ aij ] x (xm,ym) + (e,f)
+#   where  a11 = a   a12 = b   a21 = c   a22 = d
 #
 # affine conformal transformation, 4 parameters
 #  (xt,yt) = lambda [ aij ] x (xm,ym) + (e,f)
@@ -261,6 +262,34 @@ proc MapNewScaleAffineConfTransf {scale} {
     return 0
 }
 
+proc MapAffineParams {} {
+    # convert parameters of current map transformation to corresponding
+    #  parameters of an affine transformation
+    # return list of a parameter name followed by its value, where the
+    #  parameter names are at least the following ones  a, b, c, d, e, f
+    #  as described above for the affine transformation
+    global MapTransf MTData
+
+parray MTData
+    switch $MapTransf {
+	Affine { return [array get MTData] }
+	AffineConf {
+	    set ps {}
+	    foreach p {a b c d e f} cp {a b b a e f} s {1 -1 -1 -1 1 1} {
+		lappend ps $p [expr $s*$MTData($cp)]
+puts "p=$p, cp=$cp v=$MTData($cp) e=[expr $s*$MTData($cp)]"
+	    }
+	}
+	NoRot {
+	    set lambda $MTData(lambda)
+	    return [list a $lambda b 0 c 0 d $lambda \
+			e $MTData(e) f $MTData(f)]
+	}
+    }
+    return $ps
+}
+
+
 ## solving a linear system of equations nxn by Gauss-Jordan elimination
 # code adopted from the Slopes Algorithm implementation in C
 # by M Filgueiras and A P Tomas / Universidade do Porto / 1996, 1997
@@ -624,40 +653,24 @@ proc MapInitLeastSquaresTransf {args} {
 }
 
 ##### TFW metadata file
-# there is no publicly available definition for this format:
-#   each file has 6 lines with a number each referred to by tfw_ below
-#
-# assume this is an affine transformation with
-# (xt,yt) = [ aij ] x (xm,ym) + (e,f)
-#  where  a11 = tfw1*cos(tfw2)
-#         a12 = -tfw4*sin(tfw3)
-#         a21 = tfw1*sin(tfw2)
-#         a22 = tfw4*cos(tfw3)
-#         e = tfw5, f = tfw6
-# 
-# inverse computation (not used): from aij to tfw_   TO BE CHECKED!
-#     if a11 != 0
-#       tfw2 = atan2(a21,a11) ; tfw1 = c/cos(tfw2)
-#     elseif tfw1 is known to be positive (W-E orientation from bottom to top)
-#       if a21 > 0
-#         tfw2 = PI/2 ; tfw1 = a21
-#       else  tfw2 = 1.5*PI ; tfw1 = -a21
-#     elseif a21 > 0
-#       tfw2 = 1.5*PI ; tfw1 = -a21
-#     else  tfw2 = PI/2 ; tfw1 = a21
-#
-#  and similarly for a12, a22, tfw3, tfw4
 
 proc MapInitTFWTransf {data proj} {
     # compute parameters of affine transformation from the values in a
     #  TFW metadata file
-    # assume this is an affine transformation with
-    # (xt,yt) = [ aij ] x (xm,ym) + (e,f)
-    #  where  a11 = tfw1*cos(tfw2)
-    #         a12 = -tfw4*sin(tfw3)
-    #         a21 = tfw1*sin(tfw2)
-    #         a22 = tfw4*cos(tfw3)
-    #         e = tfw5, f = tfw6
+    # based on the ESRI ArcGIS 2.9 manual (consulted November 2009) at
+    #  http://webhelp.esri.com/arcgisdesktop/9.2/index.cfm?id=2676&pid=2664&topicname=World_files_for_raster_datasets
+    # this is an affine transformation with
+    # (xt,yt) = [ Aij ] x (xm,ym) + (C,F)
+    #  where  A11 = A = tfw1
+    #         A12 = B = tfw3
+    #         A21 = D = tfw2
+    #         A22 = E = tfw4 (correct sign for y map coordinates growing down)
+    #         C = tfw5, F = tfw6
+    #
+    #  therefore in the GPSMan notation
+    #     a = A,  b = B,  e = C
+    #     c = D,  d = E,  f = F
+    #
     #  $data is a pair with an empty list and a list with the 6 parameters
     #        (tfw_ in the formulae above)
     #  $proj is the projection
@@ -665,15 +678,19 @@ proc MapInitTFWTransf {data proj} {
     global MTData MapScale
 
     MapTransfIs Affine
-    foreach "t1 t2 t3 t4 MTData(e) MTData(f)" [lindex $data 1] {}
-    array set MTData [list \
-	    a [expr $t1*cos($t2)]  b [expr -$t4*sin($t3)] \
-	    c [expr $t1*sin($t2)]  d [expr $t4*cos($t3)]  ]
+    foreach m {a c b d e f} v [lindex $data 1] {
+	# to avoid integer divisions
+	set MTData($m) [expr 0.0+$v]
+    }
     set MTData(det) [expr $MTData(a)*$MTData(d)-$MTData(b)*$MTData(c)]
-    if { abs($MTData(det)) < 1e-12 } { return 0 }	    
+    if { abs($MTData(det)) < 1e-30 } {
+	return 0
+    }
+    # the following parameters simplify computations
     set MTData(k2m1) [expr $MTData(b)*$MTData(f)-$MTData(d)*$MTData(e)]
     set MTData(k4m3) [expr $MTData(c)*$MTData(e)-$MTData(a)*$MTData(f)]
-    FixMapScale $proj
+    # scale along the xm-axis when variation of ym=0
+    set MapScale [expr abs($MTData(a))]
     return 1
 }
 
