@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: navigate.tcl
-#  Last change:  27 July 2006
+#  Last change:  18 December 2009
 #
 
 ##### travel/navigation display
@@ -43,12 +43,14 @@ proc ToTravel {} {
 
 proc TravelInit {fr} {
     # set up the travel frame $fr
-    global Travel RcMenu TXT COLOUR MAPCOLOUR MAPDISTS MAPDISTVALS FontSize
+    global Travel RcMenu TXT COLOUR MAPCOLOUR MAPDISTS MAPDISTVALS
 
     foreach e $Travel(els) { set Travel(info,$e) "" }
     set Travel(info,vel_z) ""
     set Travel(nav,datum,a) [lindex [EllipsdData $Travel(nav,datum)] 0]
 
+    TravelInitFonts create
+
     # widget names are used in other procedures
     frame $fr.fctrl
     set mn $fr.fctrl.ctrl.mn
@@ -163,8 +165,7 @@ proc TravelInit {fr} {
 	foreach "x y" $ps { lappend psr [expr $cbgw-$x] $y }
 	eval $cbg create polygon $psr -fill $COLOUR(dialbg) -width 1 \
 		-outline black -tags right
-	label $cbg.lab -textvariable Travel(info,trn) \
-	    -font "fixed $FontSize bold"
+	label $cbg.lab -textvariable Travel(info,trn) -font $Travel(fontb)
 	$cbg create window $cw2 $ch2 -anchor c -window $cbg.lab
 
 	# up-down arrow
@@ -179,8 +180,7 @@ proc TravelInit {fr} {
 		[expr $ch2+2] 2"
 	eval $cvz create polygon $psn -fill $COLOUR(dialbg) -width 1 \
 		-outline black -tags vel_z
-	label $cvz.lab -textvariable Travel(info,vel_z) \
-	    -font "fixed [expr $FontSize+2] bold"
+	label $cvz.lab -textvariable Travel(info,vel_z) -font $Travel(fontb2)
 	$cvz create window [expr 0.75*$cbgw] $ch2 -anchor c -window $cvz.lab
 	set Travel(wdgts,vel_z) [expr 2+$b]
 	set Travel(wdgts,vel_z,up) 1
@@ -303,10 +303,8 @@ proc TravelChgGoal {} {
 
     set w .trvchggoal
     if { [winfo exists $w] } { Raise $w ; return }
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
-    wm title $w "$TXT(chginggoal)/GPS Manager"
-    wm geometry $w +$DPOSX+$DPOSY
+    GMToplevel $w chginggoal +$DPOSX+$DPOSY {} \
+        [list WM_DELETE_WINDOW  "destroy $w"] {}
 
     frame $w.ft
     label $w.ft.tit -text $TXT(chginggoal)
@@ -323,7 +321,7 @@ proc TravelChgGoal {} {
     grid $w.fr.s -row 0 -column 1
     grid $w.fr.t2 -row 0 -column 2
 
-    button $w.ok -text Ok -command "destroy $w"
+    button $w.ok -text $TXT(ok) -command "destroy $w"
 
     pack $w.ft $w.fr $w.ok -pady 5
     update idletasks
@@ -380,17 +378,17 @@ proc TravelRealTimeOn {} {
 
 proc TravelSetUp {dsp} {
     # set up/change the contents of the travel display $dsp
-    global Travel WConf TXT MESS DPOSX DPOSY COLOUR MAPFTSIZES
+    global Travel WConf TXT MESS DPOSX DPOSY COLOUR
 
     # used explicitly elsewhere
     set w .travsetup
     if { [winfo exists $w] } { bell ; Raise $w ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
-    wm title $w "$TXT(travdsetup)/GPS Manager"
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> "TravelSUAction ok $dsp"
+    set Travel(font,new) [set Travel(font,txt) ""]
+
+    GMToplevel $w travdsetup +$DPOSX+$DPOSY {} \
+        [list WM_DELETE_WINDOW  "destroy $w"] \
+	[list <Key-Return> "TravelSUAction ok $dsp"]
 
     label $w.tit -text "$TXT(travdsetup) $dsp"
     frame $w.fr -relief flat -borderwidth 5
@@ -447,19 +445,16 @@ proc TravelSetUp {dsp} {
     grid [BalloonButton $w.fr.frl.frb.bhlp trvhlpbxs]
     grid $w.fr.frl.frb -row 1 -column 2 -sticky n
 
-    # options: font size
+    # options: font
     frame $w.fr.fro -borderwidth 1 -bg $COLOUR(messbg)
-    menubutton $w.fr.fro.fts -text $TXT(fntsize) -menu $w.fr.fro.fts.m
-    menu $w.fr.fro.fts.m
-    foreach s $MAPFTSIZES {
-	$w.fr.fro.fts.m add command -label $s \
-		-command "TravelSUAction font $dsp $s"
-    }
-    grid $w.fr.fro.fts
+    button $w.fr.fro.ftsel -text $TXT(optTRAVELFONT) -relief raised \
+	-command "TravelSUAction font $dsp \[GMSelectFont\]"
+    label $w.fr.fro.ft -textvariable Travel(font,txt) -width 40
+    grid $w.fr.fro.ftsel $w.fr.fro.ft
 
-    # on, cancel buttons
+    # ok, cancel buttons
     frame $w.fr.frbs
-    button $w.fr.frbs.ok -text Ok \
+    button $w.fr.frbs.ok -text $TXT(ok) \
 	    -command "destroy $w ; TravelSUAction ok $dsp"
     button $w.fr.frbs.cnc -text $TXT(cancel) -command "destroy $w"
     grid $w.fr.frbs.ok
@@ -496,14 +491,8 @@ proc TravelSUMove {how box lref x y} {
 	    if { $Travel(move,$box) != "" } {
 		destroy $tb
 	    } else { set Travel(move,$box) in }
-	    toplevel $tb
-	    wm resizable $tb 0 0
-	    wm overrideredirect $tb 1
-	    wm geometry $tb \
-		   +[expr $x+[winfo rootx $pb]+9]+[expr $y+[winfo rooty $pb]+9]
-	    label $tb.mess -text $el -relief groove -bg $COLOUR(ballbg) \
-		    -fg $COLOUR(ballfg)
-	    pack $tb.mess
+	    NewBalloon $tb $el \
+		+[expr $x+[winfo rootx $pb]+9]+[expr $y+[winfo rooty $pb]+9]
 	    set Travel(move,$box,el) $el
 	    set Travel(move,$box,ix) $ix
 	}
@@ -553,8 +542,8 @@ proc TravelSUMove {how box lref x y} {
 proc TravelSUAction {act dsp args} {
     # deal with user action when setting up the travel display number $dsp
     #  $act in {ok, add, addlabelled, remove, font}
-    #  $args is font size (in $MAPFTSIZES) if $act==font
-    global Travel WConf TXT
+    #  $args contains result of proc GMSelectFont if $act==font
+    global Travel WConf TXT TRAVELFONT TkDefaultFont
 
     set w .travsetup
     set bxfrom $w.fr.frl.bxa ; set bxto $w.fr.frl.bxb
@@ -619,15 +608,26 @@ proc TravelSUAction {act dsp args} {
 	    }
 	}
 	font {
-	    # if $args is an integer it is the size in points, otherwise
-	    #  the default of Tcl/Tk for the fixed font is used
-	    set Travel(font) [GFixedFont $args]
-	    foreach e $Travel(els) {
-		$fr.fri.f$dsp.$e configure -font $Travel(font)
-		$fr.fri.f$dsp.t_$e configure -font $Travel(font)
+	    if { [set f [lindex $args 0]] != "" } {
+		if { [set ft $f] == "default" } {
+		    set ft $TXT(default)
+		    if { [set f $TRAVELFONT] == "default" } {
+			set f $TkDefaultFont
+		    }
+		}
+		set Travel(font,txt) $ft
+		set Travel(font,new) $f
 	    }
 	}
 	ok {
+	    if { $Travel(font,new) != "" } {
+		set Travel(font) $Travel(font,new)
+		TravelInitFonts recreate
+		foreach e $Travel(els) {
+		    $fr.fri.f$dsp.$e configure -font $Travel(font)
+		    $fr.fri.f$dsp.t_$e configure -font $Travel(font)
+		}
+	    }
 	    if { $Travel(dsup,cfels) != $Travel(conf,$dsp) } {
 		set Travel(conf,$dsp) $Travel(dsup,cfels)
 		foreach s [grid slaves $fr.fri.f$dsp] { grid forget $s }
@@ -638,6 +638,41 @@ proc TravelSUAction {act dsp args} {
     return
 }
 
+proc TravelInitFonts {how} {
+    # create/recreate auxiliary fonts for travel display
+    #  $how=="recreate" means that the $Travel(font) changed and
+    #                 the auxiliary fonts must be remade
+    # two variants of the travel frame font are at stake and
+    #  have fixed names:  travelfontb, travelfontb2
+    # recreating a font automatically updates widgets using it
+    #  as the name is the same
+    global Travel 
+
+    if { $how == "recreate" } {
+	font delete travelfontb travelfontb2
+    } elseif { ! [catch {set $Travel(fontb)}] } { return }
+
+    set avps [font actual $Travel(font)]
+    foreach {a v} $avps {
+	set [string replace $a 0 0] $v
+    }
+    if { $size > 0 } { set d2 2 } else { set d2 -2 }
+    if { $weight == "bold" } {
+	# change the slant to make it different
+	if { $slant == "italic" } {
+	    set opts "-slant roman"
+	} else { set opts "-slant italic" }
+    } else { set opts "-weight bold" }
+    set fb [eval font create travelfontb $avps]
+    eval font configure $fb $opts
+    set Travel(fontb) $fb
+    append opts " -size " [expr $size+$d2]
+    set fb2 [eval font create travelfontb2 $avps]
+    eval font configure $fb2 $opts
+    set Travel(fontb2) $fb2
+    return
+}
+
 ##### warnings
 
 proc TravelWarnConfigure {} {
@@ -655,11 +690,9 @@ proc TravelWarnConfigure {} {
 	set Travel(wcfg,$s) $Travel($p)
     }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
-    wm title $w "$TXT(warnconf)/GPS Manager"
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { TravelWCAction ok }
+    GMToplevel $w warnconf +$DPOSX+$DPOSY {} \
+        [list WM_DELETE_WINDOW  "destroy $w"] \
+	{<Key-Return> {TravelWCAction ok}}
 
     label $w.tit -text $TXT(warnconf)
     frame $w.fr -relief flat -borderwidth 5
@@ -725,7 +758,7 @@ proc TravelWarnConfigure {} {
     grid $fr.fs -row $row_vspeed -column 1 -columnspan 3 -sticky w
 
     frame $w.fr.frbs
-    button $w.fr.frbs.ok -text Ok \
+    button $w.fr.frbs.ok -text $TXT(ok) \
 	    -command "$w.fr.frbs.ok configure -state normal ; \
 	              TravelWCAction ok $w"
     button $w.fr.frbs.cnc -text $TXT(cancel) -command "destroy $w"
@@ -830,10 +863,10 @@ proc TravelDoWarn {mess level} {
 	destroy .travelwarn
     }
     set Travel(warnprior) $n
-    toplevel .travelwarn
+    GMToplevel .travelwarn "" +[winfo rootx $Map]+[winfo rooty $Map] {} {} {}
     wm resizable .travelwarn 0 0
     wm overrideredirect .travelwarn 1
-    wm geometry .travelwarn +[winfo rootx $Map]+[winfo rooty $Map]
+
     message .travelwarn.m -aspect 800 -text $mess \
 	    -font $Travel(font) -fg $MAPCOLOUR(trvwrn$level)
     pack .travelwarn.m
