@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2009 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  27 September 2008
+#  Last change:  18 December 2009
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -53,6 +53,7 @@
 #                 also define $OPTMENUNAMES($i) to be an array of external
 #                 names and $OPTMENUPREFIX($i) that is prefixed to the
 #                 selected value to index the array of external names
+#      font       a font description
 #      array      for a set of options all of the same type; one must
 #                  set $OPTELTYPE($i) to it, and $OPTELS($i) to the list
 #                  of options in the set; type cannot be "perms"
@@ -174,15 +175,12 @@ set OPTTYPE(DEFTLNWIDTH) fixedmenu
 set OPTMENUCONTS(DEFTLNWIDTH) {1 2 3 4 5 6 7 8}
 
 set OPTTYPE(_Fonts) group
-set OPTGRPL(_Fonts) {FONTSIZE FIXEDFONTSIZE MAPFONTSIZE TRAVELFONTSIZE}
-set OPTTYPE(FONTSIZE) fixedmenu
-set OPTMENUCONTS(FONTSIZE) $MAPFTSIZES
-set OPTTYPE(FIXEDFONTSIZE) fixedmenu
-set OPTMENUCONTS(FIXEDFONTSIZE) $MAPFTSIZES
-set OPTTYPE(MAPFONTSIZE) fixedmenu
-set OPTMENUCONTS(MAPFONTSIZE) $MAPFTSIZES
-set OPTTYPE(TRAVELFONTSIZE) fixedmenu
-set OPTMENUCONTS(TRAVELFONTSIZE) $MAPFTSIZES
+set OPTGRPL(_Fonts) {DEFAULTFONT FIXEDFONT MAPFONT TRAVELFONT PLOTFONT}
+set OPTTYPE(DEFAULTFONT) font
+set OPTTYPE(FIXEDFONT) font
+set OPTTYPE(MAPFONT) font
+set OPTTYPE(TRAVELFONT) font
+set OPTTYPE(PLOTFONT) font
 
 set OPTTYPE(_Geom) group
 set OPTGRPL(_Geom) {MAXMENUITEMS LISTWIDTH LISTHEIGHT _sep
@@ -236,30 +234,31 @@ set OPTTYPE(_sep) sep
 
 proc OutDatedOptions {} {
     # check if options read from preferences file are outdated
-    global OPTFILEVERSION VERSION MESS GPSREC MWINDOWSCONF
+    global OPTFILEVERSION VERSION MESS GPSREC MWINDOWSCONF FONTSIZE
 
-    if { [catch {set OPTFILEVERSION}] } {
-	# this is a pre-4.0 preferences file
-	AboutInfo ""
-	GMMessage $MESS(outdatedprefs)
-	return 1
+    # check that this is not a pre-4.0 preferences file
+    if { ! [catch {set OPTFILEVERSION}] } {
+	set r [string compare $OPTFILEVERSION $VERSION]
+	# correct outdated values
+	if { [llength $GPSREC]>1 && [lindex $GPSREC 0] == "Garmin" } {
+	    # no need for Garmin receiver model after version 4.0.1
+	    set GPSREC Garmin ; set r 1
+	}
+	if { $MWINDOWSCONF == "single" } {
+	    # no longer supported after 5.2
+	    set MWINDOWSCONF map ; set r 1
+	}
+	if { ! [catch {set FONTSIZE}] } {
+	    # no longer supported after 6.4
+	    set r 1
+	}
+	if { $r == 0 || "${VERSION}-patched" == $OPTFILEVERSION } {
+	    return 0
+	}
     }
-    set r [string compare $OPTFILEVERSION $VERSION]
-    # correct outdated values
-    if { [llength $GPSREC]>1 && [lindex $GPSREC 0] == "Garmin" } {
-	# no need for Garmin receiver model after version 4.0.1
-	set GPSREC Garmin ; set r 1
-    }
-    if { $MWINDOWSCONF == "single" } {
-	# no longer supported after 5.2
-	set MWINDOWSCONF map ; set r 1
-    }
-    if { $r && "${VERSION}-patched" != $OPTFILEVERSION } {
-	AboutInfo ""
-	GMMessage $MESS(outdatedprefs)
-	return 1
-    }
-    return 0
+    AboutInfo ""
+    GMMessage $MESS(outdatedprefs)
+    return 1
 }
 
 proc SetOptions {} {
@@ -272,12 +271,9 @@ proc SetOptions {} {
     set w .opts
     if { [winfo exists $w] } { Raise $w ; bell ; return 0 }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempOpts cnc ; set waitopts 0 }
-    wm title $w "$TXT(options)/GPS Manager"
-    wm transient $w .
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set TempOpts ok ; set waitopts 0 }
+    GMToplevel $w options +$DPOSX+$DPOSY . \
+        {WM_DELETE_WINDOW {set TempOpts cnc ; set waitopts 0}} \
+	{<Key-Return> {set TempOpts ok ; set waitopts 0}}
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(messbg)
 
@@ -300,9 +296,10 @@ proc SetOptions {} {
     }
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempOpts ok ; set waitopts 0 }
+    button $w.fr.bs.ok -text $TXT(ok) \
+	-command { set TempOpts ok ; set waitopts 0 }
     button $w.fr.bs.cnc -text $TXT(cancel) \
-	    -command { set TempOpts cnc ; set waitopts 0 }
+	-command { set TempOpts cnc ; set waitopts 0 }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
     if { $row == -1 } {
@@ -385,8 +382,8 @@ proc ShowOption {v ref val type vf es lv row col} {
     #  $v is identifier (normally a variable)
     #  $ref is a reference used to keep the initial value of the option
     #  $val is a reference to the option storage to be set
-    #  $tipe in {boolean, nat, float, any, colour, perms, oneof,
-    #    menu, textmenu, fixedmenu, fixedtextmenu, array, group, sep} unless
+    #  $tipe in {boolean, nat, float, any, colour, perms, oneof, menu,
+    #   textmenu, fixedmenu, fixedtextmenu, font, array, group, sep} unless
     #    $lv!="Main" in which case it cannot be in {array, group}
     #  $vf is the parent window (frame) of the widgets to create
     #  $es is list with a pair for each created entry; the pair has the
@@ -540,6 +537,16 @@ proc ShowOption {v ref val type vf es lv row col} {
 	    label $vf.bc -relief groove -background [set $val] -width 2
 	    pack $vf.b $vf.bc -side left
 	}
+	font {
+	    global $v
+	    set f [set $val]
+	    set OptOld[set lv]($ref) $f
+	    button $vf.b -text $TXT(opt$ref) -relief raised \
+		    -command "ChooseFont $v $val $vf .opts"
+	    if { $f == "default" } { set f $TXT(default) }
+	    label $vf.l -text $f -width 40
+	    pack $vf.b $vf.l -side left
+	}
 	group {
 	    if { $lv != "Main" } {
 		GMMessage "Bad option type for $v: groups only at top level"
@@ -582,12 +589,9 @@ proc ShowMoreOptions {g} {
     set w .mopts
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempMOpts cnc }
-    wm title $w "$TXT(options)/GPS Manager"
-    wm transient $w .opts
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set TempMOpts ok }
+    GMToplevel $w options +$DPOSX+$DPOSY .opts \
+        {WM_DELETE_WINDOW {set TempOpts cnc}} \
+	{<Key-Return> {set TempOpts ok}}
 
     frame $w.fr -relief flat -borderwidth 5 -bg $COLOUR(dialbg)
 
@@ -620,7 +624,7 @@ proc ShowMoreOptions {g} {
     }
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempMOpts ok }
+    button $w.fr.bs.ok -text $TXT(ok) -command { set TempMOpts ok }
     button $w.fr.bs.cnc -text $TXT(cancel) -command { set TempMOpts cnc }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
@@ -684,12 +688,9 @@ proc ShowOptionsArray {a} {
     set w .aopts
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempAOpts cnc }
-    wm title $w "$TXT(options)/GPS Manager"
-    wm transient $w .opts
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set TempAOpts ok }
+    GMToplevel $w options +$DPOSX+$DPOSY .opts \
+        {WM_DELETE_WINDOW {set TempOpts cnc}} \
+	{<Key-Return> {set TempOpts ok}}
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
 
@@ -720,7 +721,7 @@ proc ShowOptionsArray {a} {
     }
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempAOpts ok }
+    button $w.fr.bs.ok -text $TXT(ok) -command { set TempAOpts ok }
     button $w.fr.bs.cnc -text $TXT(cancel) -command { set TempAOpts cnc }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
@@ -879,7 +880,7 @@ proc ChooseColour {v val bw mw} {
     # create modal dialog for choosing a colour
     #  $v is a global variable for the option storage (it may be an array)
     #  $val is a reference to the option storage to be set (it may be
-    #   the an array name and index)
+    #   the array name and index)
     #  $bw is window with button .b and label .bc to configure
     #  $mw is toplevel window using this proc
     global $v TXT TempCol ChColour ColComp DPOSX DPOSY COLOUR
@@ -888,12 +889,9 @@ proc ChooseColour {v val bw mw} {
     set w .copts
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempCol cnc }
-    wm title $w "$TXT(options)/GPS Manager"
-    wm transient $w $mw
-    set x [expr $DPOSX+100] ; set y [expr $DPOSY+100]
-    wm geometry $w +$x+$y
+    GMToplevel $w options +[expr $DPOSX+100]+[expr $DPOSY+100] $mw \
+        {WM_DELETE_WINDOW {set TempOpts cnc}} \
+	{<Key-Return> {set TempOpts ok}}
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
     frame $w.fr.fr1
@@ -926,7 +924,7 @@ proc ChooseColour {v val bw mw} {
     canvas $self.f1.demo -bd 0 -width 100 -height 15 -bg $ChColour
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempCol ok }
+    button $w.fr.bs.ok -text $TXT(ok) -command { set TempCol ok }
     button $w.fr.bs.cnc -text $TXT(cancel) \
 	-command { set TempCol cnc }
 
@@ -1007,3 +1005,22 @@ proc PermDigToList {c} {
     set x [expr $c-48]
     return "[expr ($x&4)!=0] [expr ($x&2)!=0] [expr $x&1]"
 }
+
+proc ChooseFont {v val bw mw} {
+    # choose a font using proc GMSelectFont and configure options windows
+    #  $v is a global variable for the option storage (it may be an array)
+    #  $val is a reference to the option storage to be set (it may be
+    #   an array name and index)
+    #  $bw is window with button .b and label .l to configure
+    #  $mw is toplevel window using this proc
+    global $v TXT
+
+    $bw.b configure -state normal
+    if { [set f [GMSelectFont]] == "" } { return }
+    set $val $f
+    if { $f == "default" } { set f $TXT(default) }
+    $bw.l configure -text $f
+    update idletasks
+    return
+}
+
