@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: projections.tcl
-#  Last change:  21 September 2008
+#  Last change:  12 February 2009
 #
 
 # Includes contributions by
@@ -1072,12 +1072,9 @@ proc ProjParams {how proj data} {
 	    MAPPROJDEPDATUM MAPPARTPROJ UPName UPAbbrev
 
     catch {unset Param}
-    toplevel .proj
-    wm protocol .proj WM_DELETE_WINDOW { set ProjRes ok }
-    wm title .proj "$TXT(projection)/GPS Manager"
-    wm transient .proj
-    wm geometry .proj +$EPOSX+$EPOSY
-    bind .proj <Key-Return> { set ProjRes ok }
+    GMToplevel .proj projection +$EPOSX+$EPOSY {} \
+        {WM_DELETE_WINDOW {set ProjRes ok}} \
+        {<Key-Return> {set ProjRes ok}}
 
     frame .proj.fr -relief flat -borderwidth 5 -bg $COLOUR(selbg)
     label .proj.fr.title -text "???" -relief sunken
@@ -1632,12 +1629,9 @@ proc ChooseDatumProjection {args} {
 
     set CDPDatum $Datum ; set CDPProj $MapProjection
     set CDPProjT $TXT(PRJ$MapProjection)
-    toplevel .cdp
-    wm protocol .cdp WM_DELETE_WINDOW { set ProjRes ok }
-    wm title .cdp "$TXT(projection)/GPS Manager"
-    wm transient .cdp
-    wm geometry .cdp +$EPOSX+$EPOSY
-    bind .cdp <Key-Return> { set ProjRes ok }
+    GMToplevel .cdp projection +$EPOSX+$EPOSY {} \
+        {WM_DELETE_WINDOW {set ProjRes ok}} \
+        {<Key-Return> {set ProjRes ok}}
 
     frame .cdp.fr -relief flat -borderwidth 5 -bg $COLOUR(selbg)
     label .cdp.fr.title -text "???" -relief sunken
