@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: projs_main.tcl
-#  Last change:  15 September 2008
+#  Last change:  17 June 2009
 #
 
 # Includes contributions by
@@ -1310,12 +1310,14 @@ proc ProjStereogrComputeAux {data datum} {
 	set t [expr sin($phi0)]
 	set X [expr 2*atan([SSFunc_ $phi0 $t $e])-1.5707963267948966]
 	set t [expr $t*$e]
-	set ${data}(m_0) [expr 2*$k0*cos($phi0)/sqrt(1-$t*$t)]
+	set ${data}(m_0) [expr 2*$k0*cos($phi0)/sqrt(1.0-$t*$t)]
 	set ${data}(m_1) [expr sin($X)]
 	set ${data}(m_2) [expr cos($X)]
     } else {
 	set mode equat
 	set ${data}(m_0) [expr 2*$k0]
+	set ${data}(m_1) 0
+	set ${data}(m_2) 1.0
     }
     set ${data}(m_3) $mode
     return
@@ -1346,8 +1348,8 @@ proc ProjStereogrPoint {data latd longd datum} {
 	    set sinX1 [set ${data}(m_1)]
 	    set cosX1 [set ${data}(m_2)]
 	    set A [expr $akm1/($cosX1*(1+$sinX1*$sinX+$cosX1*$cosX*$coslam))]
-	    set x [expr $A*$cosX]
 	    set y [expr $A*($cosX1*$sinX-$sinX1*$cosX*$coslam)]
+	    set x [expr $A*$cosX]
 	}
 	n_pole {
 	    set x [expr $akm1*[ExpRedLat $phi $sinphi $e]]
@@ -1376,14 +1378,18 @@ proc ProjStereogrInvert {data x y} {
     }
     set rho [Hypot $x $y]
     set spole 0
-    switch [set ${data}(m_3)] {
+    switch [set m [set ${data}(m_3)]] {
 	obliq -
 	equat {
 	    set sinX1 [set ${data}(m_1)]
 	    set cosX1 [set ${data}(m_2)]
 	    set tp [expr 2*atan2($rho*$cosX1,$akm1)]
 	    set cosphi [expr cos($tp)] ; set sinphi [expr sin($tp)]
-	    set phi_l [Aasin [expr $cosphi*$sinX1+$y*$sinphi*$cosX1/$rho]]
+	    if { $rho == 0.0 } {
+		set phi_l [Aasin [expr $cosphi*$sinX1]]
+	    } else {
+		set phi_l [Aasin [expr $cosphi*$sinX1+($y*$sinphi*$cosX1/$rho)]]
+	    }
 	    set tp [expr tan(0.5*(1.5707963267948966+$phi_l))]
 	    set x [expr $x*$sinphi]
 	    set y [expr $rho*$cosX1*$cosphi-$y*$sinX1*$sinphi]
@@ -1393,14 +1399,14 @@ proc ProjStereogrInvert {data x y} {
 	n_pole {
 	    set y [expr -$y]
 	    set tp [expr -1.0*$rho/$akm1]
-	    set phi_l [expr -2*atan($tp)]
+	    set phi_l [expr 1.5707963267948966-2*atan($tp)]
 	    set halfpi -1.5707963267948966
 	    set halfe [expr -0.5*$e]
 	}
 	s_pole {
 	    set spole 1
 	    set tp [expr -1.0*$rho/$akm1]
-	    set phi_l [expr  -2*atan($tp)]
+	    set phi_l [expr 1.5707963267948966-2*atan($tp)]
 	    set halfpi -1.5707963267948966
 	    set halfe [expr -0.5*$e]
 	}
