@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: realtime.tcl
-#  Last change:  15 June 2005
+#  Last change:  12 February 2009
 #
 
 #### real time logging control
@@ -235,11 +235,8 @@ proc RealTimeLogWindow {} {
     trace variable PVTState w RTimeStateChange
     trace variable PVTInterval w RTimeIntervalChange
 
-    toplevel .pvt
-    wm protocol .pvt WM_DELETE_WINDOW RTimeCancel
-    wm title .pvt "$TXT(realtimelog)/GPS Manager"
-    set x [expr $MPOSX+10] ; set y [expr $MPOSY+80]
-    wm geometry .pvt +$x+$y
+    GMToplevel .pvt realtimelog +[expr $MPOSX+10]+[expr $MPOSY+80] {} \
+        {WM_DELETE_WINDOW RTimeCancel} {}
 
     label .pvt.tit -text $TXT(realtimelog)
 
@@ -481,18 +478,15 @@ proc SimulDriveOn {} {
     set SimulDrive(data) ""
     set SimulDrive(mess) ""
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { GMMessage $MESS(chgrecprot) }
-    wm title $w "$TXT(drivesim)/GPS Manager"
-    wm transient $w
-    wm geometry $w +$EPOSX+$EPOSY
-    bind $w <Key-Up> { SimulDriveChange speed 5 }
-    bind $w <Key-Down> { SimulDriveChange speed -5 }
-    bind $w <Key-Left> { SimulDriveChange turn 1 }
-    bind $w <Key-Right> { SimulDriveChange turn -1 }
-    bind $w <Key-space> { SimulDriveChange turnval 0 }
-    bind $w <Leave> { SimulDriveControl 0 }
-    bind $w <Enter> "focus $w ; SimulDriveControl 1"
+    GMToplevel $w drivesim +$EPOSX+$EPOSY {} \
+        {WM_DELETE_WINDOW {GMMessage $MESS(chgrecprot)}} \
+	[list <Key-Up> {SimulDriveChange speed 5} \
+	     <Key-Down> {SimulDriveChange speed -5} \
+	     <Key-Left> {SimulDriveChange turn 1} \
+	     <Key-Right> {SimulDriveChange turn -1} \
+	     <Key-space> {SimulDriveChange turnval 0} \
+	     <Leave> {SimulDriveControl 0} \
+	     <Enter> "focus $w ; SimulDriveControl 1"]
 
     frame $w.fr -borderwidth 2 -bg $COLOUR(messbg)
     frame $w.fr.frsw
