@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: recdefs.tcl
-#  Last change:  6 April 2006
+#  Last change:  26 February 2008
 #
-# Includes contributions by Matt Martin (matt.martin@ieee.org)
+# Includes contributions by Matt Martin (matt.martin_AT_ieee.org)
 #  marked "MGM contribution"
 #
 
@@ -48,6 +48,8 @@ switch $MYGPS {
 	} else { set RECTYPES {WP RT TR GR} }
 	set RECINFO {AL}
 	set ORIGRECTYPES $RECTYPES ; set ORIGRECINFO $RECINFO
+	# possible baud rates
+	set RECBAUDS [list 9600 19200 57600 115200 230400]
 	# character set for names
 	set RECNAMECHARS(Garmin) {^[-A-Z0-9]*$}
 	set RECNAMECHARS(Garmin,mess) "A..Z, 0..9, \"-\""
@@ -66,6 +68,8 @@ switch $MYGPS {
     Magellan {
 	# MGM contribution
 	set RECTYPES {WP RT TR GR}
+	# MF contribution: from recmodels.tcl, added 4800 for Meridian Platinum
+	set RECBAUDS [list 4800 9600 19200 57600 115200]
 	# character set for names
 	set RECNAMECHARS(Magellan) {.*}
 	set RECNAMECHARS(Magellan,mess) $TXT(any)
@@ -73,6 +77,12 @@ switch $MYGPS {
     }
 }
 
+## set the options that depend on the receiver
+
+RecModelChange $MYGPS
+
+## user may wish to have no tests...
+
 proc RecCanSendAnything {brand} {
     # use an "accept anything from receiver" setting
     #  $brand in {Garmin, Lowrance, Magellan}
