@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: search.tcl
-#  Last change:  29 April 2007
+#  Last change:  18 December 2009
 #
 
 proc Search {} {
@@ -38,12 +38,9 @@ proc Search {} {
     set SDatum $Datum
     set SearchWPSymbol $DEFAULTSYMBOL
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
-    wm title $w "$TXT(search)/GPS Manager"
-    wm transient $w .
-    wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> "DoSearch $w"
+    GMToplevel $w search +$DPOSX+$DPOSY . \
+        [list WM_DELETE_WINDOW "destroy $w"] \
+        [list <Key-Return> "DoSearch $w"] 
 
     frame $w.fr -relief flat -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.tit -text $TXT(search)
@@ -649,7 +646,7 @@ proc SearchResults {lp} {
     set ix [CreateGRFor srchres [SearchDescription] $lp]
     set w [OpenItem GR $ix]
     switch [GMSelect "$MESS(resultsin) $GRName($ix)" \
-	    [list Ok $TXT(another) $TXT(change) $TXT(cancel)] \
+	    [list $TXT(ok) $TXT(another) $TXT(change) $TXT(cancel)] \
 	    "ok another change cancel"] {
 	ok {
 	}
