@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: serial.tcl
-#  Last change:  23 October 2008
+#  Last change:  12 February 2009
 #
 # Includes contributions by Matt Martin (matt.martin_AT_ieee.org)
 #  marked "MGM contribution"
@@ -489,11 +489,8 @@ proc FailsInProgrWindow {mess} {
 
     set ProgrWGrabs [grab current]
     set SRecACKs 0 ; set SRecNAKs 0 ; set SPckts 0
-    toplevel .inprogr
-    wm protocol .inprogr WM_DELETE_WINDOW { AbortComm }
-    wm title .inprogr "$TXT(commrec)/GPS Manager"
-    wm transient .inprogr
-    wm geometry .inprogr +$EPOSX+$EPOSY
+    GMToplevel .inprogr commrec +$EPOSX+$EPOSY {} \
+        {WM_DELETE_WINDOW AbortComm} {}
 
     frame .inprogr.fr -borderwidth 5 -bg $COLOUR(messbg)
     label .inprogr.fr.title -text "..." -relief sunken
