@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: symbols.tcl
-#  Last change:  10 February 2008
+#  Last change:  16 March 2009
 #
 
 ## GPSMan symbols and display options
@@ -766,10 +766,8 @@ proc SymbolCustomMenu {} {
 	cmenu ""
     }
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
-    wm title $w "$TXT(syusrmenu)/GPS Manager"
-    wm geometry $w +$DPOSX+$DPOSY
+    GMToplevel $w syusrmenu +$DPOSX+$DPOSY {} \
+        [list WM_DELETE_WINDOW "destroy $w"] {}
 
     label $w.tit -text $TXT(syusrmenu)
     frame $w.fr -relief flat -borderwidth 5
@@ -1048,17 +1046,11 @@ proc SyCMenuMove {how box x y} {
 	start {
 	    set ix [ImageListbox index $box $y]
 	    set txt [lindex [ImageListbox get $box $ix] 0]
-	    if { $SyCMenu($box,move) != "" } {
-		destroy $tb
-	    } else { set SyCMenu($box,move) in }
-	    toplevel $tb
-	    wm resizable $tb 0 0
-	    wm overrideredirect $tb 1
-	    wm geometry $tb \
-		+[expr $x+[winfo rootx $box]+9]+[expr $y+[winfo rooty $box]+9]
-	    label $tb.mess -text $txt -relief groove -bg $COLOUR(ballbg) \
-		    -fg $COLOUR(ballfg)
-	    pack $tb.mess
+	    if { $SyCMenu($box,move) == "" } {
+		set SyCMenu($box,move) in
+	    }
+	    NewBalloon $tb $txt \
+	     +[expr $x+[winfo rootx $box]+9]+[expr $y+[winfo rooty $box]+9]
 	    set SyCMenu($box,move,tag) [ImageListbox gettags $box $ix]
 	    set SyCMenu($box,move,txt) $txt
 	    set SyCMenu($box,move,ix) $ix
@@ -1089,7 +1081,8 @@ proc SyCMenuMove {how box x y} {
 		set fix [ImageListbox index $box $y]
 		set ix $SyCMenu($box,move,ix)
 		if { $fix != $ix } {
-		    if { [regexp {^@@@=} [set tag $SyCMenu($box,move,tag)]] } {
+		    if { [regexp {^@@@=} \
+			      [set tag $SyCMenu($box,move,tag)]] } {
 			set img ""
 		    } else { set img $SYMBOLIMAGE($tag) }
 		    ImageListbox delete $box $ix
@@ -1099,7 +1092,9 @@ proc SyCMenuMove {how box x y} {
 	    }
 	}
 	leave {
-	    if { $SyCMenu($box,move) == "in" } { set SyCMenu($box,move) "out" }
+	    if { $SyCMenu($box,move) == "in" } {
+		set SyCMenu($box,move) out
+	    }
 	}
     }
     return
