@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: trtort.tcl
-#  Last change:  26 May 2005
+#  Last change:  18 December 2009
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -72,11 +72,8 @@ proc GMTRtoLine {wh window} {
     set TRCv($w,linedispl) 0 ; set TRCv($w,TRdispl) $mapped
     set TRCv($w,mouseonscale) 0
 
-    toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "TRCvCancel $w"
-    wm title $w "$TXT(TRto$wh)/GPS Manager"
-    wm transient $w
-    wm geometry $w +[expr $DPOSX+100]+[expr $DPOSY+100]
+    GMToplevel $w TRto$wh +[expr $DPOSX+100]+[expr $DPOSY+100] {} \
+        [list WM_DELETE_WINDOW "TRCvCancel $w"] {}
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.from -text [format $TXT(fromTR) $trname]
@@ -101,7 +98,7 @@ proc GMTRtoLine {wh window} {
     if { $mapped } { $w.fr.act.dtr configure -state disabled }
 
     frame $w.fr.bts
-    button $w.fr.bts.ok -text Ok -command "TRCvCommit$wh $w"
+    button $w.fr.bts.ok -text $TXT(ok) -command "TRCvCommit$wh $w"
     button $w.fr.bts.cnc -text $TXT(cancel) -command "TRCvCancel $w"
 
     pack $w.fr.from $w.fr.sep $w.fr.npts $w.fr.npscl -side top
@@ -117,16 +114,15 @@ proc TRCvNumberChange {w} {
 
     if { $TRCv($w,mouseonscale) \
 	    || $TRCv($w,npoints) == $TRCv($w,npsold) } { return }
-    SlowOpWindow $TXT(comp)
+    set sid [SlowOpWindow $TXT(comp)]
     set TRCv($w,npsold) $TRCv($w,npoints)
     if { [set l [TRCvSimpl $w $TRCv($w,npoints)]] != 0 } {
 	set TRCv($w,line) $l
-	SlowOpFinish ""
 	TRCvDisplLine $w
     } else {
-	SlowOpFinish ""
 	set TRCv($w,npoints) $TRCv($w,npsold)
     }
+    SlowOpFinish $sid ""
     return
 }
 
@@ -136,7 +132,7 @@ proc TRCvCommitRT {w} {
     global TRCv EdWindow PositionFormat CREATIONDATE GRName DEFAULTSYMBOL \
 	    DEFAULTDISPOPT TXT MESS MYGPS
 
-    SlowOpWindow $TXT(create)
+    set sid [SlowOpWindow $TXT(create)]
     set datum $TRCv($w,datum)
     # BSB contribution: empty date if Lowrance receiver
     if { $CREATIONDATE && $MYGPS != "Lowrance" } {
@@ -145,7 +141,7 @@ proc TRCvCommitRT {w} {
     set wps "" ; set n 0
     foreach p $TRCv($w,line) {
 	if { [SlowOpAborted] } {
-	    SlowOpFinish ""
+	    SlowOpFinish $sid ""
 	    return
 	}
 	set id [format "ZT%04d" $n]
@@ -163,7 +159,7 @@ proc TRCvCommitRT {w} {
 	set ix [CreateItem WP $data]
 	lappend wps $id
     }
-    SlowOpFinish ""
+    SlowOpFinish $sid ""
     CreateGRFor =TR-RT $TXT(obsTRToRT) [list [list WP $wps]]
     TRCvCancel $w
     if { [winfo exists $EdWindow(RT)] } {
@@ -261,7 +257,7 @@ proc TRCvDisplLine {w} {
 
     $Map delete expconv=$w
     if { $TRCv($w,linedispl) } {
-	SlowOpWindow $TXT(displ)
+	set sid [SlowOpWindow $TXT(displ)]
 	set tgspt [list exp=$w expconv=$w sq2]
 	set tgsln [list exp=$w expconv=$w line]
 	set ps $TRCv($w,line) ; set datum $TRCv($w,datum)
@@ -288,7 +284,7 @@ proc TRCvDisplLine {w} {
 	    set x $x2 ; set y $y2
 	    incr i
 	}
-	SlowOpFinish ""
+	SlowOpFinish $sid ""
     }
     SetMapBounds
     return
