@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: util.tcl
-#  Last change:  25 August 2008
+#  Last change:  18 December 2009
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -684,6 +684,25 @@ proc ShowTEdit {entry string flag} {
     return
 }
 
+## operations on text
+
+proc TextCheckLimit {txt max bgix errbgix} {
+    # change the background of text characters that are beyond the
+    #  given number of characters
+    #  $bgix is the normal background index in COLOUR array
+    #  $errbgix is the error background index in COLOUR array
+    # a tag "ob" is used for this
+    global COLOUR
+
+    $txt tag delete ob
+    set max "1.0+$max chars"
+    if { [$txt compare end > $max] } {
+	$txt tag add ob $max end
+	$txt tag configure ob -background $COLOUR($errbgix)
+    } else { $txt configure -background $COLOUR($bgix) }
+    return
+}
+
 ## operations on data
 
 proc CompareVals {arr i j} {
@@ -764,6 +783,23 @@ proc Intersect1 {l1 l2} {
     return ""
 }
 
+proc ListReplace {l olds news} {
+    # replace in list $l any ocurrences of elements of list $olds
+    #  by the aligned elements of list $news
+    # $l may have repeated elements
+    # return pair with flag set if there were replacements and resulting
+    #  list
+
+    set chg 0
+    foreach o $olds n $news {
+	foreach i [lsearch -exact -all $l $o] {
+	    set l [lreplace $l $i $i $n]
+	    incr chg
+	}
+    }
+    return [list $chg $l]
+}
+
 proc FindArrayIndices {array val errix} {
     # check that $val is an element of $array (possibly with repeated values)
     # return indices of $val on success and $errix on error
@@ -970,9 +1006,9 @@ proc BalloonButton {path lst} {
     global SYMBOLIMAGE
 
     button $path -image $SYMBOLIMAGE(interr) \
-	    -command "BalloonCreate 8000 $lst"
+	    -command "BalloonCreate 12000 $lst"
     bind $path <Motion> { BalloonMotion %X %Y }
-    # bind $path <Leave> BalloonDestroy    
+    bind $path <Enter> BalloonDestroy    
     return $path
 }
 
@@ -980,11 +1016,27 @@ proc Balloon {lst} {
     global BalloonStart BalloonHelp
 
     if { $BalloonHelp } {
-	set BalloonStart [after 2000 "BalloonCreate 5000 $lst"]
+	set BalloonStart [after 2000 "BalloonCreate 10000 $lst"]
     }
     return
 }
 
+proc NewBalloon {blln mess geom} {
+
+    global COLOUR
+
+    destroy $blln
+    toplevel $blln
+    wm resizable $blln 0 0
+    wm overrideredirect $blln 1
+    wm geometry $blln $geom
+    wm group $blln .
+    label $blln.mess -text $mess -relief groove -bg $COLOUR(ballbg) \
+	-fg $COLOUR(ballfg)
+    pack $blln.mess
+    return
+}
+
 proc BalloonCreate {timeout args} {
     #  $timeout is either 0 or msecs to destroy balloon help
     global BalloonX BalloonY BalloonEnd TXT COLOUR
@@ -999,14 +1051,7 @@ proc BalloonCreate {timeout args} {
 	    }
 	}
     }
-    destroy .balloon
-    toplevel .balloon
-    wm resizable .balloon 0 0
-    wm overrideredirect .balloon 1
-    wm geometry .balloon +$BalloonX+$BalloonY
-    label .balloon.mess -text $mess -relief groove -bg $COLOUR(ballbg) \
-	    -fg $COLOUR(ballfg)
-    pack .balloon.mess
+    NewBalloon .balloon $mess +$BalloonX+$BalloonY
     if { $timeout } {
 	set BalloonEnd [after $timeout "destroy .balloon"]
     } else { set BalloonEnd "" }
@@ -1102,20 +1147,23 @@ proc TurnObject {trk data} {
     return
 }
 
-## varia
+proc CanvasChangeFont {cv v vref} {
+    # change font in canvas using proc GMSelectFont
+    #  $v is name to declare as global
+    #  $vref is reference to set (variable name or array and index)
+    # all canvas items with tag txt will be reconfigured
+    global $v TkDefaultFont
 
-proc GFixedFont {size} {
-    # return fixed font of given size
-    # if $size is an integer it is taken to be the size in points, otherwise
-    #  the default for the fixed font is used
-    global FixedFont
-
-    if { [regexp {^[0-9]+$} $size] } {
-	return "fixed $size"
+    if { [set f [GMSelectFont $TkDefaultFont]] == {} } { return } 
+    set $vref $f
+    foreach it [$cv find withtag txt] {
+	$cv itemconfigure $it -font $f
     }
-    return $FixedFont
+    return
 }
 
+## varia
+
 proc Measure {text} {
     # length of a string plus 2
 
@@ -1241,17 +1289,26 @@ proc DelChText {w} {
     return
 }
 
-### quoting when writing
+### quoting
+
+proc QuoteString {string} {
+    # return string under quotes if it has spaces, escaping any quotes in it
+
+    if { [regexp { } $string] } {
+	regsub -all {\"} $string "\\\"" string
+	return \"$string\"
+    }
+    return $string
+}
 
 proc WriteQuoteList {file list} {
     # write each element in list under quotes and escape quotes in it if any
     # do not insert newline at end
 
     set n 0
-    while { $list != "" } {
+    foreach x $list {
 	if { $n != 0 } { puts -nonewline $file " " }
-	WriteQuote $file [lindex $list 0]
-	set list [lreplace $list 0 0]
+	puts -nonewline  $file [QuoteString $x]
 	set n 1
     }
     return
@@ -1261,9 +1318,7 @@ proc WriteQuote {file string} {
     # write under quotes $string and escape quotes in it if any
     # do not insert newline at end
 
-    puts -nonewline $file "\""
-    regsub -all {"} $string "\\\"" new
-    puts -nonewline $file ${new}\"
+    puts -nonewline $file [QuoteString $string]
     return
 }
 
@@ -1311,3 +1366,74 @@ proc ColourMatch {r g b ncs} {
     return $match
 }
 
+##### posting to a web service
+
+proc WebPost {service login url fieldname message maxlength} {
+    # edit and post a message to a web site
+    #  $service is the service name used when asking for login information
+    #  $login is set if authorization required
+    #  $maxlength == -1  when message can be of any length
+    # use TclCurl
+    # return 0 on failure
+    global GMResConf MESS TXT COLOUR DPOSX DPOSY
+
+    if { [catch {package require TclCurl}] } { return 0 }
+    set w .webpost
+    set gs [grab current]
+    GMToplevel $w message +$DPOSX+$DPOSY {} . \
+	{WM_DELETE_WINDOW {set GMResConf 0}}
+
+    frame $w.fr -borderwidth 5 -bg $COLOUR(confbg)
+    label $w.fr.tit -text $TXT(message)
+    frame $w.fr.ft
+    set txt $w.fr.ft.txt
+    text $txt -wrap word  -width 70 -height 10 \
+	-exportselection true -yscrollcommand [list $w.fr.ft.sv set]
+    $txt insert 1.0 $message
+    if { $maxlength != -1 } {
+	bind $txt <KeyRelease> [list TextCheckLimit $txt $maxlength bg messbg]
+    }
+    TextBindings $txt
+    scrollbar $w.fr.ft.sv -command [list $txt yview]
+
+    frame $w.fr.bs
+    button $w.fr.bs.ok -text $TXT(ok) -command { set GMResConf 1 }
+    button $w.fr.bs.cancel -text $TXT(cancel) -command { set GMResConf 0 }
+
+    grid $txt -row 0 -column 0 -sticky nesw
+    grid $w.fr.ft.sv -row 0 -column 1 -sticky ns
+    pack $w.fr.bs.ok $w.fr.bs.cancel -side left -pady 5
+    pack $w.fr.tit $w.fr.ft $w.fr.bs -side top -pady 5
+    pack $w.fr
+    update idletasks
+    set gs [grab current]
+    grab $w
+    RaiseWindow $w
+    tkwait variable GMResConf
+    set message [$txt get 1.0 end]
+    DestroyRGrabs $w $gs
+    update idletasks
+    if { $GMResConf } {
+	if { $maxlength != -1 && [string length $message] > $maxlength } {
+	    set message [string replace $message $maxlength end]
+	}
+	set cmd [list configure -verbose 0 -url $url -connecttimeout 2 \
+		    -post 1 -postfields "$fieldname=$message"]
+	if { $login } {
+	    if { [set usrpwd [GMLogin $service]] == {} } { return 0 }
+	    set usrpwd "[lindex $usrpwd 0]:[lindex $usrpwd 1]"
+	    lappend cmd -userpwd $usrpwd
+	}
+	if { [catch {set chandle [curl::init]}] } { return 0 }
+	set cmd [linsert $cmd 0 $chandle]
+	if { [catch {eval $cmd}] || \
+		 [catch {set res [$chandle perform]}] || \
+		 [catch {$chandle reset}] } {
+		return 0
+	}
+	return 1
+    }
+    return 0
+}
+
+
