@@ -1,11 +1,11 @@
 #!/bin/sh
 # This is a Tcl/Tk script to be interpreted by wish (Tk8.3 or better): \
-exec wish "$0" -- "$@"
+exec wish8.4 "$0" -- "$@"
 
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -63,20 +63,20 @@ exec wish "$0" -- "$@"
 ## German language support:
 #      before version 6.0: by Andreas Lange (Andreas.C.Lange_AT_GMX.de)
 #       Copyright (c) 2002 by Andreas Lange
-#      since version 6.0: by Sabine Broda (sbb_AT_ncc.up.pt) Copyright (c) 2008
+#      since version 6.0: by Sabine Broda (sbb_AT_ncc.up.pt) Copyright (c) 2009
 #       by Sabine Broda
 ##
 #
 ## Italian language support by Alessandro Palmas (alpalmas_AT_tin.it)
-#      Copyright (c) 2008 by Alessandro Palmas
+#      Copyright (c) 2009 by Alessandro Palmas
 ##
 #
 ## French language support by Valere Robin (valere.robin_AT_wanadoo.fr)
-#       Copyright (c) 2008 by Valere Robin
+#       Copyright (c) 2009 by Valere Robin
 ##
 #
 ## Dutch language support by Rob Buitenhuis (rob_AT_buitenhs.demon.nl)
-#      Copyright (c) 2008 by Rob Buitenhuis
+#      Copyright (c) 2009 by Rob Buitenhuis
 ##
 #
 ## Indonesian language support by Tri Agus Prayitno; (acuss_AT_bk.or.id)
@@ -87,8 +87,11 @@ exec wish "$0" -- "$@"
 #      Copyright (c) 2007 by Alberto Morales
 ##
 #
-## Russian language support by Nikolai Kosyakoff (priroda.net_AT_gmail.com)
-#      Copyright (c) 2007 by Nikolai Kosyakoff
+## Russian language support:
+#      until version 6.4:  by Nikolai Kosyakoff (priroda.net_AT_gmail.com)
+#       Copyright (c) 2007 by Nikolai Kosyakoff
+#      since October 2009: by Alexander B. Preobrazhenskiy, (modul@ihome.ru)
+#       Copyright (c) 2009 by Alexander B. Preobrazhenskiy
 ##
 #
 ## Includes:
@@ -156,11 +159,11 @@ exec wish "$0" -- "$@"
 #
 ## This program uses the following Tcl libraries if they are installed:
 #    - Img, written by Jan Nijtmans
-#      http://www.xs4all.nl/~nijtmans/img.html
-#      and available as a Debian package under the name libtk-img
+#      now part of the standard Tcl distribution
 #    - gpsmanshp, written by Miguel Filgueiras
 #      http://www.ncc.up.pt/gpsmanshp
 #      and available as a Debian package under the name gpsmanshp
+#    - TclCurl, available as a Debian package under the name tclcurl
 #
 ##
 #
@@ -177,7 +180,7 @@ exec wish "$0" -- "$@"
 ##
 #
 #  File: gpsman.tcl
-#  Last change:  25 September 2008
+#  Last change:  27 December 2009
 #
 
 ############ configuration parameters
@@ -232,7 +235,7 @@ switch $tcl_platform(platform) {
 }
 
  # path to directory containing program files
-set SRCDIR gmsrc
+set SRCDIR /usr/lib/gpsman
 
 # all other default configuration is now done in file $SRCDIR/config.tcl
 
@@ -240,7 +243,7 @@ set SRCDIR gmsrc
 
 # abstract data used in the program is now in file $SRCDIR/metadata.tcl
 
-foreach f "config metadata" {
+foreach f {config metadata} {
     source [file join $SRCDIR $f.tcl]
 }
 
@@ -295,26 +298,26 @@ if { [file readable $USEROPTIONS] } {
 
 # source files read before initialization of preferences file
 set SRCFILESBEGIN {i18n-utf8 lang$LANG symbols gendials util check
-    datumell geod compute posncomp projections projs_main
+    datumell geod plugins compute posncomp projections projs_main
     recmodels recdefs rgb options}
 
 # this file may cause problems in non-western Linux installations
 if { $ISOLATIN1 } { lappend SRCFILESBEGIN isolatin1 }
 
 # source files depending on receiver brand
-set SRCFILESFOR(Garmin) "serial garmin_protocols garmin_symbols \
-	garmin_nmea garmin"
-set SRCFILESFOR(Lowrance) "lowrance_symbols lowrance_nmea lowrance \
-	lowrance_patches"
+set SRCFILESFOR(Garmin) {serial garmin_protocols garmin_symbols
+	garmin_nmea garmin}
+set SRCFILESFOR(Lowrance) {lowrance_symbols lowrance_nmea lowrance
+	lowrance_patches}
 # MGM contribution
-set SRCFILESFOR(Magellan) "serial magellan"
+set SRCFILESFOR(Magellan) {serial magellan}
 
 # other generic source files
-set SRCFILESEND "wrtdials search lists files files_foreign gpsinfo \
-	maptransf map mapanim realtime know trtort gdata cluster \
-	elevation navigate"
+set SRCFILESEND {setup wrtdials search lists files files_foreign
+        gpsinfo	maptransf map mapanim realtime know trtort gdata
+	cluster elevation navigate}
 # conditional source files
-set SRCFILESCOND [list "ACCFORMULAE acccomp" "CMDLINE command"]
+set SRCFILESCOND {{ACCFORMULAE acccomp} {CMDLINE command}}
 
 if { $tcl_version == 8.4 } {
     # Tk8.4 is incompatible with Img < 1.3
